@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,21 +17,25 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: add_photos_frame.php,v 1.9.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: add_photos_frame.php 193 2008-07-15 22:02:33Z jens $
+ */
+
+/**
+ * @package Add Photos
  */
-?>
-<?php
 
 require_once(dirname(__FILE__) . '/init.php');
 ?>
 
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Frameset//EN" "http://www.w3.org/TR/html4/frameset.dtd">
+
 <html>
 <head>
-  <title><?php echo _("Add Photos") ?></title>
+  <title><?php echo gTranslate('core', "Add Photos") ?></title>
 </head>
-<frameset rows="100%, 0%" border=0 frameborder=0 framespacing=0>
-  <frame src="<?php echo makeGalleryUrl('add_photos.php', array('set_albumName' => $gallery->session->albumName, "type" => "popup")); ?>" noresize />
-  <frame name="hack" src="" noresize noscroll />
+<frameset rows="100%, 0%" border="0" frameborder="0" framespacing="0">
+  <frame src="<?php echo makeGalleryUrl('add_photos.php', array('set_albumName' => $gallery->session->albumName, 'type' => 'popup')); ?>" noresize>
+  <frame name="hack" src="" noresize noscroll>
 </frameset>
 
 <!-- This is a hack that's needed for the GR applet to be able to
