@@ -1,30 +1,28 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: admin-page.php,v 1.16.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: admin-page.php 193 2008-07-15 22:02:33Z jens $
  *
  */
-?>
-<?php
 
 if (!isset($gallery->version)) {
-        require_once(dirname(__FILE__) . '/init.php');
+		require_once(dirname(__FILE__) . '/init.php');
 }
 
 // Security check
@@ -33,58 +31,70 @@ if (!$gallery->user->isAdmin()) {
 	exit;
 }
 
-$adminOptions[] = array( 'text' => _("statistics"), 
-			 'url' => makeGalleryUrl('stats-wizard.php'),
-			 'longtext' => _("View some statistics about your Gallery. Such as most viewed pictures, or best rated photos etc."));
+$adminOptions[] = array(
+			'text' => gTranslate('core', "Statistics"),
+			'url' => makeGalleryUrl('stats-wizard.php'),
+			'longtext' => gTranslate('core', "View some statistics about your Gallery. Such as most viewed pictures, or best rated photos etc."));
 
-$adminOptions[] = array( 'text' => _("configuration wizard"),
+$adminOptions[] = array( 'text' => gTranslate('core', "Configuration wizard"),
 			 'url' => $gallery->app->photoAlbumURL . '/setup/index.php',
-			 'longtext' => _("Use the config wizard to reconfigure or tweak your Gallery"));
+			 'longtext' => gTranslate('core', "Use the config wizard to reconfigure or tweak your Gallery."));
 
-$adminOptions[] = array( 'text' => _("find orphans"),
+$adminOptions[] = array( 'text' => gTranslate('core', "Find orphans"),
 			 'url' => makeGalleryUrl('tools/find_orphans.php'),
-			 'longtext' => _("Find, remove or re-attach orphaned elements."));
+			 'longtext' => gTranslate('core', "Find, remove or re-attach orphaned elements."));
 
-$adminOptions[] = array( 'text' => _("find comment spam"),
+$adminOptions[] = array( 'text' => gTranslate('core', "Find comment spam"),
 			 'url' => makeGalleryUrl('tools/despam-comments.php'),
-			 'longtext' => _("Find and remove comments that contains spam."));
+			 'longtext' => gTranslate('core', "Find and remove comments that contains spam."));
 
-$adminOptions[] = array( 'text' => _("validate albums"),
+$adminOptions[] = array( 'text' => gTranslate('core', "Validate albums"),
 			 'url' => makeGalleryUrl('tools/validate_albums.php'),
-			 'longtext' => _("Identify invalid albums, missing files, and other errors that may prevent you from migrating to Gallery 2"));
+			 'longtext' => gTranslate('core', "Identify invalid albums, missing files, and other errors that may prevent you from migrating to Gallery 2."));
 
-#$adminOptions[] = array( 'text' => _("Gallery backup"),
-#			 'url' => makeGalleryUrl('backup_albums.php'),
-#			 'longtext' => _("Make a backup of your Gallery."));
+/*
+$adminOptions[] = array(
+		'text' => gTranslate('core', "Gallery backup"),
+		'url' => makeGalleryUrl('backup_albums.php'),
+		'longtext' => gTranslate('core', "Make a backup of your Gallery."));
+*/
 
 if (!$GALLERY_EMBEDDED_INSIDE) {
-    $adminOptions[]  = array('text' => _("manage users"),
+    $adminOptions[]  = array('text' => gTranslate('core', "Manage users"),
 			 'popupFile' => 'manage_users.php',
-			 'longtext' => _("Manage your users."));
+			 'longtext' => gTranslate('core', "Manage your users."));
 }
 
 array_sort_by_fields($adminOptions, 'text', 'asc');
 
+$iconElements[] = galleryIconLink(
+			makeAlbumUrl(),
+			'navigation/return_to.gif',
+			gTranslate('core', "Return to gallery"));
+
+$iconElements[] = LoginLogoutButton();
+
+$adminbox['text']     = gTranslate('core', "Admin options");
+$adminbox['commands'] = makeIconMenu($iconElements, 'right');
+
+$breadcrumb['text'][] = languageSelector();
+
 if (!$GALLERY_EMBEDDED_INSIDE) {
-    doctype();
+	doctype();
 ?>
 <html>
 <head>
-<title><?php echo $gallery->app->galleryTitle; ?>::<?php echo _("Admin options") ?></title>
-<?php 
+<title><?php echo $gallery->app->galleryTitle; ?>::<?php echo gTranslate('core', "Admin options") ?></title>
+<?php
 	common_header() ;
 ?>
 </head>
 <body dir="<?php echo $gallery->direction ?>">
-<?php  
+<?php
 }
 
 includeHtmlWrap('gallery.header');
 
-$adminbox['text'] ='<span class="head">'. _("Admin options") .'</span>';
-$adminbox['commands'] = '[<a href="'. makeAlbumUrl() .'">'. _("return to gallery") .'</a>]';
-$breadcrumb['text'][] = languageSelector();
-
 includeLayout('navtablebegin.inc');
 includeLayout('adminbox.inc');
 includeLayout('navtablemiddle.inc');
@@ -99,7 +109,7 @@ if(!empty($adminOptions)) {
 		if (isset($option['url'])) {
 			$link = '<a class="admin" href="'. $option['url'] .'">'. $option['text'] .'</a>';
 		} else {
-			$link = popup_link($option['text'], $option['popupFile'], false, true, 500, 500, 'admin');
+			$link = popup_link($option['text'], $option['popupFile'], false, true, 500, 500, 'admin', '', '', false);
 		}
 		echo "\n<td class=\"adm_options\">$link</td>";
 		echo "\n<td class=\"adm_options\">". $option['longtext'] ."</td>";
