@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: block-random.php,v 1.14.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: block-random.php 193 2008-07-15 22:02:33Z jens $
  */
 /*
  * This block selects a random photo for display.  It will only display photos
@@ -36,7 +36,7 @@
  * *Nuke:
  * http://<URL to your Nuke>/modules.php?op=modload&name=gallery&file=index&include=block-random.php
  *
- * Mambo:
+ * Mambo / Joomla :
  * http://<URL to Mambo>/index.php?option=com_gallery&Itemid=XXX
  */
 
@@ -59,9 +59,10 @@ if (fs_file_exists(CACHE_FILE)) {
 
 if ($rebuild) {
 	scanAlbums();
-	saveCache();
-} else {
-	readCache();
+	saveGalleryBlockRandomCache();
+}
+else {
+	readGalleryBlockRandomCache();
 }
 
 $i = 0;
@@ -71,7 +72,7 @@ do {
 } while (empty($success) && $i < $gallery->app->blockRandomAttempts);
 
 if (empty($success)) {
-	echo '<center>No photo chosen.</center>';
+	echo gTranslate('core', "No photo chosen.");
 }
 
 function doPhoto() {
@@ -83,20 +84,21 @@ function doPhoto() {
 
 	if (!empty($index)) {
 		$id = $album->getPhotoId($index);
-		echo ""
-			. '<center><a href="' . makeAlbumUrl($album->fields['name'], $id) . '">'
-			. $album->getThumbnailTag($index)
-			. '</a></center>';
-
-		$caption = $album->getCaption($index);
-		if ($caption) {
-			echo '<br><center>' . $caption . '</center>';
-		}
-
-		echo '<br><center>From: '
-			. '<a href="' .makeAlbumUrl($album->fields['name']) .'">'
-			. $album->fields['title']
-			. '</a></center>';
+		$caption = $album->getCaption($index) ? '<br>'. $album->getCaption($index) : '';
+		$photoUrl = makeAlbumUrl($album->fields['name'], $id);
+		$imageUrl = $album->getThumbnailTag($index);
+		$albumUrl = makeAlbumUrl($album->fields['name']);
+		$albumTitle = $album->fields['title'];
+?>
+  <div class="random-block">
+    <div class="random-block-photo">
+    <a href="<?php echo $photoUrl; ?>"><?php echo $imageUrl; ?></a>
+    <?php echo $caption; ?>
+    
+    </div>
+    <?php printf (_("From album: %s"), "<a href=\"$albumUrl\">$albumTitle</a>"); ?>
+  </div>
+<?php
 		return 1;
 	} else {
 		return 0;
@@ -109,15 +111,15 @@ function doPhoto() {
  * --------------------------------------------------
  */
 
-function saveCache() {
+function saveGalleryBlockRandomCache() {
 	global $cache;
 	safe_serialize($cache, CACHE_FILE);
 }
 
-function readCache() {
+function readGalleryBlockRandomCache() {
 	global $cache;
 
-	$sCache = getFile(CACHE_FILE);
+	$sCache = fs_file_get_contents(CACHE_FILE);
 	$cache = unserialize($sCache);
 }
 
