@@ -1,38 +1,52 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: AlbumDB.php,v 1.41.2.1 2005/09/12 22:40:44 dmolavi Exp $
- */
-?>
-<?php
+ * $Id: AlbumDB.php 193 2008-07-15 22:02:33Z jens $
+*/
+
 class AlbumDB {
 	var $albumList;
 	var $albumOrder;
+	var $initialized;
 
-	function AlbumDB($loadphotos=TRUE) {
+	function AlbumDB($loadphotos = true) {
 		global $gallery;
+
 		$changed = 0;
+		$this->initialized = false;
 
 		$dir = $gallery->app->albumDir;
 
-		$tmp = getFile("$dir/albumdb.dat");
-		if (strcmp($tmp, "")) {
+		$allowedInvalidAlbums = array('CVS', 'SVN', '_vti_cnf', 'lost+found', 'captcha_tmp');
+
+		if(!fs_is_dir($dir)) {
+			echo infoBox(array(array(
+				'type' => 'error',
+				'text' => sprintf("Albumdir (%s) not found! Please check the path to the albums folder in your config.php.",
+						  $dir)
+			)));
+
+			return false;
+		}
+
+		$tmp = fs_file_get_contents("$dir/albumdb.dat");
+		if (strcmp($tmp, '')) {
 			$this->albumOrder = unserialize($tmp);
 
 			// albumdb.dat is corrupt, rebuild it
@@ -40,7 +54,8 @@ class AlbumDB {
 				$this->albumOrder = array();
 			}
 			$changed = 1;
-		} else {
+		}
+		else {
 			$this->albumOrder = array();
 		}
 
@@ -50,21 +65,24 @@ class AlbumDB {
 		$i = 0;
 		while ($i < sizeof($this->albumOrder)) {
 			$name = $this->albumOrder[$i];
-		       	if (ereg("^\.", $name)) { // how did this get here??
+			if (ereg("^\.", $name)) { // how did this get here??
 				array_splice($this->albumOrder, $i, 1);
 				$changed = 1;
-			} else if (fs_is_dir("$dir/$name")) {
+			}
+			else if (fs_is_dir("$dir/$name")) {
 				$album = new Album;
 				if ($album->load($name,$loadphotos)) {
 					array_push($this->albumList, $album);
 					if ($album->versionOutOfDate()) {
 						array_push($this->outOfDateAlbums, $name);
 					}
-				} else if ($name != 'CVS') {
+				}
+				else if (!in_array($name, $allowedInvalidAlbums)) {
 					array_push($this->brokenAlbums, $name);
 				}
 				$i++;
-			} else {
+			}
+			else {
 				/* Couldn't find the album -- delete it from order */
 				array_splice($this->albumOrder, $i, 1);
 				$changed = 1;
@@ -73,10 +91,11 @@ class AlbumDB {
 
 		if ($fd = fs_opendir($dir)) {
 			while ($file = readdir($fd)) {
-				if (!ereg("^\.", $file) && 
-				    fs_is_dir("$dir/$file") &&
-				    strcmp($file, "_vti_cnf") &&
-				    !in_array($file, $this->albumOrder)) {
+				if (!ereg("^\.", $file) &&
+					fs_is_dir("$dir/$file") &&
+					!in_array($file, $allowedInvalidAlbums) &&
+					!in_array($file, $this->albumOrder))
+				{
 					$album = new Album;
 					$album->load($file,$loadphotos);
 					array_push($this->albumList, $album);
@@ -90,6 +109,41 @@ class AlbumDB {
 		if ($changed) {
 			$this->save();
 		}
+
+		$this->initialized = true;
+	}
+
+	/**
+	 * Returns whether the AlbumDB was succesfully initialized or not
+	 *
+	 * @return boolean	 true if succesfully initialized.
+	 * @author Jens Tkotz
+	 */
+	function isInitialized() {
+		return $this->initialized === true;
+	}
+
+	function sortByField($fieldname = '', $order = 'desc') {
+		$tmpOrder = array();
+
+		if(!empty($fieldname)) {
+			if($fieldname == 'name') {
+				if($order == 'asc') {
+					sort($this->albumOrder);
+				}
+				else {
+					rsort($this->albumOrder);
+				}
+			}
+			else {
+				array_sort_by_fields($this->albumList, $fieldname , $order, true, false, true);
+				foreach ($this->albumList as $album) {
+					$tmpOrder[] = $album->fields["name"];
+				}
+				$this->albumOrder = $tmpOrder;
+			}
+			$this->save();
+		}
 	}
 
 	function renameAlbum($oldName, $newName) {
@@ -117,7 +171,7 @@ class AlbumDB {
 		$album->load($newName);
 		$album->fields['name'] = $newName;
 		$album->save();
-		
+
 		for ($i = 0; $i < sizeof($this->albumOrder); $i++) {
 			if (!strcmp($this->albumOrder[$i], $oldName)) {
 				$this->albumOrder[$i] = $newName;
@@ -127,13 +181,17 @@ class AlbumDB {
 		return 1;
 	}
 
-	function newAlbumName($name="album01") {
+	function newAlbumName($name = '') {
 		global $gallery;
 
-		if (!$name) {
-			$name="album01";
+		/* If an invalid album name was given (however) we use a default. */
+		$validAlbumName = validAlbumName($name);
+		if (!$name || !empty($validAlbumName)) {
+			$name = 'album01';
 		}
+
 		$albumDir = $gallery->app->albumDir;
+
 		while (fs_file_exists("$albumDir/$name")) {
 			switch($name) {
 				case 'album99':
@@ -150,7 +208,7 @@ class AlbumDB {
 
 				default:
 					if (!ereg('[0-9][0-9]$', $name)) {
-						$name.="00";
+						$name .= "00";
 					}
 					$name++;
 			}
@@ -161,15 +219,17 @@ class AlbumDB {
 	function numAlbums($user) {
 		return sizeof($this->getVisibleAlbums($user));
 	}
-	
+
 	function numPhotos($user) {
 		$numPhotos = 0;
+
 		foreach ($this->albumList as $album) {
 			if ($user->canWriteToAlbum($album)) {
 				$numPhotos += $album->numPhotos(1);
-                        } else if ($user->canReadAlbum($album)) {
-                                $numPhotos += $album->numPhotos(0);
-                        }
+			}
+			else if ($user->canReadAlbum($album)) {
+				$numPhotos += $album->numPhotos(0);
+			}
 		}
 
 		return $numPhotos;
@@ -177,6 +237,7 @@ class AlbumDB {
 
 	function getCachedNumPhotos($user) {
 		$numPhotos = 0;
+
 		foreach ($this->albumList as $album) {
 			if ($user->canReadAlbum($album)) {
 				$numPhotos += $album->fields["cached_photo_count"];
@@ -186,20 +247,25 @@ class AlbumDB {
 	}
 
 	function getAlbum($user, $index) {
-	    global $gallery;
-	    $list = $this->getVisibleAlbums($user);
-	    $wantedAlbum = isset($list[$index-1]) ? $list[$index-1] : false;
-	    if ($wantedAlbum && (!isset($wantedAlbum->transient) || !$wantedAlbum->transient->photosloaded)) {
-		$wantedAlbum->loadPhotos($gallery->app->albumDir . "/" . $wantedAlbum->fields["name"]);
-	    }
-	    return $wantedAlbum;
+		global $gallery;
+
+		$list = $this->getVisibleAlbums($user);
+		$wantedAlbum = isset($list[$index-1]) ? $list[$index-1] : false;
+
+		if ($wantedAlbum &&
+			(!isset($wantedAlbum->transient) || !$wantedAlbum->transient->photosloaded))
+		{
+			$wantedAlbum->loadPhotos($gallery->app->albumDir . "/" . $wantedAlbum->fields["name"]);
+		}
+		return $wantedAlbum;
 	}
 
-	function getAlbumByName($name, $load=TRUE) {
+	function getAlbumByName($name, $load = TRUE) {
 		global $gallery;
+
 		/* Look for an exact match */
 		foreach ($this->albumList as $album) {
-		        set_time_limit($gallery->app->timeLimit);
+			set_time_limit($gallery->app->timeLimit);
 			if ($album->fields["name"] == $name) {
 				if ((!isset($album->transient) || !$album->transient->photosloaded) && $load) {
 					$album->loadPhotos($gallery->app->albumDir . "/$name");
@@ -210,7 +276,8 @@ class AlbumDB {
 
 		/* Look for a match that is case insensitive */
 		foreach ($this->albumList as $album) {
-		        set_time_limit($gallery->app->timeLimit);
+			set_time_limit($gallery->app->timeLimit);
+
 			if (!strcasecmp($album->fields["name"], $name)) {
 				if (!$album->transient->photosloaded && $load) {
 					$album->loadPhotos($gallery->app->albumDir . "/$name");
@@ -218,14 +285,14 @@ class AlbumDB {
 				return $album;
 			}
 		}
-		
-		return 0;
+
+		return false;
 	}
 
 	function moveAlbum($user, $index, $newIndex) {
 
 		// This is tricky.  The old and new indices are only relevant
-		// within the list of albums that this user is able to see!  
+		// within the list of albums that this user is able to see!
 		// Find the location that the user desires and determine that it's
 		// one of three cases:
 		//	1. At the beginning of the album
@@ -252,10 +319,12 @@ class AlbumDB {
 		if ($newIndex == 1) {
 			// Move to beginning
 			$this->moveAlbumAbsolute($absIndex, 0);
-		} else if ($newIndex == sizeof($visible)) {
+		}
+		else if ($newIndex == sizeof($visible)) {
 			// Move to end
 			$this->moveAlbumAbsolute($absIndex, sizeof($this->albumList)-1);
-		} else {
+		}
+		else {
 			// Move to relative spot
 			$this->moveAlbumAbsolute($absIndex, $absNewIndex);
 		}
@@ -273,7 +342,9 @@ class AlbumDB {
 
 	function getVisibleAlbums($user) {
 		global $gallery;
+
 		$list = array();
+
 		foreach ($this->albumList as $album) {
 			if ($user->canReadAlbum($album) && $album->isRoot()) {
 				array_push($list, $album);
@@ -285,43 +356,53 @@ class AlbumDB {
 
 	function save() {
 		global $gallery;
-		$success = 0;
+        	$success = 0;
 
 		$dir = $gallery->app->albumDir;
-		return safe_serialize($this->albumOrder, "$dir/albumdb.dat");
+        	return safe_serialize($this->albumOrder, "$dir/albumdb.dat");
 	}
 
 	function numAccessibleAlbums($user) {
 		$numAlbums = 0;
+
 		foreach ($this->albumList as $album) {
-			if ($user->canReadAlbum($album))
-			$numAlbums++;
+			if ($user->canReadAlbum($album)) {
+				$numAlbums++;
+			}
 		}
+
 		return $numAlbums;
 	}
 
 	function numAccessibleItems($user) {
 		global $gallery;
+
 		$numPhotos = $numAlbums = $numTopAlbums = 0;
+
 		foreach ($this->albumList as $album) {
 			if ($user->canReadAlbum($album)) {
 				$numAlbums++;
+
 				if ($album->isRoot()) {
 					$numTopAlbums++;
 				}
+
 				if (empty($gallery->app->slowPhotoCount) || $gallery->app->slowPhotoCount == "no") {
 					$numPhotos += $album->fields["cached_photo_count"];
-				} else {
+				}
+				else {
 					$album->load($album->fields['name']);
 					$numPhotos += $album->numPhotos(1,1);
 				}
 			}
 		}
+
 		return array($numPhotos, $numAlbums, $numTopAlbums);
 	}
 
 	function getAlbumsByRoot($rootAlbumName, $user=null) {
 		$namedAlbum = $this->getAlbumByName($rootAlbumName);
+
 		if ($namedAlbum) {
 			$arr = $namedAlbum->getSubAlbums();
 			array_push($arr, $namedAlbum);
@@ -330,4 +411,4 @@ class AlbumDB {
 	}
 }
 
-?>
+?>
\ No newline at end of file
