@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: Comment.php,v 1.18.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: Comment.php 193 2008-07-15 22:02:33Z jens $
  */
 ?>
 <?php
@@ -53,13 +53,16 @@ class Comment {
 
 	function getName() {
 		global$gallery;
-		$name="";
-		if  ($gallery->app->comments_anonymous == "no") {
-			$name=user_name_string($this->UID, 
-					$gallery->app->comments_display_name);
+		
+		$name = '';
+		$user = $gallery->userDB->getUserByUid($this->UID);
+		
+		if (!$user->isPseudo()) {
+		    $name = $user->printableName($gallery->app->comments_display_name);
 		}
+		
 		if (!$name) {
-			$name=$this->name;
+			$name = $this->name;
 		}
 		return $name;
 	}
