@@ -1,26 +1,25 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: Image.php,v 1.66.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: Image.php 239 2008-07-28 09:07:46Z jens $
  */
-?>
-<?php
+
 class Image {
 	var $name;
 	var $type;
@@ -66,7 +65,7 @@ class Image {
 
 		/*
 		 * Fix a specific bug where the width/height are reversed
-		 * for sized images 
+		 * for sized images
 		 */
 		if ($this->version < 3) {
 			if ($this->resizedName) {
@@ -78,9 +77,11 @@ class Image {
 		}
 
 		$filename = "$dir/$this->name.$this->type";
+
 		if (!isMovie($this->type)) {
 			if (!$this->raw_width) {
 				list($w, $h) = getDimensions($filename);
+
 				$this->raw_width = $w;
 				$this->raw_height = $h;
 				$changed = 1;
@@ -101,28 +102,30 @@ class Image {
 	function resize($dir, $target, $filesize, $pathToResized) {
 		global $gallery;
 
-		/* getting rid of the resized image */
+		// getting rid of the resized image
 		if (stristr($target, "orig")) {
 			list($w, $h) = getDimensions("$dir/$this->name.$this->type");
+
 			$this->width = $w;
 			$this->height = $h;
+
 			if (fs_file_exists("$dir/$this->resizedName.$this->type")) {
 				fs_unlink("$dir/$this->resizedName.$this->type");
 			}
-			$this->resizedName = "";
-		/* doing a resize */
-		} else {
+			$this->resizedName = '';
+		}
+		// doing a resize
+		else {
 			$name = $this->name;
 			$type = $this->type;
-			
+
 			if ($pathToResized) {
-				$ret = copy($pathToResized,"$dir/$name.sized.$this->type");	
-			} else {
-				$ret = resize_image("$dir/$name.$type",
-					     "$dir/$name.sized.$this->type",
-					     $target, $filesize);
+				$ret = copy($pathToResized,"$dir/$name.sized.$this->type");
 			}
-			
+			else {
+				$ret = resize_image("$dir/$name.$type", "$dir/$name.sized.$this->type", $target, $filesize);
+			}
+
 			#-- resized image is not always a jpeg ---
 			if ($ret == 1) {
 				$this->resizedName = "$name.sized";
@@ -133,17 +136,20 @@ class Image {
 			elseif ($ret == 2) {
 				$this->resize($dir, "orig", 0, $pathToResized);
 			}
-		}	
+		}
 	}
 
 	function delete($dir) {
 		clearstatcache();
+
 		if (fs_file_exists("$dir/$this->resizedName.$this->type")) {
 			fs_unlink("$dir/$this->resizedName.$this->type");
 		}
+
 		if (fs_file_exists("$dir/$this->name.highlight.$this->type")) {
 			fs_unlink("$dir/$this->name.highlight.$this->type");
 		}
+
 		fs_unlink("$dir/$this->name.$this->type");
 	}
 
@@ -153,52 +159,73 @@ class Image {
 		}
 	}
 
-	function getTag($dir, $full=0, $size=0, $attrs="",$alttext="") {
+	function getTag($dir, $full = false, $size = 0, $attrs = array()) {
 		global $gallery;
 
-		// Prevent non-integer data
+		/* Prevent non-integer data */
 		$size = (int)$size;
 
-		$name = $this->getName($dir);
-		$alttext = unhtmlentities(strip_tags($alttext));
+		$attrsCopy = $attrs;
+
+		$attrs['alt'] = $attrs['title'] = htmlspecialchars(strip_tags(trim($attrs['alt'])));
 
-		$attrs .= ' border="0"';
 		if ($size) {
 			if ($this->width > $this->height) {
-				$width = $size;
-				$height = round($size * ($this->height / $this->width));
-			} else {
-				$width = round($size * ($this->width / $this->height));
-				$height = $size;
+				$width	= $size;
+				$height	= round($size * ($this->height / $this->width));
 			}
-			$size_val = "width=\"$width\" height=\"$height\"";
-		} else if ($full || !$this->resizedName) {
-			$size_val = "width=\"$this->raw_width\" height=\"$this->raw_height\"";
-		} else {
-			$size_val = "width=\"$this->width\" height=\"$this->height\"";
+			else {
+				$width	= round($size * ($this->width / $this->height));
+				$height	= $size;
+			}
+			$attrs['width']		= $width;
+			$attrs['height']	= $height;
+		}
+		else if ($full || !$this->resizedName) {
+			$attrs['width']		= $this->raw_width;
+			$attrs['height']	= $this->raw_height;
+		}
+		else {
+			$attrs['width']		= $this->width;
+			$attrs['height']	= $this->height;
 		}
 
-		$fullImage = urlencode($this->name) .".$this->type";
-		$resizedImage = urlencode($this->resizedName) .".$this->type";
+		$fullImage	= urlencode($this->name) .".$this->type";
+		$resizedImage	= urlencode($this->resizedName) .".$this->type";
 
 		if ($this->resizedName && $size == 0) {
 			if ($full) {
-				return "<img src=\"$dir/$fullImage\" " .
-					"width=\"$this->raw_width\" height=\"$this->raw_height\" $attrs alt=\"$alttext\" title=\"$alttext\">";
-			} else {
-				return "<img src=\"$dir/$resizedImage\" " .
-					"width=\"$this->width\" height=\"$this->height\" " .
-					"$attrs alt=\"$alttext\" title=\"$alttext\">";
+				$attrs['width']		= $this->raw_width;
+				$attrs['height']	= $this->raw_height;
+				$attrs['src']		= "$dir/$fullImage";
+			}
+			else {
+				$attrs['width']		= $this->width;
+				$attrs['height']	= $this->height;
+				$attrs['src']		= "$dir/$resizedImage";
 			}
-		} else {
-			return "<img src=\"$dir/$fullImage\" $size_val $attrs alt=\"$alttext\" title=\"$alttext\" name=\"photo_j\">";
 		}
+		else {
+			$attrs['src']			= "$dir/$fullImage";
+		}
+
+		$overwrite = array('height', 'width');
+		foreach ($overwrite as $attr) {
+			if(isset($attrsCopy[$attr])) {
+				$attrs[$attr] = $attrsCopy[$attr];
+			}
+		}
+
+		$tag = '<img'. generateAttrs($attrs). '>';
+
+		return $tag;
 	}
 
-	function getName($dir, $full=0) {
+	function getName($dir, $full = false) {
 		if ((!$full) && (fs_file_exists("$dir/$this->resizedName.$this->type"))) {
 			return $this->resizedName;
-		} else {
+		}
+		else {
 			return $this->name;
 		}
 	}
@@ -206,21 +233,34 @@ class Image {
 	function getId() {
 		return $this->name;
 	}
-	
+
 	function getPath($dir, $full=0) {
 		if ($full || !$this->resizedName) {
-		    $name = $this->name;
-		} else {
-		    $name = $this->resizedName;
+			$name = $this->name;
 		}
+		else {
+			$name = $this->resizedName;
+		}
+
 		return "$dir/$name.$this->type";
 	}
 
+	function getImageName($full = false) {
+		if ($full || !$this->resizedName) {
+			$name = $this->name;
+		} else {
+			$name = $this->resizedName;
+		}
+
+		return "$name.$this->type";
+	}
+
 	function isResized() {
 		if ($this->resizedName) {
-			return 1;
-		} else {
-			return 0;
+			return true;
+		}
+		else {
+			return false;
 		}
 	}
 
@@ -235,23 +275,25 @@ class Image {
 	}
 
 	function getDimensions($size=0, $full=false) {
-	    if ($size) {
-                if ($this->width > $this->height) {
-                    $width = $size;
-                    $height = round($size * ($this->height / $this->width));
-                } else {
-                    $width = round($size * ($this->width / $this->height));
-                    $height = $size;
-                }
-            } else if ($full) {
-		$width = $this->raw_width;
-		$height = $this->raw_height;
-	    }
-	    else {
-		$width = $this->width;
-		$height = $this->height;
-            }
-	        
+		if ($size) {
+			if ($this->width > $this->height) {
+				$width = $size;
+				$height = round($size * ($this->height / $this->width));
+			}
+			else {
+				$width = round($size * ($this->width / $this->height));
+				$height = $size;
+			}
+		}
+		else if ($full) {
+			$width = $this->raw_width;
+			$height = $this->raw_height;
+		}
+		else {
+			$width = $this->width;
+			$height = $this->height;
+		}
+
 		return array($width, $height);
 	}
 
@@ -263,8 +305,12 @@ class Image {
 	}
 
 	function getThumbRectangle() {
-		return array($this->thumb_x, $this->thumb_y,
-		             $this->thumb_width, $this->thumb_height);
+		return array(
+			$this->thumb_x,
+			$this->thumb_y,
+			$this->thumb_width,
+			$this->thumb_height
+		);
 	}
 
 	function getRawDimensions() {
@@ -272,9 +318,9 @@ class Image {
 	}
 
 	function rawFileSize($dir) {
-	    $filename = "$dir/$this->name.$this->type";
-	    return fs_filesize($filename);
+		$filename = "$dir/$this->name.$this->type";
+		return fs_filesize($filename);
 	}
-}	
+}
 
 ?>
