@@ -1,24 +1,41 @@
 <?php
 /**
- * Filename.......: class.html.mime.mail.inc
- * Project........: HTML Mime mail class
- * Last Modified..: $Date: 2005/07/19 20:57:19 $
- * CVS Revision...: $Revision: 1.4 $
- * Copyright......: 2001, 2002 Richard Heyes
- * @package Mail
+ * Gallery SVN info
+ * $Id: htmlMimeMail.php 149 2008-06-26 23:09:32Z jens $
+ * 
+ * Note: This file was very slightly modified to fit into Gallery 1.x
+ * - PHP 5 compatible: Changed all $HTTP_ to $_SERVER
+ * - Added some Gallery error messages
 */
 
 /**
- *
- */
+* This file is part of the htmlMimeMail package (http://www.phpguru.org/)
+*
+* htmlMimeMail is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or
+* (at your option) any later version.
+*
+* htmlMimeMail is distributed in the hope that it will be useful,
+* but WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+* GNU General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with htmlMimeMail; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+* 
+*  Copyright 2004 Richard Heyes
+*/
+
 require_once(dirname(__FILE__) . '/mimePart.php');
 
 class htmlMimeMail
 {
 	/**
 	* The html part of the message
-    * @var string
-    */
+	* @var string
+	*/
 	var $html;
 
 	/**
@@ -74,18 +91,18 @@ class htmlMimeMail
 	* @var boolean
 	*/
 	var $is_built;
-	
+
 	/**
-    * The return path address. If not set the From:
+	* The return path address. If not set the From:
 	* address is used instead
 	* @var string
-    */
+	*/
 	var $return_path;
-	
+
 	/**
-    * Array of information needed for smtp sending
+	* Array of information needed for smtp sending
 	* @var array
-    */
+	*/
 	var $smtp_params;
 
 /**
@@ -96,17 +113,17 @@ class htmlMimeMail
 	function htmlMimeMail()
 	{
 		/**
-        * Initialise some variables.
-        */
+		* Initialise some variables.
+		*/
 		$this->html_images = array();
-		$this->headers     = array();
-		$this->is_built    = false;
+		$this->headers	 = array();
+		$this->is_built	= false;
 
 		/**
-        * If you want the auto load functionality
+		* If you want the auto load functionality
 		* to find other image/file types, add the
 		* extension and content type here.
-        */
+		*/
 		$this->image_types = array(
 									'gif'	=> 'image/gif',
 									'jpg'	=> 'image/jpeg',
@@ -120,22 +137,22 @@ class htmlMimeMail
 								  );
 
 		/**
-        * Set these up
-        */
+		* Set these up
+		*/
 		$this->build_params['html_encoding'] = 'quoted-printable';
 		$this->build_params['text_encoding'] = '7bit';
 		$this->build_params['html_charset']  = 'ISO-8859-1';
 		$this->build_params['text_charset']  = 'ISO-8859-1';
 		$this->build_params['head_charset']  = 'ISO-8859-1';
-		$this->build_params['text_wrap']     = 998;
+		$this->build_params['text_wrap']	 = 998;
 
 		/**
-        * Defaults for smtp sending
-        */
-		if (!empty($GLOBALS['HTTP_SERVER_VARS']['HTTP_HOST'])) {
-			$helo = $GLOBALS['HTTP_SERVER_VARS']['HTTP_HOST'];
-		} elseif (!empty($GLOBALS['HTTP_SERVER_VARS']['SERVER_NAME'])) {
-			$helo = $GLOBALS['HTTP_SERVER_VARS']['SERVER_NAME'];
+		* Defaults for smtp sending
+		*/
+		if (!empty($_SERVER['HTTP_HOST'])) {
+			$helo = $_SERVER['HTTP_HOST'];
+		} elseif (!empty($_SERVER['SERVER_NAME'])) {
+			$helo = $_SERVER['SERVER_NAME'];
 		} else {
 			$helo = 'localhost';
 		}
@@ -148,8 +165,8 @@ class htmlMimeMail
 		$this->smtp_params['pass'] = '';
 
 		/**
-        * Make sure the MIME version header is first.
-        */
+		* Make sure the MIME version header is first.
+		*/
 		$this->headers['MIME-Version'] = '1.0';
 	}
 
@@ -314,7 +331,7 @@ class htmlMimeMail
 */
 	function setHtml($html, $text = null, $images_dir = null)
 	{
-		$this->html      = $html;
+		$this->html	  = $html;
 		$this->html_text = $text;
 
 		if (isset($images_dir)) {
@@ -354,7 +371,7 @@ class htmlMimeMail
 			// If duplicate images are embedded, they may show up as attachments, so remove them.
 			$html_images = array_unique($html_images);
 			sort($html_images);
-	
+
 			for ($i=0; $i<count($html_images); $i++) {
 				if ($image = $this->getFile($images_dir.$html_images[$i])) {
 					$ext = substr($html_images[$i], strrpos($html_images[$i], '.') + 1);
@@ -375,7 +392,7 @@ class htmlMimeMail
 										'body'   => $file,
 										'name'   => $name,
 										'c_type' => $c_type,
-										'cid'    => md5(uniqid(time()))
+										'cid'	=> md5(uniqid(time()))
 									);
 	}
 
@@ -399,8 +416,8 @@ class htmlMimeMail
 	function &_addTextPart(&$obj, $text)
 	{
 		$params['content_type'] = 'text/plain';
-		$params['encoding']     = $this->build_params['text_encoding'];
-		$params['charset']      = $this->build_params['text_charset'];
+		$params['encoding']	 = $this->build_params['text_encoding'];
+		$params['charset']	  = $this->build_params['text_charset'];
 		if (is_object($obj)) {
 			$ret = & $obj->addSubpart($text, $params);
 		} else {
@@ -415,8 +432,8 @@ class htmlMimeMail
 	function &_addHtmlPart(&$obj)
 	{
 		$params['content_type'] = 'text/html';
-		$params['encoding']     = $this->build_params['html_encoding'];
-		$params['charset']      = $this->build_params['html_charset'];
+		$params['encoding']	 = $this->build_params['html_encoding'];
+		$params['charset']	  = $this->build_params['html_charset'];
 		if (is_object($obj)) {
 			$ret = & $obj->addSubpart($this->html, $params);
 		} else {
@@ -466,25 +483,25 @@ class htmlMimeMail
 /**
 * Adds an html image subpart to a mime_part object
 */
-	function &_addHtmlImagePart(&$obj, $value)
+	function _addHtmlImagePart(&$obj, $value)
 	{
 		$params['content_type'] = $value['c_type'];
-		$params['encoding']     = 'base64';
+		$params['encoding']	 = 'base64';
 		$params['disposition']  = 'inline';
-		$params['dfilename']    = $value['name'];
-		$params['cid']          = $value['cid'];
+		$params['dfilename']	= $value['name'];
+		$params['cid']		  = $value['cid'];
 		$obj->addSubpart($value['body'], $params);
 	}
 
 /**
 * Adds an attachment subpart to a mime_part object
 */
-	function &_addAttachmentPart(&$obj, $value)
+	function _addAttachmentPart(&$obj, $value)
 	{
 		$params['content_type'] = $value['c_type'];
-		$params['encoding']     = $value['encoding'];
+		$params['encoding']	 = $value['encoding'];
 		$params['disposition']  = 'attachment';
-		$params['dfilename']    = $value['name'];
+		$params['dfilename']	= $value['name'];
 		$obj->addSubpart($value['body'], $params);
 	}
 
@@ -495,19 +512,19 @@ class htmlMimeMail
 * of the message. Currently supported are:
 *
 * $params['html_encoding'] - The type of encoding to use on html. Valid options are
-*                            "7bit", "quoted-printable" or "base64" (all without quotes).
-*                            7bit is EXPRESSLY NOT RECOMMENDED. Default is quoted-printable
+*							"7bit", "quoted-printable" or "base64" (all without quotes).
+*							7bit is EXPRESSLY NOT RECOMMENDED. Default is quoted-printable
 * $params['text_encoding'] - The type of encoding to use on plain text Valid options are
-*                            "7bit", "quoted-printable" or "base64" (all without quotes).
-*                            Default is 7bit
-* $params['text_wrap']     - The character count at which to wrap 7bit encoded data.
-*                            Default this is 998.
+*							"7bit", "quoted-printable" or "base64" (all without quotes).
+*							Default is 7bit
+* $params['text_wrap']	 - The character count at which to wrap 7bit encoded data.
+*							Default this is 998.
 * $params['html_charset']  - The character set to use for a html section.
-*                            Default is ISO-8859-1
+*							Default is ISO-8859-1
 * $params['text_charset']  - The character set to use for a text section.
-*                          - Default is ISO-8859-1
+*						  - Default is ISO-8859-1
 * $params['head_charset']  - The character set to use for header encoding should it be needed.
-*                          - Default is ISO-8859-1
+*						  - Default is ISO-8859-1
 */
 	function buildMessage($params = array())
 	{
@@ -523,11 +540,11 @@ class htmlMimeMail
 			}
 		}
 
-		$null        = null;
+		$null		= null;
 		$attachments = !empty($this->attachments) ? true : false;
 		$html_images = !empty($this->html_images) ? true : false;
-		$html        = !empty($this->html)        ? true : false;
-		$text        = isset($this->text)         ? true : false;
+		$html		= !empty($this->html)		? true : false;
+		$text		= isset($this->text)		 ? true : false;
 
 		switch (true) {
 			case $text AND !$attachments:
@@ -617,7 +634,7 @@ class htmlMimeMail
 
 			// Add message ID header
 			srand((double)microtime()*10000000);
-			$message_id = sprintf('<%s.%s@%s>', base_convert(time(), 10, 36), base_convert(rand(), 10, 36), !empty($GLOBALS['HTTP_SERVER_VARS']['HTTP_HOST']) ? $GLOBALS['HTTP_SERVER_VARS']['HTTP_HOST'] : $GLOBALS['HTTP_SERVER_VARS']['SERVER_NAME']);
+			$message_id = sprintf('<%s.%s@%s>', base_convert(time(), 10, 36), base_convert(rand(), 10, 36), !empty($_SERVER['HTTP_HOST']) ? $_SERVER['HTTP_HOST'] : $_SERVER['SERVER_NAME']);
 			$this->headers['Message-ID'] = $message_id;
 
 			$this->is_built = true;
@@ -633,12 +650,12 @@ class htmlMimeMail
 */
 	function _encodeHeader($input, $charset = 'ISO-8859-1')
 	{
-		preg_match_all('/(\w*[\x80-\xFF]+\w*)/', $input, $matches);
+        preg_match_all('/(\s?\w*[\x80-\xFF]+\w*\s?)/', $input, $matches);
 		foreach ($matches[1] as $value) {
-			$replacement = preg_replace('/([\x80-\xFF])/e', '"=" . strtoupper(dechex(ord("\1")))', $value);
+            $replacement = preg_replace('/([\x20\x80-\xFF])/e', '"=" . strtoupper(dechex(ord("\1")))', $value);
 			$input = str_replace($value, '=?' . $charset . '?Q?' . $replacement . '?=', $input);
 		}
-		
+
 		return $input;
 	}
 
@@ -679,12 +696,12 @@ class htmlMimeMail
 				} else {
 					$result = mail($to, $subject, $this->output, implode(CRLF, $headers));
 				}
-				
+
 				// Reset the subject in case mail is resent
 				if ($subject !== '') {
 					$this->headers['Subject'] = $subject;
 				}
-				
+
 				// Return
 				return $result;
 				break;
@@ -693,7 +710,7 @@ class htmlMimeMail
 				require_once(dirname(__FILE__) . '/smtp.php');
 				require_once(dirname(__FILE__) . '/RFC822.php');
 				$smtp = &smtp::connect($this->smtp_params);
-				
+
 				// Parse recipients argument for internet addresses
 				foreach ($recipients as $recipient) {
 					$addresses = Mail_RFC822::parseAddressList($recipient, $this->smtp_params['helo'], null, false);
@@ -720,11 +737,11 @@ class htmlMimeMail
 				}
 				// Add To header based on $recipients argument
 				$headers[] = 'To: ' . $this->_encodeHeader(implode(', ', $recipients), $this->build_params['head_charset']);
-				
+
 				// Add headers to send_params
-				$send_params['headers']    = $headers;
+				$send_params['headers']	= $headers;
 				$send_params['recipients'] = array_values(array_unique($smtp_recipients));
-				$send_params['body']       = $this->output;
+				$send_params['body']	   = $this->output;
 
 				// Setup return path
 				if (isset($this->return_path)) {
@@ -739,6 +756,12 @@ class htmlMimeMail
 				// Send it
 				if (!$smtp->send($send_params)) {
 					$this->errors = $smtp->errors;
+					if(isDebugging()) {
+						echo gallery_error(gTranslate('core', "Sending mail via smtp method failed with these errors:") .
+							 '<br>' .
+							 nl2br(implode('<br>', $smtp->errors))
+						);
+					}
 					return false;
 				}
 				return true;
