@@ -1,27 +1,33 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: User.php,v 1.29.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: User.php 193 2008-07-15 22:02:33Z jens $
+*/
+
+/**
+ * Abstract class for the user object.
+ * Methodes might be overwritten by special classes.
+ *
+ * @package User
  */
-?>
-<?php
 class Abstract_User {
+
 	var $username;
 	var $fullname;
 	var $password;
@@ -40,20 +46,26 @@ class Abstract_User {
 	function integrityCheck() {
 		return 0;
 	}
+
 	function versionOutOfDate() {
 		return false;
 	}
 
-	function salt($len = 4)
-	{
+	function salt($len = 4) {
 		$salt = '';
-		for($i = 0; $i < $len; $i++)
-		{
+		for($i = 0; $i < $len; $i++) {
 			$char = mt_rand(48, 109);
-			if($char > 57) $char += 7;
-			if($char > 90) $char += 6;
+			if($char > 57) {
+				$char += 7;
+			}
+
+			if($char > 90) {
+				$char += 6;
+			}
+
 			$salt .= chr($char);
 		}
+
 		return $salt;
 	}
 
@@ -64,6 +76,7 @@ class Abstract_User {
 
 	function isCorrectPassword($password) {
 		$hash = '';
+
 		if(strlen($this->password) == 32) { // old password schema
 			$hash =  md5($password);
 		}
@@ -71,6 +84,7 @@ class Abstract_User {
 			$salt = substr($this->password,0, 4);
 			$hash = $salt.md5($salt.$password);
 		}
+
 		return (!strcmp($this->password, $hash));
 	}
 
@@ -79,26 +93,44 @@ class Abstract_User {
 	}
 
 	function setUsername($username) {
-		$this->username = $username;
+		$this->username = strip_tags($username);
 	}
 
 	function getUsername() {
-	       	return $this->username;
-       	}
+		return $this->username;
+	}
 
-       	function printableName($format) {
-		$name=$format;
-		$name=str_replace('!!FULLNAME!!', $this->getFullName(), $name);
-		$name=str_replace('!!USERNAME!!', $this->getUsername(), $name);
-		$name=str_replace('!!EMAIL!!',$this->getEmail(), $name);
-		$name=str_replace('!!MAILTO_FULLNAME!!', '<a href="mailto:'.
-				$this->getEmail().'">'.
-				$this->getFullName() ? $this->getFullName() : $this->getUserName() .
-			       	'</a>', $name);
-	       	$name=str_replace('!!MAILTO_USERNAME!!', '<a href="mailto:'.
-				$this->getEmail().'">'.$this->getUserName() .
-			       	'</a>', $name);
-	       	return $name;
+	function printableName($format = '!!FULLNAME!! (!!USERNAME!!)') {
+		if (empty($this)) {
+			$name = '>Unknown User<';
+		}
+		else {
+			$name = $format;
+
+			$fullname = $this->displayName();
+			$username = $this->getUsername();
+			$email = $this->getEmail();
+
+			$name = str_replace('!!FULLNAME!!', $fullname, $name);
+			$name = str_replace('!!USERNAME!!', $username, $name);
+
+			if (!empty($email)) {
+				$name = str_replace('!!EMAIL!!', $email, $name);
+				$name = str_replace('!!MAILTO_FULLNAME!!', "<a href=\"mailto:$email\">$fullname</a>", $name);
+				$name = str_replace('!!MAILTO_USERNAME!!', "<a href=\"mailto:$email\">$username</a>", $name);
+			}
+			else {
+				$name = str_replace('!!EMAIL!!', '', $name);
+				$name = str_replace('!!MAILTO_FULLNAME!!', $fullname , $name);
+				$name = str_replace('!!MAILTO_USERNAME!!', $fullname , $name);
+			}
+		}
+
+		if(empty($name)) {
+			$name = $this->username;
+		}
+
+		return $name;
 	}
 
 	function setEmail($email) {
@@ -110,15 +142,16 @@ class Abstract_User {
 	}
 
 	function setFullName($fullname) {
-		$this->fullname = $fullname;
+		$this->fullname = strip_tags($fullname);
 	}
 
 	function getFullName() {
-	       	if (get_magic_quotes_gpc()) {
-		       	return stripslashes($this->fullname);
-	       	} else {
-		       	return $this->fullname;
-	       	}
+		if (get_magic_quotes_gpc()) {
+			return stripslashes($this->fullname);
+		}
+		else {
+			return $this->fullname;
+		}
 	}
 
 	function isAdmin() {
@@ -138,8 +171,13 @@ class Abstract_User {
 	}
 
 	function canChangeOwnPw() {
-	       	return $this->canChangeOwnPw;
-       	}
+		if ($this->isAdmin()) {
+			return true;
+		}
+		else {
+			return $this->canChangeOwnPw;
+		}
+	}
 
 	function canReadAlbum($album) {
 		if ($this->isAdmin()) {
@@ -153,16 +191,33 @@ class Abstract_User {
 		return false;
 	}
 
+	/**
+	 * Can a user write to an album? Aka can he/she modify it.
+	 *
+	 * @param object $album
+	 * @return boolean
+	 */
 	function canWriteToAlbum($album) {
 		if ($this->isAdmin()) {
-			return true;
+			$ret = true;
+		}
+		elseif ($album->canWrite($this->uid)) {
+			$ret =  true;
+		}
+		else {
+			$ret =  false;
 		}
 
-		if ($album->canWrite($this->uid)) {
-			return true;
+		if (isDebugging(2)) {
+			if ($ret) {
+				debugMessage(sprintf(gTranslate('core',"User %s can write to album '%s'"), $this->getUsername(), $album->fields['name']), __FILE__, __LINE__);
+			}
+			else {
+				debugMessage(sprintf(gTranslate('core',"User %s can NOT write to album '%s'"), $this->getUsername(), $album->fields['name']), __FILE__, __LINE__);
+			}
 		}
 
-		return false;
+		return $ret;
 	}
 
 	function canAddToAlbum($album) {
@@ -170,8 +225,7 @@ class Abstract_User {
 			return true;
 		}
 
-		if (!$album)
-		{
+		if (!$album) {
 			return false;
 		}
 
@@ -185,7 +239,7 @@ class Abstract_User {
 		}
 
 		return false;
-	}		
+	}
 
 	function canDeleteFromAlbum($album) {
 		if ($this->isAdmin()) {
@@ -197,7 +251,7 @@ class Abstract_User {
 		}
 
 		return false;
-	}		
+	}
 
 	function canDeleteAlbum($album) {
 		if ($this->isAdmin()) {
@@ -222,7 +276,7 @@ class Abstract_User {
 
 		return false;
 	}
-	
+
 	function canCreateAlbums() {
 		if ($this->isAdmin()) {
 			return true;
@@ -248,6 +302,10 @@ class Abstract_User {
 			return true;
 		}
 
+		if ($album->isOwner($this->uid)) {
+			return true;
+		}
+
 		return false;
 	}
 
@@ -263,37 +321,43 @@ class Abstract_User {
 		return false;
 	}
 
-        function canAddComments($album) {
-                if ($this->isAdmin()) {
-                        return true;
-                }
+	function canAddComments($album) {
+		global $gallery;
 
-                if ($album->canAddComments($this->uid)) {
-                        return true;
-                }
+		if($gallery->app->comments_enabled == 'no') {
+			return false;
+		}
 
-                return false;
-        }
+		if ($this->isAdmin()) {
+			return true;
+		}
 
-        function canViewComments($album) {
-                if ($this->isAdmin()) {
-                        return true;
-                }
+		if ($album->canAddComments($this->uid)) {
+			return true;
+		}
 
-		/* Note Jens Tkotz, 23.09.2004
-		** Allow album owner to see comments, as they are a kind of local admin
-		*/
+		return false;
+	}
+
+	function canViewComments($album) {
+		if ($this->isAdmin()) {
+			return true;
+		}
+
+		/** Note Jens Tkotz, 23.09.2004
+		 * Allow album owner to see comments, as they are a kind of local admin
+		 */
 		if ($this->isOwnerOfAlbum($album)) {
 			return true;
 		}
 
-                if ($album->canViewComments($this->uid)) {
-                        return true;
-                }
+		if ($album->canViewComments($this->uid)) {
+			return true;
+		}
+
+		return false;
+	}
 
-                return false;
-        }
-	
 	function isOwnerOfAlbum($album) {
 		if ($album->isOwner($this->uid)) {
 			return true;
@@ -307,7 +371,7 @@ class Abstract_User {
 	}
 
 	function getDefaultLanguage() {
-		return "";
+		return '';
 	}
 
 	function setDefaultLanguage($var) {
@@ -315,13 +379,37 @@ class Abstract_User {
 
 	function displayName() {
 		$FullName = $this->getFullName();
-	        if (! empty($FullName)) {
+
+		if (! empty($FullName)) {
 			return $this->getFullname();
-		} else {
+		}
+		else {
 			return $this->getUsername();
-	        }
+		}
 	}
 
+	function canDownloadAlbum($album) {
+		if ($this->hasAlbumPermission('zipDownload', $album) && canCreateArchive('zip')) {
+			return true;
+		}
+		else {
+			return false;
+		}
+	}
+
+	function hasAlbumPermission($perm, $album) {
+		/* Note: owners do not have explict every Permission via this method. Just admin. */
+		if ($this->isAdmin()) {
+			return true;
+		}
+
+		if ($album->getPerm($perm, $this->uid)) {
+			return true;
+		}
+		else {
+			return false;
+		}
+	}
 }
 
 ?>
