@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,10 +17,13 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: UserDB.php,v 1.3.2.1 2005/09/12 22:40:45 dmolavi Exp $
+ * $Id: UserDB.php 193 2008-07-15 22:02:33Z jens $
  */
-?>
-<?php
+
+if (! class_exists('Abstract_UserDB')) {
+	exit;
+}
+
 class CPGNuke_UserDB extends Abstract_UserDB {
 	var $db;
 	var $fields;
@@ -40,8 +43,8 @@ class CPGNuke_UserDB extends Abstract_UserDB {
 		$db = $this->db;
 
 		$sql= 'select ' . $this->fields{'uid'} . 
-		      ' from ' . $this->prefix. 'users' .
-		      ' where '. $this->fields{'uid'} .'>1';
+			  ' from ' . $this->prefix. 'users' .
+			  ' where '. $this->fields{'uid'} .'>1';
 
 		$results = $db->query($sql);
 
