@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,18 +16,24 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
+ *
+ * $Id: User.php 193 2008-07-15 22:02:33Z jens $
  */
 
-/* This class is written for phpBB2 and provides full integration of the phpbb users database
-** Instead of using or duplicating memberships manually in Gallery.
-**
-** Gallery <-> phpBB2 integration ver. (www.snailsource.com)
-** Written by Martin Smallridge       <info@snailsource.com>
-**
-** This file was modified for official integration into Gallery 1.4.3 by
-** Jens Tkotz
+/** This class is written for phpBB2 and provides full integration of the phpbb users database
+ * Instead of using or duplicating memberships manually in Gallery.
+ *
+ * Gallery <-> phpBB2 integration ver. (www.snailsource.com)
+ * Written by Martin Smallridge	   <info@snailsource.com>
+ *
+ * This file was modified for official integration into Gallery 1.4.3 by
+ * Jens Tkotz
 */
 
+if (! class_exists('Abstract_User')) {
+	exit;
+}
+
 class phpbb_User extends Abstract_User {
 	var $db;
 
