@@ -1,7 +1,7 @@
 <?php
 /*
 * Gallery - a web based photo album viewer and editor
-* Copyright (C) 2000-2005 Bharat Mediratta
+* Copyright (C) 2000-2008 Bharat Mediratta
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -17,10 +17,13 @@
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
-* $Id: User.php,v 1.8.2.2 2005/09/12 22:40:45 dmolavi Exp $
+* $Id: User.php 193 2008-07-15 22:02:33Z jens $
 */
-?>
-<?php
+
+if (! class_exists('Abstract_User')) {
+	exit;
+}
+
 class PostNuke_User extends Abstract_User {
 	function loadByUid($uid) {
 		/*
@@ -59,7 +62,9 @@ class PostNuke_User extends Abstract_User {
 	}
 
 	function loadByUserName($uname) {
-		if (substr(_PN_VERSION_NUM, 0, 7) < "0.7.5.0") {
+		global $GALLERY_POSTNUKE_VERSION;
+
+		if (substr($GALLERY_POSTNUKE_VERSION, 0, 7) < "0.7.5.0") {
 			list($dbconn) = pnDBGetConn();
 			$pntable = pnDBGetTables();
 		} else {
