@@ -1,26 +1,29 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: UserDB.php,v 1.6.2.2 2005/09/12 22:40:45 dmolavi Exp $
+ * $Id: UserDB.php 193 2008-07-15 22:02:33Z jens $
  */
-?>
-<?php
+
+if (! class_exists('Abstract_UserDB')) {
+	exit;
+}
+
 class PostNuke_UserDB extends Abstract_UserDB {
 	var $db;
 	var $prefix;
@@ -32,30 +35,31 @@ class PostNuke_UserDB extends Abstract_UserDB {
 	}
 
 	function getUidList() {
+		global $GALLERY_POSTNUKE_VERSION;
 		$uidList = array();
 
-		if (substr(_PN_VERSION_NUM, 0, 7) < "0.7.5.0") {
+		if (substr($GALLERY_POSTNUKE_VERSION, 0, 7) < "0.7.5.0") {
 			list($dbconn) = pnDBGetConn();
 			$pntable = pnDBGetTables();
 		} else {
 			$dbconn =& pnDBGetConn(true);
 			$pntable =& pnDBGetTables();
 		}
-		
+
 		$userstable = $pntable['users'];
 		$userscolumn = &$pntable['users_column'];
-		
+
 		$sql = "SELECT $userscolumn[uid] FROM $userstable";
 		$result = $dbconn->Execute($sql);
 
 		while(!$result->EOF) {
-		    list($uid) = $result->fields;
-		    $uidList[] = $uid;
-		    $result->MoveNext();
+			list($uid) = $result->fields;
+			$uidList[] = $uid;
+			$result->MoveNext();
 		}
 
 		$result->Close();
-		
+
 		array_push($uidList, $this->nobody->getUid());
 		array_push($uidList, $this->everybody->getUid());
 		array_push($uidList, $this->loggedIn->getUid());
