@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,35 +17,15 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: GalleryRemoteProperties.php,v 1.7.2.1 2005/09/12 22:40:46 dmolavi Exp $
+ * $Id: GalleryRemoteProperties.php 193 2008-07-15 22:02:33Z jens $
  */
-?>
-<?php
-
-/*
- * workaround for php < 4.1.0
- */
-if (!function_exists ('array_key_exists')) {
-	function array_key_exists($key, $arr)
-	{
-		if (!is_array($arr)) {
-			return false;
-		}
-		foreach (array_keys($arr) as $k) {
-			if ($k == $key) {
-				return true;
-			}
-		}
-		return false;
-	}
-}
 
 /**
  *  This class partially mirrors the functionality of the java class
  *	java.util.Properties.
  *
- *@author     tmiller
- *@created    September 29, 2002
+ *@author	 tmiller
+ *@created	September 29, 2002
  */
 class Properties {
 	var $map;
