@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  * Gallery Component for Mambo Open Source CMS v4.5 or newer
  * Original author: Beckett Madden-Woods <beckett@beckettmw.com>
  *
- * $Id: admin.gallery.php,v 1.3.2.1 2005/09/12 22:40:46 dmolavi Exp $
+ * $Id: admin.gallery.php 193 2008-07-15 22:02:33Z jens $
  */
 
 defined( '_VALID_MOS' ) or die( 'Direct Access to this location is not allowed.' );
@@ -43,6 +43,7 @@ switch ($task) {
 	case "save":
 		saveSettings($option, $act);
 	break;
+
 	default:
 		viewSettings($option, $act);
 	break;
@@ -57,7 +58,7 @@ function viewSettings( $option, $act ) {
 	$cid = mosGetParam($_REQUEST, 'cid', array(0));
 	$uid = intval($cid[0]);
 	$row->load($uid);
-	
+
 	$database->setQuery("SELECT * FROM #__gallery");
 	$param = $database->loadRowList();
 
@@ -93,8 +94,9 @@ function viewSettings( $option, $act ) {
 	}
 
 	$params['minAuthType'] = mosHTML::selectList($gtree, 'minAuthType', 'size="6"', 'value', 'text', isset($params['minAuthType']) ? $params['minAuthType'] : 20);
+	$params['minAuthAlbums'] = mosHTML::selectList($gtree, 'minAuthAlbums', 'size="6"', 'value', 'text', isset($params['minAuthAlbums']) ? $params['minAuthAlbums'] : 21);
 	$params['hideRightSide'] = mosHTML::yesnoSelectList('hideRightSide', 'class="inputbox" size="1"', isset($params['hideRightSide']) ? $params['hideRightSide'] : 1);
-	
+
 	HTML_content::showSettings($option, $params, $act);
 }
 
@@ -111,8 +113,9 @@ function saveSettings( $option, $act ) {
 		$path .= addslashes(DIRECTORY_SEPARATOR);
 	}
 	$params['path'] = $path;
-	
+
 	$params['minAuthType'] = mosGetParam($_POST, 'minAuthType', 20);
+	$params['minAuthAlbums'] = mosGetParam($_POST, 'minAuthAlbums', 21);
 	$params['hideRightSide'] = mosGetParam($_POST, 'hideRightSide', true);
 
 	foreach ($params as $field => $value) {
