@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,9 +20,13 @@
  * Gallery Component for Mambo Open Source CMS v4.5 or newer
  * Original author: Beckett Madden-Woods <beckett@beckettmw.com>
  *
- * $Id: toolbar.gallery.php,v 1.2.2.1 2005/09/12 22:40:46 dmolavi Exp $
+ * $Id: toolbar.gallery.php 193 2008-07-15 22:02:33Z jens $
  */
 
+if(! isset($mainframe) || ! is_object($mainframe)) {
+	exit;	
+}
+
 require_once($mainframe->getPath('toolbar_default'));
 
 mosMenuBar::startTable();
