@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,10 +17,8 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: create_user.php,v 1.53.2.2 2005/09/13 09:20:18 jenst Exp $
+ * $Id: create_user.php 193 2008-07-15 22:02:33Z jens $
  */
-?>
-<?php
 
 require_once(dirname(__FILE__) . '/init.php');
 
@@ -31,11 +29,12 @@ list($formaction, $canCreate, $canChangeOwnPw, $isAdmin, $send_email, $dismiss)
     getRequestVar(array('formaction', 'canCreate', 'canChangeOwnPw', 'isAdmin', 'send_email', 'dismiss'));
 
 if (!$gallery->user->isAdmin()) {
-	echo _("You are not allowed to perform this action!");
+	echo gTranslate('core', "You are not allowed to perform this action!");
 	exit;	
 }
 
 $errorCount = 0;
+
 if (!empty($formaction) && $formaction == 'create') {
 	$gErrors["uname"] = $gallery->userDB->validNewUserName($uname);
 	if ($gErrors["uname"]) {
@@ -43,7 +42,7 @@ if (!empty($formaction) && $formaction == 'create') {
 	}
 
 	if (strcmp($new_password1, $new_password2)) {
-		$gErrors["new_password2"] = _("Passwords do not match!");
+		$gErrors["new_password2"] = gTranslate('core', "Passwords do not match!");
 		$errorCount++;
 	} else {
 		$gErrors["new_password1"] = 
@@ -54,17 +53,8 @@ if (!empty($formaction) && $formaction == 'create') {
 	}
 
 	if (!$errorCount) {
-		doctype();
-?>
-<html>
-<head>
-  <title><?php echo _("Create User") ?></title>
-  <?php common_header(); ?>
-</head>
-<body dir="<?php echo $gallery->direction ?>">
-	<div class="popup" align="center">
-		<div class="popuphead"><?php echo _("Create User") ?></div>
-	<?php
+		printPopupStart(gTranslate('core', "Create User"), '', 'left');
+
 		$tmpUser = new Gallery_User();
 		$tmpUser->setUsername($uname);
 		$tmpUser->setPassword($new_password1);
@@ -79,7 +69,10 @@ if (!empty($formaction) && $formaction == 'create') {
 		$tmpUser->log("register");
 		$tmpUser->save();
 
-		echo infoLine(sprintf(_("User %s created"), $uname), 'success');
+		echo infoBox(array(array(
+		  'type' => 'success',
+		  'text' => sprintf(gTranslate('core', "User %s created"), $uname)))
+		);
 
 		if (!empty($send_email)) {
 			$values = array('password' => $new_password1, 
@@ -91,7 +84,7 @@ if (!empty($formaction) && $formaction == 'create') {
 
 			echo "\n<p><pre>". wordwrap($msg,80) ."\n</pre></p>";
 
-		       	$logmsg = sprintf(_("New user '%s' has been registered by %s.  Gallery has sent a notification email to %s."),
+			$logmsg = sprintf(gTranslate('core', "New user '%s' has been registered by %s.  Gallery has sent a notification email to %s."),
 				       	$uname, $gallery->user->getUsername(), $email);
 		       	$logmsg2  = sprintf("New user '%s' has been registered by %s.  Gallery has sent a notification email to %s.",
 				       	$uname, $gallery->user->getUsername(), $email);
@@ -99,18 +92,20 @@ if (!empty($formaction) && $formaction == 'create') {
 			       	$logmsg .= " <<<<>>>>> $logmsg2";
 		       	}
 
-			if (gallery_mail($email, _("Gallery Registration"),$msg, $logmsg)) {
+			if (gallery_mail($email, gTranslate('core', "Gallery Registration"),$msg, $logmsg)) {
 			       	clearstatcache();
 			       	$tmpUser->save();
-			       	print sprintf(_("Email sent to %s."), $email);
+				
+				print sprintf(gTranslate('core', "Email sent to %s."), $email);
 			       	print "<br><br>";
 		       	}
 	       	} 
+
+	echo "\n<br><br>";
+	echo makeFormIntro('create_user.php', array(), array('type' => 'popup'));
+	echo gSubmit('moreuser', gTranslate('core', "Create another user"));
+	echo gSubmit('dismiss', gTranslate('core', "Back to usermanagement"));
 	?>
-	<br><br>
-	<form>
-		<input type="submit" name="moreuser" value="<?php echo _("Create another user") ?>">
-		<input type="submit" name="dismiss" value="<?php echo _("Back to usermanagement") ?>">
 	</form>
 	</div>
 </body>
@@ -119,41 +114,29 @@ if (!empty($formaction) && $formaction == 'create') {
 		exit;
        	}
 } else if (!empty($formaction) || isset($dismiss)) {
-	header("Location: " . makeGalleryHeaderUrl("manage_users.php"));
+	header("Location: " . makeGalleryHeaderUrl('manage_users.php', array('type' => 'popup')));
 }
-doctype();
-?>
-<html>
-<head>
-  <title><?php echo _("Create User") ?></title>
-  <?php common_header(); ?>
-</head>
-<body dir="<?php echo $gallery->direction ?>" class="popupbody">
-<div class="popuphead"><?php echo _("Create User") ?></div>
-<div class="popup" align="center">
-<?php
+printPopupStart(gTranslate('core', "Create User"), '', 'left');
+
 $canCreate = 0;
 
-$allowChange["uname"] = true;
-$allowChange["email"] = true;
-$allowChange["password"] = true;
-$allowChange["old_password"] = false;
-$allowChange["fullname"] = true;
-$allowChange["send_email"] = true;
-$allowChange["create_albums"] = true;
-$allowChange["canChangeOwnPw"] = true;
+$allowChange["uname"]		= true;
+$allowChange["email"]		= true;
+$allowChange["password"]	= true;
+$allowChange["old_password"]	= false;
+$allowChange["fullname"]	= true;
+$allowChange["send_email"]	= true;
+$allowChange["create_albums"]	= true;
+$allowChange["canChangeOwnPw"]	= true;
 $allowChange["default_language"] = true;
-$allowChange["member_file"] = false;
-$allowChange["admin"] = true;
+$allowChange["member_file"]	= false;
+$allowChange["admin"]		= true;
 
-echo _("Create a new user here.");
-?>
-<br>
+echo "\n<center>". gTranslate('core', "Create a new user here.") .'</center>';
 
-<?php echo makeFormIntro("create_user.php", array(
-				"name" => "usercreate_form", 
-				"method" => "POST",
-				'onsubmit' => 'usercreate_form.create.disabled = true;'));
+echo makeFormIntro('create_user.php',
+	array('name' => 'usercreate_form', 'onSubmit' => 'usercreate_form.create.disabled = true;'),
+	array('type' => 'popup'));
 ?>
 <br>
 
@@ -161,9 +144,11 @@ echo _("Create a new user here.");
 
 <br>
 
+  <div style="text-align: center">
 <input type="hidden" name="formaction" value="">
-<input type="submit" name="create" value="<?php echo _("Create user") ?>" onclick="usercreate_form.formaction.value='create'">
-<input type="submit" name="cancel" value="<?php echo _("Back to usermanagement") ?>" onclick="usercreate_form.formaction.value='cancel'">
+	<input type="submit" name="create" value="<?php echo gTranslate('core', "Create user") ?>" onclick="usercreate_form.formaction.value='create'" class="g-button">
+	<input type="submit" name="cancel" value="<?php echo gTranslate('core', "Back to usermanagement") ?>" onclick="usercreate_form.formaction.value='cancel'" class="g-button">
+  </div>
 </form>
 </div>
 
