@@ -1,26 +1,24 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: gallery_remote2.php,v 1.75.2.2 2005/09/12 22:40:44 dmolavi Exp $
- */
-?>
-<?php
+ * $Id: gallery_remote2.php 193 2008-07-15 22:02:33Z jens $
+*/
 
 require_once(dirname(__FILE__) . '/init.php');
 require(dirname(__FILE__) . '/classes/remote/GalleryRemoteProperties.php');
@@ -36,49 +34,48 @@ if (!getRequestVar('cmd')) {
 }
 
 /*
- * Set content type
- */
+* Set content type
+*/
 header("Content-type: text/plain");
 
 /*
- * Start buffering output
- */
+* Start buffering output
+*/
 //if(!isDebugging()) {
 //	@ob_start();
 //}
 
 /*
- * Gallery remote protocol version 2.10
- */
+* Gallery remote protocol version 2.10
+*/
 $GR_VER['MAJ'] = 2;
 $GR_VER['MIN'] = 15;
 
-
 /*
- * Protocol result codes
- */
+* Protocol result codes
+*/
 
-$GR_STAT['SUCCESS']             = 0;
+$GR_STAT['SUCCESS']			 	= 0;
 
 $GR_STAT['PROTOCOL_MAJOR_VERSION_INVALID'] 	= 101;
 $GR_STAT['PROTOCOL_MINOR_VERSION_INVALID'] 	= 102;
-$GR_STAT['PROTOCOL_VERSION_FORMAT_INVALID'] = 103;
+$GR_STAT['PROTOCOL_VERSION_FORMAT_INVALID']	= 103;
 $GR_STAT['PROTOCOL_VERSION_MISSING']   		= 104;
 
-$GR_STAT['PASSWORD_WRONG']      = 201;
-$GR_STAT['LOGIN_MISSING']       = 202;
+$GR_STAT['PASSWORD_WRONG']			= 201;
+$GR_STAT['LOGIN_MISSING']			= 202;
 
-$GR_STAT['UNKNOWN_COMMAND']		= 301;
+$GR_STAT['UNKNOWN_COMMAND']			= 301;
 
-$GR_STAT['NO_ADD_PERMISSION']	= 401;
-$GR_STAT['NO_FILENAME']			= 402;
-$GR_STAT['UPLOAD_PHOTO_FAIL']	= 403;
-$GR_STAT['NO_WRITE_PERMISSION']	= 404;
+$GR_STAT['NO_ADD_PERMISSION']			= 401;
+$GR_STAT['NO_FILENAME']				= 402;
+$GR_STAT['UPLOAD_PHOTO_FAIL']			= 403;
+$GR_STAT['NO_WRITE_PERMISSION']			= 404;
 
-$GR_STAT['NO_CREATE_ALBUM_PERMISSION']	= 501;
+$GR_STAT['NO_CREATE_ALBUM_PERMISSION']		= 501;
 $GR_STAT['CREATE_ALBUM_FAILED']			= 502;
-$GR_STAT['MOVE_ALBUM_FAILED']	= 503;
-$GR_STAT['ROTATE_IMAGE_FAILED'] = 504;
+$GR_STAT['MOVE_ALBUM_FAILED']			= 503;
+$GR_STAT['ROTATE_IMAGE_FAILED']			= 504;
 
 
 $response = new Properties();
@@ -94,7 +91,8 @@ if ($gallery->user) {
 	$response->setProperty( "debug_user", $gallery->user->getUsername());
 	$response->setProperty( "debug_user_type", get_class($gallery->user));
 	$response->setProperty( "debug_user_already_logged_in", $gallery->user->isLoggedIn());
-} else {
+}
+else {
 	$response->setProperty( "debug_user", "NO_USER");
 }
 
@@ -104,29 +102,49 @@ switch(getRequestVar('cmd') === 0 ? '' : getRequestVar('cmd')) {
 	case 'login':
 		gr_login( $gallery, $response, getRequestVar('uname'), getRequestVar('password') );
 		break;
+
 	case 'fetch-albums':
 		gr_fetch_albums( $gallery, $response );
 		break;
+
 	case 'fetch-albums-prune':
 		gr_fetch_albums_prune( $gallery, $response, getRequestVar('check_writeable') );
 		break;
+
 	case 'add-item':
-		gr_add_item( $gallery, $response, $_FILES['userfile']['tmp_name'], $_FILES['userfile']['name'],
-getRequestVar('caption'), getRequestVar('force_filename'), getRequestVar('auto_rotate') );
+		gr_add_item(
+			$gallery,
+			$response,
+			$_FILES['userfile']['tmp_name'],
+			$_FILES['userfile']['name'],
+			getRequestVar('caption'),
+			getRequestVar('force_filename'),
+			getRequestVar('auto_rotate')
+		);
 		break;
+
 	case 'album-properties':
 		gr_album_properties( $gallery, $response );
 		break;
+
 	case 'new-album':
-		gr_new_album( $gallery, $response, getRequestVar('newAlbumName'), getRequestVar('newAlbumTitle'),
-getRequestVar('newAlbumDesc') );
+		gr_new_album(
+			$gallery,
+			$response,
+			getRequestVar('newAlbumName'),
+			getRequestVar('newAlbumTitle'),
+			getRequestVar('newAlbumDesc')
+		);
 		break;
+
 	case 'fetch-album-images':
 		gr_fetch_album_images( $gallery, $response, getRequestVar('albums_too') );
 		break;
+
 	case 'move-album':
 		gr_move_album( $gallery, $response, getRequestVar('set_destalbumName') );
 		break;
+
 	default:
 		$response->setProperty( 'status', $GR_STAT['UNKNOWN_COMMAND'] );
 		$response->setProperty( 'status_text', "Command '" . getRequestVar('cmd') . "' unknown." );
@@ -137,8 +155,6 @@ getRequestVar('newAlbumDesc') );
 echo $response->listprops();
 //end of processing
 
-
-
 function gr_login( &$gallery, &$response, $uname, $password ) {
 	global $GR_STAT, $GR_VER;
 
@@ -161,7 +177,7 @@ function gr_login( &$gallery, &$response, $uname, $password ) {
 	if ($tmpUser && $tmpUser->isCorrectPassword($password)) {
 		// log user in
 		$gallery->session->username = $uname;
- 
+
 		$response->setProperty( 'debug_user', $tmpUser->getUsername());
 		$response->setProperty( 'debug_user_type', get_class($tmpUser));
 
@@ -169,7 +185,8 @@ function gr_login( &$gallery, &$response, $uname, $password ) {
 		$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
 		$response->setProperty( 'status_text', 'Login successful.' );
 		return 1;
-	} else {
+	}
+	else {
 		$response->setProperty( 'status', $GR_STAT['PASSWORD_WRONG'] );
 		$response->setProperty( 'status_text', 'Password incorrect.' );
 		return 0;
@@ -178,7 +195,6 @@ function gr_login( &$gallery, &$response, $uname, $password ) {
 }
 
 function gr_fetch_albums( &$gallery, &$response ) {
-
 	global $GR_STAT;
 
 	$albumDB = new AlbumDB(FALSE);
@@ -215,8 +231,9 @@ function gr_fetch_albums_prune( &$gallery, &$response, $check_writeable ) {
 	$album_count = 0;
 
 	if ($check_writeable != 'no') {
-	    mark_and_sweep($albumDB, TRUE);
-	} else {
+		mark_and_sweep($albumDB, TRUE);
+	}
+	else {
 		mark_and_sweep($albumDB, FALSE);
 	}
 
@@ -239,7 +256,6 @@ function gr_fetch_albums_prune( &$gallery, &$response, $check_writeable ) {
 }
 
 function gr_add_item( &$gallery, &$response, &$userfile, &$userfile_name, $caption, $force_filename, $auto_rotate ) {
-
 	global $GR_STAT, $temp_files;
 
 	if (!$gallery->user->canAddToAlbum($gallery->album)) {
@@ -251,7 +267,8 @@ function gr_add_item( &$gallery, &$response, &$userfile, &$userfile_name, $capti
 	if(!empty($auto_rotate)) {
 		if($auto_rotate == 'yes') {
 			$gallery->app->autorotate = 'yes';
-		} else {
+		}
+		else {
 			$gallery->app->autorotate = 'no';
 		}
 	}
@@ -262,19 +279,23 @@ function gr_add_item( &$gallery, &$response, &$userfile, &$userfile_name, $capti
 			$response->setProperty( 'status_text', 'Only administrators can fetch remote images.' );
 			return 0;
 		}
+
 		$acceptable = array_merge(acceptableMovieList(),acceptableImageList());
 		foreach($acceptable as $imagetype) {
 			if(strtolower(substr($userfile,strlen($imagetype) * -1)) == $imagetype) {
 				$userfile_name = substr(md5(microtime()),0,8).'.'.$imagetype;
 			}
 		}
+
 		if($tmpImage = fs_file_get_contents($userfile)) {
 			$userfile = tempnam($gallery->app->tmpDir,'img');
+
 			if(!$fhandle = fopen($userfile,'wb')) {
 				$response->setProperty( 'status', $GR_STAT['UPLOAD_PHOTO_FAIL'] );
 				$response->setProperty( 'status_text', 'Could not open tmp file to write remote image.' );
 				return 0;
 			}
+
 			if(!fwrite($fhandle,$tmpImage)) {
 				$response->setProperty( 'status', $GR_STAT['UPLOAD_PHOTO_FAIL'] );
 				$response->setProperty( 'status_text', 'Could not write to tmp file.' );
@@ -282,7 +303,8 @@ function gr_add_item( &$gallery, &$response, &$userfile, &$userfile_name, $capti
 				return 0;
 			}
 			fclose($fhandle);
-		} else {
+		}
+		else {
 			$response->setProperty( 'status', $GR_STAT['UPLOAD_PHOTO_FAIL'] );
 			$response->setProperty( 'status_text', 'Could not fetch image, HTTP wrapper may be disabled or invalid URL' );
 			return 0;
@@ -297,9 +319,11 @@ function gr_add_item( &$gallery, &$response, &$userfile, &$userfile_name, $capti
 
 	if(!empty($force_filename)) {
 		$name = $force_filename;
-	} else {
+	}
+	else {
 		$name = $userfile_name;
 	}
+
 	$tag = ereg_replace(".*\.([^\.]*)$", "\\1", $userfile_name);
 	$tag = strtolower($tag);
 
@@ -319,7 +343,8 @@ function gr_add_item( &$gallery, &$response, &$userfile, &$userfile_name, $capti
 		$response->setProperty( 'status', $GR_STAT['UPLOAD_PHOTO_FAIL'] );
 		$response->setProperty( 'status_text', 'Upload failed: \''.$error.'\'.' );
 		return 0;
-	} else {
+	}
+	else {
 		$gallery->album->save(array(i18n('Image added')));
 		$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
 		$response->setProperty( 'status_text', 'Add photo successful.' );
@@ -329,7 +354,6 @@ function gr_add_item( &$gallery, &$response, &$userfile, &$userfile_name, $capti
 }
 
 function gr_album_properties( &$gallery, &$response ) {
-
 	global $GR_STAT;
 
 	$resize_dimension = $gallery->album->fields['resize_size'];
@@ -356,12 +380,12 @@ function gr_album_properties( &$gallery, &$response ) {
 }
 
 function gr_new_album( &$gallery, &$response, $newAlbumName, $newAlbumTitle, $newAlbumDesc ) {
-
 	global $GR_STAT;
 
 	if(isset($gallery->album) && isset($gallery->album->fields["name"])) {
 		$canAddAlbum = $gallery->user->canCreateSubAlbum($gallery->album);
-	} else {
+	}
+	else {
 		$canAddAlbum = $gallery->user->canCreateAlbums();
 	}
 
@@ -371,14 +395,18 @@ function gr_new_album( &$gallery, &$response, $newAlbumName, $newAlbumTitle, $ne
 		return 0;
 	}
 
-	if ($returnVal = createNewAlbum( $gallery->session->albumName,
-		$newAlbumName, $newAlbumTitle, $newAlbumDesc )) {
+	if ($returnVal = createNewAlbum(
+		  $gallery->session->albumName,
+		  $newAlbumName,
+		  $newAlbumTitle, $newAlbumDesc))
+	{
 		// set status and message
 		$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
 		$response->setProperty( 'status_text', 'New album created successfully.' );
 		$response->setProperty( 'album_name', $returnVal );
 		return 1;
-	} else {
+	}
+	else {
 		// set status and message
 		$response->setProperty( 'status', $GR_STAT['CREATE_ALBUM_FAILED'] );
 		$response->setProperty( 'status_text', 'Create album failed.' );
@@ -388,17 +416,17 @@ function gr_new_album( &$gallery, &$response, $newAlbumName, $newAlbumTitle, $ne
 }
 
 function gr_fetch_album_images( &$gallery, &$response, $albums_too ) {
-
 	global $GR_STAT;
-	
+
 	if ($albums_too == 'yes') {
-	    $albums_too = TRUE;
-	} else {
+		$albums_too = TRUE;
+	}
+	else {
 		$albums_too = FALSE;
 	}
 
 	$tmpImageNum = 0;
-	
+
 	if (isset($gallery->album)) {
 		if (isset($gallery->album->photos)) {
 			foreach($gallery->album->photos as $albumItemObj) {
@@ -441,7 +469,8 @@ function gr_fetch_album_images( &$gallery, &$response, $albums_too ) {
 					$response->setProperty( 'image.capturedate.minutes.'.$tmpImageNum, $albumItemObj->itemCaptureDate['minutes'] );
 					$response->setProperty( 'image.capturedate.seconds.'.$tmpImageNum, $albumItemObj->itemCaptureDate['seconds'] );
 					$response->setProperty( 'image.hidden.'.$tmpImageNum, $albumItemObj->isHidden()? "yes":"no" );
-				} else {
+				}
+				else {
 					if ($albums_too) {
 						if (! isset($albumDB)) {
 							$albumDB = new AlbumDB(FALSE);
@@ -459,14 +488,15 @@ function gr_fetch_album_images( &$gallery, &$response, $albums_too ) {
 				}
 			}
 		}
-	} else {
+	}
+	else {
 		// we're in the root album: just list root albums
 		if ($albums_too) {
 			$albumDB = new AlbumDB(FALSE);
 			foreach ($albumDB->albumList as $myAlbum) {
 				if ($myAlbum->isRoot() && $gallery->user->canReadAlbum($myAlbum)) {
-				    $tmpImageNum++;
-		 
+					$tmpImageNum++;
+
 					$response->setProperty( 'album.name.'.$tmpImageNum, $myAlbum->fields['name'] );
 					// root albums can't be hidden
 					$response->setProperty( 'album.hidden.'.$tmpImageNum, 'no' );
@@ -474,10 +504,10 @@ function gr_fetch_album_images( &$gallery, &$response, $albums_too ) {
 			}
 		}
 	}
-	
+
 	$response->setProperty( 'image_count', $tmpImageNum );
 	if (isset($gallery->album)) {
-	    $response->setProperty( 'baseurl', $gallery->album->getAlbumDirURL('full').'/' );
+		$response->setProperty( 'baseurl', $gallery->album->getAlbumDirURL('full').'/' );
 	}
 
 	$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
@@ -487,7 +517,6 @@ function gr_fetch_album_images( &$gallery, &$response, $albums_too ) {
 }
 
 function gr_move_album( &$gallery, &$response, &$set_destalbumName ) {
-
 	global $GR_STAT;
 
 	// check that source and destination albums exist
@@ -515,6 +544,7 @@ function gr_move_album( &$gallery, &$response, &$set_destalbumName ) {
 		$response->setProperty( 'status_text', 'You must specify a destination album.' );
 		return 0;
 	}
+
 	if($set_destalbumName == $gallery->album->fields['name']) {
 		$response->setProperty( 'status', $GR_STAT['MOVE_ALBUM_FAILED'] );
 		$response->setProperty( 'status_text', 'Album and destination album cannot be the same.' );
@@ -527,11 +557,13 @@ function gr_move_album( &$gallery, &$response, &$set_destalbumName ) {
 			$response->setProperty( 'status_text', 'Album is already in specified destination album.' );
 			return 0;
 		}
+
 		if(checkIfNestedAlbum($gallery->album,$destAlbum)) {
 			$response->setProperty( 'status', $GR_STAT['MOVE_ALBUM_FAILED'] );
 			$response->setProperty( 'status_text', 'Cannot move album into a sub-album of itself.' );
 			return 0;
 		}
+
 		if($gallery->user->canWriteToAlbum($gallery->album) && $gallery->user->canWriteToAlbum($destAlbum)) {
 			$gallery->album->fields['parentAlbumName'] = $set_destalbumName;
 			$gallery->album->save();
@@ -540,7 +572,8 @@ function gr_move_album( &$gallery, &$response, &$set_destalbumName ) {
 			$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
 			$response->setProperty( 'status_text', 'Move album successful.' );
 			return 1;
-		} else {
+		}
+		else {
 			$response->setProperty( 'status', $GR_STAT['NO_WRITE_PERMISSION'] );
 			$response->setProperty( 'status_text', 'No write permission to album or destination.' );
 			return 0;
@@ -552,6 +585,7 @@ function gr_move_album( &$gallery, &$response, &$set_destalbumName ) {
 		$response->setProperty( 'status_text', 'Cannot move album into a sub-album of itself.' );
 		return 0;
 	}
+
 	if($gallery->album->fields['parentAlbumName'] == $set_destalbumName) {
 		$response->setProperty( 'status', $GR_STAT['MOVE_ALBUM_FAILED'] );
 		$response->setProperty( 'status_text', 'Album is already in specified destination album.' );
@@ -569,12 +603,14 @@ function gr_move_album( &$gallery, &$response, &$set_destalbumName ) {
 			$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
 			$response->setProperty( 'status_text', 'Move album successful.' );
 			return 1;
-		} else {
+		}
+		else {
 			$response->setProperty( 'status', $GR_STAT['NO_WRITE_PERMISSION'] );
 			$response->setProperty( 'status_text', 'No write permission to album or destination.' );
 			return 0;
 		}
-	} else {
+	}
+	else {
 		if($gallery->user->canWriteToAlbum($gallery->album) && $gallery->user->canWriteToAlbum($destAlbum)) {
 			$parentAlbum = new Album();
 			$parentAlbum->load($gallery->album->fields['parentAlbumName']);
@@ -587,7 +623,8 @@ function gr_move_album( &$gallery, &$response, &$set_destalbumName ) {
 			$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
 			$response->setProperty( 'status_text', 'Move album successful.' );
 			return 1;
-		} else {
+		}
+		else {
 			$response->setProperty( 'status', $GR_STAT['NO_WRITE_PERMISSION'] );
 			$response->setProperty( 'status_text', 'No write permission to album or destination.' );
 			return 0;
@@ -602,7 +639,6 @@ function gr_move_image( &$gallery, &$response ) {
 }
 
 function gr_change_index( &$gallery, &$response ) {
-
 	global $GR_STAT;
 
 	if(!isset($gallery->album)) { //if reordering root album
@@ -612,17 +648,20 @@ function gr_change_index( &$gallery, &$response ) {
 			$albumDB->save();
 			$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
 			$response->setProperty( 'status_text', 'Change index successful.' );
-		} else {
+		}
+		else {
 			$response->setProperty( 'status', $GR_STAT['NO_WRITE_PERMISSION'] );
 			$response->setProperty( 'status_text', 'No write permission.' );
 		}
-	} else {
+	}
+	else {
 		if($gallery->user->canWriteToAlbum($gallery->album)) {
 			$gallery->album->movePhoto($index,$newIndex-1);
 			$gallery->album->save();
 			$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
 			$response->setProperty( 'status_text', 'Change index successful.' );
-		} else {
+		}
+		else {
 			$response->setProperty( 'status', $GR_STAT['NO_WRITE_PERMISSION'] );
 			$response->setProperty( 'status_text', 'No write permission.' );
 		}
@@ -630,7 +669,6 @@ function gr_change_index( &$gallery, &$response ) {
 }
 
 function gr_rotate_image( &$gallery, &$response ) {
-
 	global $GR_STAT;
 
 	if(is_object($gallery->album->photos[$index-1]->image)) {
@@ -642,11 +680,13 @@ function gr_rotate_image( &$gallery, &$response ) {
 				$response->setProperty( 'status', $GR_STAT['SUCCESS'] );
 				$response->setProperty( 'status_text', 'Image successfully rotated.' );
 			}
-		} else {
+		}
+		else {
 			$response->setProperty( 'status', $GR_STAT['NO_WRITE_PERMISSION'] );
 			$response->setProperty( 'status_text', 'No write permission.' );
 		}
-	} else {
+	}
+	else {
 		$response->setProperty( 'status', $GR_STAT['ROTATE_IMAGE_FAILED'] );
 		$response->setProperty( 'status_text', 'Specified index is not an image.' );
 	}
@@ -674,8 +714,9 @@ function check_proto_version( &$response ) {
 				echo $response->listprops();
 				exit;
 			}
-		// else version compatible, proceed
-		} else {
+			// else version compatible, proceed
+		}
+		else {
 			$response->setProperty( "status", $GR_STAT['PROTOCOL_VERSION_FORMAT_INVALID'] );
 			$response->setProperty( "status_text", "Protocol version format invalid." );
 
@@ -683,7 +724,8 @@ function check_proto_version( &$response ) {
 			echo $response->listprops();
 			exit;
 		}
-	} else {
+	}
+	else {
 		// must specify protocol_version
 		$response->setProperty( "status", $GR_STAT['PROTOCOL_VERSION_MISSING'] );
 		$response->setProperty( "status_text", "Protocol version not found." );
@@ -699,11 +741,13 @@ function checkIfNestedAlbum(&$startAlbum,&$possibleSub) {
 	if(count($startAlbum->photos) < 1) {
 		return FALSE;
 	}
+
 	foreach($startAlbum->photos as $subItem) {
 		if($subItem->isAlbum()) { //if it's an album
 			if($subItem->getAlbumName() == $possibleSub->fields['name']) {
 				return TRUE; //possible sub was found to be a sub of startalbum
-			} else {
+			}
+			else {
 				$subAlbum = new Album();
 				$subAlbum->load($subItem->getAlbumName());
 				if(checkIfNestedAlbum($subAlbum,$possibleSub)) {
@@ -718,36 +762,36 @@ function checkIfNestedAlbum(&$startAlbum,&$possibleSub) {
 //-- FUNCTIONS
 //--
 function appendNestedAlbums( &$myAlbum, &$album_index, &$response ) {
-    global $gallery;
-	
+	global $gallery;
+
 	$parent_index = $album_index;
 
 	$numPhotos = $myAlbum->numPhotos(1);
-    
-    for ($i=1; $i <= $numPhotos; $i++) {
-        if ($myAlbum->isAlbum($i)) {
-            $myName = $myAlbum->getAlbumName($i);
-            $nestedAlbum = new Album();
-            $nestedAlbum->load($myName);
-            if ($gallery->user->canReadAlbum($nestedAlbum)) {
-            	// if readable, add this album plus readable nested albums
+
+	for ($i=1; $i <= $numPhotos; $i++) {
+		if ($myAlbum->isAlbum($i)) {
+			$myName = $myAlbum->getAlbumName($i);
+			$nestedAlbum = new Album();
+			$nestedAlbum->load($myName);
+			if ($gallery->user->canReadAlbum($nestedAlbum)) {
+				// if readable, add this album plus readable nested albums
 				add_album( $nestedAlbum, $album_index, $parent_index, $response );
-                appendNestedAlbums($nestedAlbum, $album_index, $response );
-            }
-        }
-    }
+				appendNestedAlbums($nestedAlbum, $album_index, $response );
+			}
+		}
+	}
 }
 
 function add_album( &$myAlbum, &$album_index, $parent_index, &$response ){
 	global $gallery;
-	
+
 	// increment index
 	$album_index++;
 
 	// fetch name & title
 	$albumName = $myAlbum->fields['name'];
 	$albumTitle = $myAlbum->fields['title'];
-	
+
 	// write name, title and parent
 	$response->setProperty( "album.name.$album_index", $albumName );
 	$response->setProperty( "album.title.$album_index", $albumTitle );
@@ -763,7 +807,7 @@ function add_album( &$myAlbum, &$album_index, $parent_index, &$response ){
 	$can_delete_from = $gallery->user->canDeleteFromAlbum($myAlbum) ? "true" : "false";
 	$can_delete_alb = $gallery->user->canDeleteAlbum($myAlbum) ? "true" : "false";
 	$can_create_sub = $gallery->user->canCreateSubAlbum($myAlbum) ? "true" : "false";
-	
+
 	$response->setProperty( "album.perms.add.$album_index", $can_add );
 	$response->setProperty( "album.perms.write.$album_index", $can_write );
 	$response->setProperty( "album.perms.del_item.$album_index", $can_delete_from );
@@ -782,92 +826,133 @@ function add_album( &$myAlbum, &$album_index, $parent_index, &$response ){
 
 //-- Renamed this function because it conflicts with
 //-- another one that happens when upgrading the album
-//-- Speaking of which, trying to upload a picture to 
+//-- Speaking of which, trying to upload a picture to
 //-- an album which is not yet upgraded fails. Need warning
 //-- in the docs.
 
 function processFile($file, $tag, $name, $setCaption="") {
-    global $gallery;
-    global $temp_files;
+	global $gallery;
+	global $temp_files;
 
-    if (!strcmp($tag, "zip")) {
-        if (!$gallery->app->feature["zip"]) {
-            $error = "Zip not supported";
-            continue;
-        }
-        /* Figure out what files we can handle */
-        list($files, $status) = exec_internal(
-            fs_import_filename($gallery->app->zipinfo, 1) .
-            " -1 " .
-            fs_import_filename($file, 1));
-        sort($files);
-        foreach ($files as $pic_path) {
-            $pic = basename($pic_path);
-            $tag = ereg_replace(".*\.([^\.]*)$", "\\1", $pic);
-            $tag = strtolower($tag);
+	$error = null;
 
-            if (acceptableFormat($tag) || !strcmp($tag, "zip")) {
-                $cmd_pic_path = str_replace("[", "\[", $pic_path);
-                $cmd_pic_path = str_replace("]", "\]", $cmd_pic_path);
-                exec_wrapper(fs_import_filename($gallery->app->unzip, 1) .
-                         " -j -o " .
-                         fs_import_filename($file, 1) .
-                         " \"" .
-                         fs_import_filename($cmd_pic_path, 1) .
-                         "\" -d " .
-                         fs_import_filename($gallery->app->tmpDir, 1));
-                processFile($gallery->app->tmpDir . "/$pic", $tag, $pic, $setCaption);
-                fs_unlink($gallery->app->tmpDir . "/$pic");
-            }
-        }
-    } else {
-        // remove %20 and the like from name
-        $name = urldecode($name);
+	if (isAcceptableArchive($tag)) {
+		processingMsg(sprintf(gTranslate('core', "Processing file '%s' as archive"), $name));
+		$tool = canDecompressArchive($tag);
+		if (!$tool) {
+			$error = sprintf(gTranslate('core', "Skipping '%s' (%s support not enabled)"), $name, $tag);
+			return $error;
+		}
 
-        // parse out original filename without extension
-        $originalFilename = eregi_replace(".$tag$", "", $name);
-        // replace multiple non-word characters with a single "_"
-        $mangledFilename = ereg_replace("[^[:alnum:]]", "_", $originalFilename);
+		$temp_filename	= tempnam($gallery->app->tmpDir, 'g1_tmp_');
+		$temp_dirname	= $temp_filename . '.dir';
 
-        /* Get rid of extra underscores */
-        $mangledFilename = ereg_replace("_+", "_", $mangledFilename);
-        $mangledFilename = ereg_replace("(^_|_$)", "", $mangledFilename);
-   
-        /*
-        need to prevent users from using original filenames that are purely numeric.
-        Purely numeric filenames mess up the rewriterules that we use for mod_rewrite
-        specifically:
-        RewriteRule ^([^\.\?/]+)/([0-9]+)$  /~jpk/gallery/view_photo.php?set_albumName=$1&index=$2  [QSA]
-        */
-   
-        if (ereg("^([0-9]+)$", $mangledFilename)) {
-            $mangledFilename .= "_G";
-        }
-   
-        set_time_limit($gallery->app->timeLimit);
-        
-        if (acceptableFormat($tag)) {
-   
-		    /*
-		     * Move the uploaded image to our temporary directory
-		     * using move_uploaded_file so that we work around
-		     * issues with the open_basedir restriction.
-		     */
-		    if (function_exists('move_uploaded_file')) {
+		if (fs_is_dir($temp_dirname)) {
+			$error = gTranslate('core', "Error occured before extracting the archive. Temporary destination exists.");
+			return $error;
+		}
+
+		if (! fs_mkdir($temp_dirname)) {
+			$error = gTranslate('core', "Error occured before extracting the archive. Temporary destination could not be created.");
+			return $error;
+		}
+
+		if(! extractArchive($file, $tag, $temp_dirname)) {
+			$error = gTranslate('core', "Extracting archive failed.");
+			return $error;
+		}
+
+		echo debugMessage(gTranslate('core', "Processing archive content."), __FILE__, __LINE__);
+		$files_to_process	= array();
+		$dir_handle			= fs_opendir($temp_dirname);
+		while (false !== ($content_filename = readdir($dir_handle))) {
+			if(! isXSSclean($content_filename) ||
+			   $content_filename == "." || $content_filename == '..')
+			{
+			continue;
+		}
+
+			$content_file_ext		= getExtension($content_filename);
+			$fullpath_content_file	= $temp_dirname .'/' . $content_filename;
+
+			if (isAcceptableFormat($content_file_ext) ||
+				isAcceptableArchive($content_file_ext))
+			{
+				$files_to_process[] = array(
+					'filename'	=> $fullpath_content_file,
+					'ext'		=> $content_file_ext
+				);
+			}
+			}
+
+		closedir($dir_handle);
+
+		/* Now process all valid files we found */
+		echo debugMessage(gTranslate('core', "Processing valid files from archive"), __FILE__, __LINE__);
+		$loop = 0;
+		foreach ($files_to_process as $current_file) {
+			$current_file_name = basename($current_file['filename']);
+			$current_file_ext  = basename($current_file['ext']);
+
+			processFile($current_file['filename'],
+						$current_file_ext,
+						$current_file_name,
+						$caption,
+						$setCaption
+			);
+		}
+		/* End of archive processing */
+		rmdirRecursive($temp_dirname);
+		fs_unlink($temp_filename);
+	}
+	else {
+		// remove %20 and the like from name
+		$name = urldecode($name);
+
+		// parse out original filename without extension
+		$originalFilename = eregi_replace(".$tag$", "", $name);
+		// replace multiple non-word characters with a single "_"
+		$mangledFilename = ereg_replace("[^[:alnum:]]", "_", $originalFilename);
+
+		/* Get rid of extra underscores */
+		$mangledFilename = ereg_replace("_+", "_", $mangledFilename);
+		$mangledFilename = ereg_replace("(^_|_$)", "", $mangledFilename);
+
+		/*
+		need to prevent users from using original filenames that are purely numeric.
+		Purely numeric filenames mess up the rewriterules that we use for mod_rewrite
+		specifically:
+		RewriteRule ^([^\.\?/]+)/([0-9]+)$  /~jpk/gallery/view_photo.php?set_albumName=$1&index=$2  [QSA]
+		*/
+
+		if (ereg("^([0-9]+)$", $mangledFilename)) {
+			$mangledFilename .= "_G";
+		}
+
+		set_time_limit($gallery->app->timeLimit);
+
+		if (isAcceptableFormat($tag) || isAcceptableArchive($tag)) {
+			/*
+			* Move the uploaded image to our temporary directory
+			* using move_uploaded_file so that we work around
+			* issues with the open_basedir restriction.
+			*/
+			if (function_exists('move_uploaded_file')) {
 				$newFile = tempnam($gallery->app->tmpDir, "gallery");
 				if (move_uploaded_file($file, $newFile)) {
-				    $file = $newFile;
-		
-				    /* Make sure we remove this file when we're done */
-				    $temp_files[$file] = 1;
-				}
-		    }
+					$file = $newFile;
 
-            if ($setCaption) {
-                $caption = $setCaption;
-            } else {
-                $caption = "";
-            }
+					/* Make sure we remove this file when we're done */
+					$temp_files[$file] = 1;
+				}
+			}
+
+			if ($setCaption) {
+				$caption = $setCaption;
+			}
+			else {
+				$caption = '';
+			}
 
 			// add the extra fields
 			$myExtraFields = array();
@@ -893,16 +978,19 @@ function processFile($file, $tag, $name, $setCaption="") {
 			}
 			//echo "Extra fields ". implode("/", array_keys($myExtraFields)) ." -- ". implode("/", array_values($myExtraFields)) ."\n";
 
-	        $err = $gallery->album->addPhoto($file, $tag, $mangledFilename, $caption, "", $myExtraFields, $gallery->user->getUid());
-	        if ($err)  {
-	        	$error = "$err";
-	        }
-	    } else {
-	    	$error = "Skipping $name (can't handle '$tag' format)";
-	    }
-    }
-    
-    return empty($error) ? '' : $error;
+			$plainErrorMessage = true;
+
+			list($status, $statusMsg) = $gallery->album->addPhoto($file, $tag, $mangledFilename, $caption, '', $myExtraFields, $gallery->user->getUid());
+			if(!$status) {
+				$error = $statusMsg;
+			}
+		}
+		else {
+			$error = sprintf(gTranslate('core', "Skipping %s (can't handle '%s' format)"), $name, $tag);
+		}
+	}
+
+	return empty($error) ? '' : $error;
 }
 
 function mark_and_sweep(&$albumDB, $checkWriteable = TRUE) {
