@@ -1,46 +1,51 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: stats.inc.php,v 1.10.2.1 2005/09/12 22:40:47 dmolavi Exp $
+ * $Id: stats.inc.php 193 2008-07-15 22:02:33Z jens $
  *
- */
-?>
-<?php
-
-/* This defines all posibilities for the stats-wizard
-**
-** The wizard is divided into 4 sections
-** - types
-** - options
-** - layout
-** - filters
-**
-** Every item has properties:
-**   type	which html type is used in the gui.
-**		'radio', 'checkbox', 'text' or 'select'
-**   default	default value
-**		NOTE: this is also used for the publich links to stats !
-**   name	used for radiogroups. all elements with same name are grouped.
-**   text	This Text is displayed next to the element
-**   linktext	This Text is used for the public links
 */
 
+/**
+ * This defines all posibilities for the stats-wizard
+ *
+ * The wizard is divided into 4 sections
+ * - types
+ * - options
+ * - layout
+ * - filters
+ *
+ * Every item has properties:
+ *   type	which html type is used in the gui.
+ *		'radio', 'checkbox', 'text' or 'select'
+ *   default	default value
+ *		NOTE: this is also used for the publich links to stats !
+ *   name	used for radiogroups. all elements with same name are grouped.
+ *   text	This Text is displayed next to the element
+ * 	 linktext	This Text is used for the public links
+ *
+ * @package Statistics
+*/
+
+if (!isset($gallery) || !function_exists('gTranslate')) {
+	exit;
+}
+
 $stats['types'] = array (
 	'views'		=> array('type' => 'radio',
 				 'default' => 'checked',
@@ -104,11 +109,12 @@ $stats['options'] = array (
 /*	'svo'		=> array('type' => 'checkbox',
 				 'default' => '',
 				 'text' => _("Show the number of 'simplified' votes an image has")),
-*/
 	'sav'		=> array('type' => 'checkbox',
 				 'default' => '',
 				 'text' => _("Show the add vote link")),
+*/
 	'sao'		=> array('type' => 'checkbox',
+
 				 'default' => '',
 				 'text' => _("Show the album owners")),
 	'stm'		=> array('type' => 'checkbox',
@@ -157,49 +163,59 @@ $stats['filter'] = array(
 				 'text' => _("Filter by day")),
 );
 
+/**
+ * Returns a string that contains the HTML code for links to certain statistics
+ *
+ * @return	string	$links	HTML code to statistics
+ */
 function generateStatsLinks() {
-    global $gallery;
-    global $stats;
-    $links = '';
+	global $gallery, $stats;
 
-    if (!empty($gallery->app->stats_foruser)) {
-	foreach ($gallery->app->stats_foruser as $key) {
-	    if (isset($stats['types'][$key])) {
-	        $links .= "\n\t". '[<a href="'. defaultStatsUrl($key) .'">' . $stats['types'][$key]['linktext'] .'</a>]';
-	    }
+	$links = '';
+
+	if (!empty($gallery->app->stats_foruser)) {
+		foreach ($gallery->app->stats_foruser as $key) {
+			if($key == 'comments' && $gallery->app->comments_enabled != 'yes') continue;
+
+			if (isset($stats['types'][$key])) {
+				$links .= "\n\t". '[<a href="'. defaultStatsUrl($key) .'">' . $stats['types'][$key]['linktext'] .'</a>]';
+			}
+		}
 	}
-    }
 
 	return $links;
 }
 
 /* Layout function */
 function stats_showBlock($block, $caption=null) {
-	echo "\n<table>";
+	echo "\n<table width=\"100%\">";
+
 	if (isset($caption)) {
-		echo "\n<caption>$caption</caption>"; 
+		echo "\n<caption>$caption</caption>";
 	}
+
 	foreach ($block as $option => $attr) {
 		echo "\n<tr>";
+		echo "\n\t<td>". $attr['text'] ."</td>";
+
 		switch ($attr['type']) {
 			case 'radio':
-					echo "\n\t". '<td><input type="'. $attr['type'] .'" name="'. $attr['name'] .'" value="'. $option .'" '. $attr['default'] .'></td>';
-			break;
+				echo "\n\t". '<td width="30%"><input type="'. $attr['type'] .'" name="'. $attr['name'] .'" value="'. $option .'" '. $attr['default'] .'></td>';
+				break;
 			case 'checkbox':
-					echo "\n\t". '<td><input type="'. $attr['type'] .'" name="'. $option .'" value="1" '. $attr['default'] .'></td>';
-			break;
+				echo "\n\t". '<td width="30%"><input type="'. $attr['type'] .'" name="'. $option .'" value="1" '. $attr['default'] .'></td>';
+				break;
 			case 'select':
-					echo "\n\t". '<td><select name="'. $option .'">';
-					foreach ($attr['options'] as $optkey => $optvalue) {
-							echo "\n\t\t<option value=\"$optkey\">$optvalue</option>";
-					}
-					echo "\n\t</select></td>";
-			break;
+				echo "\n\t". '<td width="30%"><select name="'. $option .'">';
+				foreach ($attr['options'] as $optkey => $optvalue) {
+					echo "\n\t\t<option value=\"$optkey\">$optvalue</option>";
+				}
+				echo "\n\t</select></td>";
+				break;
 			default:
-				echo "\n\t". '<td><input type="'. $attr['type'] .'" name="'. $option .'" value="'. $attr['default'] .'" size="5"></td>';
-			break;
+				echo "\n\t". '<td width="30%"><input type="'. $attr['type'] .'" name="'. $option .'" value="'. $attr['default'] .'" size="5"></td>';
+				break;
 		}
-		echo "\n\t<td>". $attr['text'] ."</td>";
 		echo "\n</tr>";
 	}
 	echo "\n</table>";
@@ -207,9 +223,10 @@ function stats_showBlock($block, $caption=null) {
 
 function defaultStatsUrl($type='') {
 	global $stats;
+
 	$urlParams = array();
 
-	$paramListGroups = array('options', 'layout', 'filter'); 
+	$paramListGroups = array('options', 'layout', 'filter');
 	if (isset($type)) {
 		$urlParams['type'] = $type;
 		foreach($paramListGroups as $group) {
@@ -217,7 +234,8 @@ function defaultStatsUrl($type='') {
 				if (!empty($stats[$group][$itemKey]['default'])) {
 					if($stats[$group][$itemKey]['default'] == 'checked') {
 						$urlParams[$itemKey] = 1;
-					} else {
+					}
+					else {
 						$urlParams[$itemKey] = $stats[$group][$itemKey]['default'];
 					}
 				}
@@ -225,7 +243,7 @@ function defaultStatsUrl($type='') {
 		}
 	}
 
-	$msStatsUrl = makeGalleryUrl( "stats.php", $urlParams);
+	$msStatsUrl = makeGalleryUrl('stats.php', $urlParams);
 
 	return $msStatsUrl;
 }
