@@ -1,13 +1,34 @@
 <?php
+/*
+ * Gallery - a web based photo album viewer and editor
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or (at
+ * your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
+ *
+ * $Id: url.php 295 2008-08-05 13:42:53Z jens $
+ */
 
 /**
  * Functions that provide possibility to create and modify URLS
  *
- * @package	urls
+ * @package     Libs
+ * @subpackage  URLs
  */
 
 /**
- * Define Constants for Gallery pathes.
+ * Define Constants for absolute Gallery pathes.
  */
 function setGalleryPaths() {
 	if (defined('GALLERY_BASE')) {
@@ -16,10 +37,11 @@ function setGalleryPaths() {
 
 	$currentFile = __FILE__;
 	if ( $currentFile == '/usr/share/gallery/lib/url.php') {
-		/* We assum Gallery runs on as Debian Package */
+		/* We assume Gallery runs on as Debian Package */
 		define ("GALLERY_CONFDIR", "/etc/gallery");
 		define ("GALLERY_SETUPDIR", "/var/lib/gallery/setup");
-	} else {
+	}
+	else {
 		define ("GALLERY_CONFDIR", dirname(dirname(__FILE__)));
 		define ("GALLERY_SETUPDIR", dirname(dirname(__FILE__)) . "/setup");
 	}
@@ -28,24 +50,31 @@ function setGalleryPaths() {
 }
 
 /**
+ * Return the URL to your Gallery
  *
+ * @return string	$base
  */
 function getGalleryBaseUrl() {
-    global $gallery;
+	global $gallery;
 
-    if (isset($gallery->app) && isset($gallery->app->photoAlbumURL)) {
-        $base = $gallery->app->photoAlbumURL;
-    }
-    elseif(where_i_am() == 'config') {
-        $base = '..';
-    } elseif (defined('GALLERY_URL')) {
-        $base = GALLERY_URL;
-    } else {
-        $base = '.';
-    }
+	if (isset($gallery->app) &&
+		isset($gallery->app->photoAlbumURL))
+	{
+		$base = $gallery->app->photoAlbumURL;
+	}
+	elseif(where_i_am() == 'config') {
+		$base = '..';
+	}
+	elseif (defined('GALLERY_URL')) {
+		$base = GALLERY_URL;
+	}
+	else {
+		$base = '.';
+	}
 
-    return $base;
+	return $base;
 }
+
 /**
  * Any URL that you want to use can either be accessed directly
  * in the case of a standalone Gallery, or indirectly if we're
@@ -59,7 +88,6 @@ function getGalleryBaseUrl() {
  *				(eg, array("index" => 1, "set_albumName" => "foo"))
  * @return	string
  */
-
 function makeGalleryUrl($target = '', $args = array()) {
 	global $gallery;
 	global $GALLERY_EMBEDDED_INSIDE;
@@ -67,17 +95,21 @@ function makeGalleryUrl($target = '', $args = array()) {
 	global $GALLERY_MODULENAME;
 	global $modpath;
 
-        if (empty($GALLERY_MODULENAME)
-          && $GALLERY_EMBEDDED_INSIDE =='nuke'
-          && !empty($modpath)) {
-            $GALLERY_MODULENAME = basename(dirname($modpath));
-        }
+	if (empty($GALLERY_MODULENAME) &&
+		$GALLERY_EMBEDDED_INSIDE =='nuke' &&
+		!empty($modpath))
+	{
+		$GALLERY_MODULENAME = basename(dirname($modpath));
+	}
+
+	/* Needed for postNuke (0.8 and above) */
+	global $GALLERY_POSTNUKE_VERSION;
 
 	/* Needed for phpBB2 */
 	global $userdata;
 	global $board_config;
-        
-	/* Needed for Mambo */
+
+	/* Needed for Mambo / Joomla! */
 	global $MOS_GALLERY_PARAMS;
 
 	/* Needed for CPGNuke */
@@ -85,21 +117,27 @@ function makeGalleryUrl($target = '', $args = array()) {
 
 	$url = '';
 	$prefix = '';
-	$isSetupUrl = (stristr($target,"setup")) ? true : false;
+	$isSetupUrl = (stristr($target, 'setup')) ? true : false;
 
-	if(!urlIsRelative($gallery->app->photoAlbumURL)) {
+	if(isset($gallery->app->photoAlbumURL) && !urlIsRelative($gallery->app->photoAlbumURL)) {
 		$gUrl = parse_url($gallery->app->photoAlbumURL);
-		$urlprefix = $gUrl['scheme'] .'://'. $gUrl['host'];
+
+		if(isset($gUrl['port'])) {
+			$urlprefix = $gUrl['scheme'] .'://'. $gUrl['host'] . ':' . $gUrl['port'];
+		}
+		else {
+			$urlprefix = $gUrl['scheme'] .'://'. $gUrl['host'];
+		}
 	}
 	else {
-	    $urlprefix = '';
+		$urlprefix = '';
 	}
-	
+
 	/* make sure the urlprefix doesnt end with a / */
 	$urlprefix = ereg_replace("\/$", "", $urlprefix);
-	
+
 	/* Add the folder to the url when *Nuke is not direct in the main folder */
-	$addpath = substr($_SERVER['SCRIPT_NAME'], 0, strrpos($_SERVER['SCRIPT_NAME'], '/'));
+	$addpath = substr($_SERVER['PHP_SELF'], 0, strrpos($_SERVER['PHP_SELF'], '/'));
 
 	if( isset($GALLERY_EMBEDDED_INSIDE) && !$isSetupUrl && where_i_am() != 'config') {
 		switch ($GALLERY_EMBEDDED_INSIDE_TYPE) {
@@ -141,7 +179,7 @@ function makeGalleryUrl($target = '', $args = array()) {
 			break;
 
 			case 'postnuke':
-				if (substr(_PN_VERSION_NUM, 0, 7) < "0.7.6.0") {
+				if (substr($GALLERY_POSTNUKE_VERSION, 0, 7) < "0.7.6.0") {
 					$args["op"] = "modload";
 					$args["file"] = "index";
 
@@ -150,7 +188,7 @@ function makeGalleryUrl($target = '', $args = array()) {
 				else {
 					$url = $urlprefix . pnGetBaseURI()."/index.php";
 				}
-				
+
 				$args["name"] = $GALLERY_MODULENAME;
 				/*
 				 * include *must* be last so that the JavaScript code in
@@ -158,38 +196,39 @@ function makeGalleryUrl($target = '', $args = array()) {
 				 */
 				$args["include"] = $target;
 			break;
-							
+
 			case 'mambo':
+			case 'joomla':
 				$args['option'] = $GALLERY_MODULENAME;
 				$args['Itemid'] = $MOS_GALLERY_PARAMS['itemid'];
 				$args['include'] = $target;
 
-				/* We cant/wantTo load the complete Mambo Environment into the pop up
+				/* We cant/wantTo load the complete Mambo / Joomla! Environment into the pop up
 				** E.g. the Upload Framwork does not work then
-				** So we need to put necessary infos of Mambo into session.
+				** So we need to put necessary infos of Mambo / Joomla! into session.
 				*/
 				if ((isset($args['type']) && $args['type'] == 'popup') ||
 					(!empty($args['gallery_popup']))) {
 					$target = 'index.php';
-				} else {
+				}
+				else {
 					if (!empty($gallery->session->mambo->mosRoot)) {
 						$url = $urlprefix . $gallery->session->mambo->mosRoot . 'index.php';
-					} else {
-						$url ='index.php';
+					}
+					else {
+						$url = 'index.php';
 					}
 				}
 			break;
 
-
-
 			// Maybe something went wrong, we do nothing as URL we be build later.
 			default:
 			break;
 		}
 	}
 
-	if (empty($url)) {       
-	    $url = getGalleryBaseUrl() ."/$target";
+	if (empty($url)) {
+		$url = getGalleryBaseUrl() ."/$target";
 	}
 
 	if ($args) {
@@ -197,13 +236,15 @@ function makeGalleryUrl($target = '', $args = array()) {
 		foreach ($args as $key => $value) {
 			if ($i++) {
 				$url .= "&";  // should replace with &amp; for validatation
-			} else {
+			}
+			else {
 				$url .= "?";
 			}
 
 			if (! is_array($value)) {
 				$url .= "$key=$value";
-			} else {
+			}
+			else {
 				$j = 0;
 				foreach ($value as $subkey => $subvalue) {
 					if ($j++) {
@@ -216,19 +257,25 @@ function makeGalleryUrl($target = '', $args = array()) {
 	}
 	return htmlspecialchars($url);
 }
-
-function makeGalleryHeaderUrl($target, $args=array()) {
+/**
+ * A wrapper around makeGalleryUrl that returns the url with decoded htmlentities
+ *
+ * @param string	$target
+ * @param array		$args
+ * @return string
+ */
+function makeGalleryHeaderUrl($target = '', $args = array()) {
 	$url = makeGalleryUrl($target, $args);
+
 	return unhtmlentities($url);
 }
 
-/*
+/**
  * makeAlbumUrl is a wrapper around makeGalleryUrl.  You tell it what
  * album (and optional photo id) and it does the rest.  You can also
  * specify additional key/value pairs in the optional third argument.
- */
-
-function makeAlbumUrl($albumName="", $photoId="", $args=array()) {
+*/
+function makeAlbumUrl($albumName = '', $photoId = '', $args = array()) {
 	global $GALLERY_EMBEDDED_INSIDE, $GALLERY_EMBEDDED_INSIDE_TYPE;
 	global $gallery;
 
@@ -236,11 +283,11 @@ function makeAlbumUrl($albumName="", $photoId="", $args=array()) {
 	if ( $gallery->app->feature["rewrite"] == 1 &&
 		(! $GALLERY_EMBEDDED_INSIDE || $GALLERY_EMBEDDED_INSIDE_TYPE == 'GeekLog')) {
 		if ($albumName) {
-			$target = urlencode ($albumName);
+			$target = urlencode($albumName);
 
 			// Can't have photo without album
 			if ($photoId) {
-				$target .= "/".urlencode ($photoId);
+				$target .= '/'. urlencode($photoId);
 			}
 		} else {
 			$target = "albums.php";
@@ -250,7 +297,7 @@ function makeAlbumUrl($albumName="", $photoId="", $args=array()) {
 			$args["set_albumName"] = urlencode ($albumName);
 			if ($photoId) {
 				$target = "view_photo.php";
-				$args["id"] = urlencode ($photoId);
+				$args['id'] = urlencode($photoId);
 			} else {
 				$target = "view_album.php";
 			}
@@ -267,9 +314,10 @@ function makeAlbumHeaderUrl($albumName="", $photoId="", $args=array()) {
 }
 
 function addUrlArg($url, $arg) {
-	if (strchr($url, "?")) {
-		return "$url&$arg"; // should replace with &amp; for validatation
-	} else {
+	if (strstr ($url, "?")) {
+		return "$url&$arg";
+	}
+	else {
 		return "$url?$arg";
 	}
 }
@@ -280,41 +328,167 @@ function addUrlArg($url, $arg) {
  * @return	string	$retUrl		Complete URL to the Image
  */
 function getImagePath($name, $skinname = '') {
-    global $gallery;
-    $retUrl = '';
+	global $gallery;
+	$retUrl = '';
 
-    if (!$skinname) {
-	$skinname = $gallery->app->skinname;
-    }
+	if (!$skinname) {
+		$skinname = $gallery->app->skinname;
+	}
 
-    /* We cant use makeGalleryUrl() here, as Gallery could be embedded. */
-    $base = getGalleryBaseUrl();
-    $defaultname = "$base/images/$name";
-    $fullname = dirname(dirname(__FILE__)) . "/skins/$skinname/images/$name";
-    $fullURL = "$base/skins/$skinname/images/$name";
+	/* We cant use makeGalleryUrl() here, as Gallery could be embedded. */
+	$base		= getGalleryBaseUrl();
+	$defaultname	= dirname(dirname(__FILE__)) . "/images/$name";
+	$fullname	= dirname(dirname(__FILE__)) . "/skins/$skinname/images/$name";
 
-    if (fs_file_exists($fullname) && !broken_link($fullname)) {
-	$retUrl = $fullURL;
-    } else {
-	$retUrl = $defaultname;
-    }
+	$defaultURL	= "$base/images/$name";
+	$fullURL	= "$base/skins/$skinname/images/$name";
 
-    return $retUrl;
+	if (fs_file_exists($fullname) && !broken_link($fullname)) {
+		$retUrl = $fullURL;
+	}
+	elseif (fs_file_exists($defaultname) && !broken_link($defaultname)) {
+		$retUrl = $defaultURL;
+	}
+
+	return $retUrl;
 }
 
 /**
- * Checkes wether an URL is relative or not
+ * @param	string	$name		Name of Image
+ * @param	string	$skinname	Optional Name skin, if file is not found, fallback to default location
+ * @return	string	$retPath	Complete Path to the Image
+ * @author	Jens Tkotz
+ */
+function getAbsoluteImagePath($name, $skinname = '') {
+	global $gallery;
+	$retPath = '';
+
+	$base = dirname(dirname(__FILE__));
+
+	$defaultPath = "$base/images/$name";
+
+	/* Skin maybe 'none', but this is never found, so we fall back to default. */
+	if (!$skinname) {
+		$skinname = $gallery->app->skinname;
+	}
+	$skinPath = "$base/skins/$skinname/images/$name";
+
+	if (fs_file_exists($skinPath)) {
+		$retPath = $skinPath;
+	} else {
+		$retPath = $defaultPath;
+	}
+
+	return $retPath;
+}
+
+/**
+ * Checks whether an URL is relative or not
  * @param	string	$url
  * @return	boolean
  * @author	Jens Tkotz
  */
-function urlIsrelative($url) {
-     if (substr($url, 0,4) == 'http') {
-	return false;
-    }
-    else {
-	return true;
-    }
+function urlIsRelative($url) {
+	if (substr($url, 0,7) == 'http://') {
+		return false;
+	}
+	elseif(substr($url, 0,6) == 'ftp://') {
+		return false;
+	}
+	else {
+		return true;
+	}
+}
+
+/**
+ * Checks whether a path looks absolute. Means: starting with a /
+ *
+ * @param string	$path
+ * @return boolean
+ * @author Jens Tkotz
+ */
+function pathIsAbsolute($path) {
+	if($path{0} == '/' && $path{1} != '/') {
+		return true;
+	}
+	else {
+		return false;
+	}
+}
+
+function broken_link($file) {
+	if (fs_is_link($file)) {
+		return !fs_is_file($file);
+	}
+	else {
+		return false;
+	}
+}
+
+function galleryLink($url = '', $text ='', $attrList = array(), $icon = '', $addBrackets = false) {
+	global $gallery;
+
+	$html = '';
+	$altText = $text;
+
+	if (!empty($attrList['altText'])) {
+		$altText = $attrList['altText'];
+		unset($attrList['altText']);
+	}
+
+	$attrs = generateAttrs($attrList);
+
+	if(!empty($icon)) {
+		$content = getIconText($icon, $text, '', $addBrackets, $altText);
+	}
+	else {
+		if($addBrackets) {
+			$content = '['. $text .']';
+		}
+		else {
+			$content = $text;
+		}
+	}
+
+	if (!empty($url)) {
+		$html .= "<a href=\"$url\"$attrs>$content</a>\n";
+	}
+	elseif (! empty($attrs)) {
+		$html .= "<a$attrs>$content</a>\n";
+	}
+	else {
+		$html = $content;
+	}
+
+	return $html;
+}
+
+function galleryIconLink($url, $icon, $text, $iconMode = '', $attrList = array()) {
+	global $gallery;
+
+	$html		= '';
+	$altText	= '';
+
+	$iconMode = !empty($iconMode) ? $iconMode : $gallery->app->useIcons;
+
+	if($iconMode == 'yes') {
+		$altText = $text;
+	}
+
+	$addBrackets = ($iconMode == 'no') ? true : false;
+
+	$content = getIconText($icon, $text, $iconMode, $addBrackets, $altText, true);
+
+	$attrs = generateAttrs($attrList);
+
+	if (!empty($url)) {
+		$html .= "<a href=\"$url\"$attrs>$content</a>";
+	}
+	else {
+		$html .= "<a$attrs>$content</a>";
+	}
+
+	return $html;
 }
 
 ?>
