@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: modify_user.php,v 1.44.2.2 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: modify_user.php 253 2008-07-28 19:08:00Z jens $
  */
 ?>
 <?php
@@ -31,7 +31,7 @@ list($email, $defaultLanguage, $canCreate, $canChangeOwnPw, $isAdmin) =
     getRequestVar(array('email', 'defaultLanguage', 'canCreate','canChangeOwnPw', 'isAdmin'));
 
 if (!$gallery->user->isAdmin()) {
-    echo _("You are not allowed to perform this action!");
+    echo gTranslate('core', "You are not allowed to perform this action!");
     exit;	
 }
 
@@ -39,30 +39,31 @@ $errorCount = 0;
 $msg = '';
 $infoLineType = '';
 
-/* User pressed "save" Button
-** If (changed) user name is valid and password match,
-** then load former user as temp user and overwrite with new values
-** If one modified itself, changes current user.
-*/
+/**
+ * User pressed "save" Button
+ * If (changed) user name is valid and password match,
+ * then load former user as temp user and overwrite with new values
+ * If one modified itself, changes current user.
+ */
 if (!empty($save)) {
-   if (strcmp($old_uname, $uname)) {
-	$gErrors["uname"] = $gallery->userDB->validNewUserName($uname);
-	    if ($gErrors["uname"]) {
-		$errorCount++;
-		$uname = $old_uname;
-	    }
+    if (strcmp($old_uname, $uname)) {
+        $gErrors["uname"] = $gallery->userDB->validNewUserName($uname);
+        if ($gErrors["uname"]) {
+            $errorCount++;
+            $uname = $old_uname;
+        }
     }
 
     if ($new_password1 || $new_password2) {
-	if (strcmp($new_password1, $new_password2)) {
-	    $gErrors["new_password2"] = _("Passwords do not match!");
-	    $errorCount++;
-	} else {
-	    $gErrors["new_password1"] = $gallery->userDB->validPassword($new_password1);
-	    if ($gErrors["new_password1"]) {
-		$errorCount++;
-	    }
-	}
+        if (strcmp($new_password1, $new_password2)) {
+            $gErrors["new_password2"] = gTranslate('core', "Passwords do not match!");
+            $errorCount++;
+        } else {
+            $gErrors["new_password1"] = $gallery->userDB->validPassword($new_password1);
+            if ($gErrors["new_password1"]) {
+                $errorCount++;
+            }
+        }
     }
 
     if (!$errorCount) {
@@ -85,12 +86,12 @@ if (!empty($save)) {
 	if (!strcmp($old_uname, $gallery->session->username)) {
 	    $gallery->session->username = $uname;
 	}
-	$msg = _("User information succesfully updated.");
+	$msg = gTranslate('core', "User information succesfully updated.");
         $infoLineType = 'success';
     }
     else {
-	$msg = gallery_error(_("User information was not succesfully updated !!"));
-	$infoLineType = 'error';
+        $msg = gallery_error(gTranslate('core', "User information was not succesfully updated!"));
+        $infoLineType = 'error';
     }
 } else if (isset($dismiss)) {
     header("Location: " . makeGalleryHeaderUrl("manage_users.php"));
@@ -100,7 +101,7 @@ if (!empty($save)) {
 $tmpUser = $gallery->userDB->getUserByUsername($uname);
 
 if (!$tmpUser) {
-    echo gallery_error(_("Invalid user") ." <i>$uname</i>");
+    echo gallery_error(gTranslate('core', "Invalid user") ." <i>$uname</i>");
     exit;
 }
 
@@ -138,21 +139,19 @@ doctype();
 ?>
 <html>
 <head>
-  <title><?php echo _("Modify User") ?></title>
+  <title><?php echo gTranslate('core', "Modify User") ?></title>
   <?php common_header(); ?>
 </head>
 <body dir="<?php echo $gallery->direction ?>" class="popupbody">
-<div class="popuphead"><?php echo _("Modify User") ?></div>
+<div class="popuphead"><?php echo gTranslate('core', "Modify User") ?></div>
 <div class="popup" align="center">
 <?php 
 	echo infoLine($msg, $infoLineType);
-	echo _("You can change any information about the user using this form.") 
+	echo gTranslate('core', "You can change any information about the user using this form.") 
 ?>
 <br>
 
-<?php echo makeFormIntro("modify_user.php", 
-				array("name" => "usermodify_form", 
-					"method" => "POST")); ?>
+<?php echo makeFormIntro("modify_user.php", array('name' => 'usermodify_form')); ?>
 
 <input type="hidden" name="old_uname" value="<?php echo $uname ?>">
 
@@ -161,9 +160,9 @@ doctype();
 <?php include(dirname(__FILE__) . '/html/userData.inc'); ?>
 
 <br>
-<input type="submit" name="save" value="<?php echo _("Save") ?>">
-<input type="submit" name="dismiss" value="<?php echo _("Back to usermanagement") ?>">
-<input type="button" value="<?php echo _("Done") ?>" onclick='parent.close()'>
+<?php echo gSubmit('save', gTranslate('core', "Save")); ?>
+<?php echo gSubmit('dismiss', gTranslate('core', "Back to usermanagement")); ?>
+<?php echo gButton('close', gTranslate('core', "Done"), 'parent.close()'); ?>
 </form>
 </div>
 
