@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
  * This additional file was created by Joan McGalliard
  *	http://www.mcgalliard.org
  *
- * $Id: multi_create_user.php,v 1.23.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: multi_create_user.php 193 2008-07-15 22:02:33Z jens $
  */
 ?>
 <?php
@@ -139,8 +139,8 @@ if ($formaction == 'create') {
         }
         echo "\n<p>";
         echo sprintf(_("%s added, %s skipped"),
-        pluralize_n2(ngettext("1 user", "%d users", $total_added), $total_added),
-        pluralize_n2(ngettext("1 user", "%d users", $total_skipped), $total_skipped));
+	    gTranslate('core', "1 user", "%d users", $total_added),
+	    gTranslate('core', "1 user", "%d users", $total_skipped));
         echo "\n</p>";      
 ?>
 
@@ -184,10 +184,9 @@ $allowChange["admin"] = true;
 
 echo makeFormIntro("multi_create_user.php", array(
     "name" => "usercreate_form",
-    "enctype" => "multipart/form-data",
-    "method" => "POST",));
+    "enctype" => "multipart/form-data"));
 
-$canCreateChoices = array(1 => _("yes"), 0 => _("no"));
+$canCreateChoices = array(1 => _("Yes"), 0 => _("No"));
 $canCreate = 0;
 ?>
 	<input type="hidden" name="MAX_FILE_SIZE" value="10000000">
