@@ -1,37 +1,46 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: fs_win32.php,v 1.31.2.3 2005/09/17 13:12:36 jenst Exp $
+ * $Id: fs_win32.php 193 2008-07-15 22:02:33Z jens $
+ */
+
+/**
+ * @package Filesystem_windows
+ */
+
+/**
+ * Copies a file from $source to $dest.
+ * @param  string	$source	Full path to source file.
+ * @param  string	$dest	Full path to destination file.
+ * @return boolean	$result	true on success, otherwise false
  */
-?>
-<?php
 function fs_copy($source, $dest) {
-	$umask = umask(0133);
-	$results = copy(
-		fs_import_filename($source, 0), 
-		fs_import_filename($dest, 0));
-	umask($umask);
+	$result = copy(fs_import_filename($source, 0), fs_import_filename($dest, 0));
+	chmod (fs_import_filename($dest, 0), 0644);
+
+	return $result;
 }
 
 function fs_file_exists($filename) {
 	$filename = fs_import_filename($filename, 0);
 	debug("Checking for [$filename] == " . @file_exists($filename));
+
 	return @file_exists($filename);
 }
 
@@ -50,20 +59,29 @@ function fs_fopen($filename, $mode, $use_include_path=0) {
 	return fopen($filename, $mode, $use_include_path);
 }
 
-function fs_file_get_contents($filename) {
+function fs_file_get_contents($filename, $legacy = false) {
 	$filename = fs_import_filename($filename, 0);
+	$content = '';
+
+	if (!fs_file_exists($filename) || broken_link($filename)) {
+		return $content;
+	}
 
 	if (function_exists("file_get_contents")) {
-		$tmp = @file_get_contents($filename);
-	} else {
-		if ($fd = fs_fopen($fname, "rb")) {
+		$content = @file_get_contents($filename);
+	}
+	else {
+		$mode = ($legacy) ? 'rt' : 'rb';
+	
+		if ($fd = fs_fopen($filename, $mode)) {
 			while (!feof($fd)) {
-				$tmp .= fread($fd, 65536);
+				$content .= fread($fd, 65536);
 			}
 			fclose($fd);
 		}
 	}
-	return $tmp;
+	
+	return $content;
 }
 
 function fs_is_dir($filename) {
@@ -83,41 +101,47 @@ function fs_is_readable($filename) {
 
 function fs_is_writable($filename) {
 	$filename = fs_import_filename($filename, 0);
-        return @is_writable($filename);
+		return @is_writable($filename);
 }
 
-function fs_opendir($path) {
-    $path = fs_import_filename($path, 0);
-
-    $dir_handle = @opendir($path);
-    if ($dir_handle) {
-        return $dir_handle;
-    }
-    else {
-        echo gallery_error(sprintf(_("Gallery was not able to open dir: %s. <br>Please check permissions and existence"), $path));
-    }
+function fs_opendir($path, $withDebug = true) {
+	$path = fs_import_filename($path, 0);
+	$dir_handle = @opendir($path);
+	
+	if ($dir_handle) {
+		return $dir_handle;
+	}
+	else {
+		if($withDebug) {
+			echo "\<br>". gallery_error(sprintf(gTranslate('core', "Gallery was not able to open dir: %s. <br>Please check permissions and existence"), $path));
+		}
+		
+		return false;
+	}
 }
 
 function fs_rename($oldname, $newname) {
 	$oldname = fs_import_filename($oldname, 0);
 	$newname = fs_import_filename($newname, 0);
 
-	/* 
-	 * It appears that win32 doesn't like it when you rename 
-	 * a file to end with ".dat.bak".  Why?  This is very 
+	/*
+	 * It appears that win32 doesn't like it when you rename
+	 * a file to end with ".dat.bak".  Why?  This is very
 	 * annoying.
 	 */
 	$newname = str_replace(".dat.bak", ".bak", $newname);
 
 	debug("Rename $oldname -> $newname");
 	clearstatcache();
+
 	if (file_exists("$newname.bak")) {
 		unlink("$newname.bak");
 	}
 	if (file_exists("$newname")) {
 		return rename($newname, "$newname.bak") &&
 			rename($oldname, $newname);
-	} else {
+	}
+	else {
 		return rename($oldname, $newname);
 	}
 }
@@ -127,8 +151,9 @@ function fs_stat($filename) {
 	return stat($filename);
 }
 
-/* This function deletes a file.
-** The errormessage is surpressed !
+/**
+ * This function deletes a file.
+ * The errormessage is surpressed !
 */
 function fs_unlink($filename) {
 	$filename = fs_import_filename($filename, 0);
@@ -143,11 +168,16 @@ function fs_executable($filename) {
 	return $filename;
 }
 
-function fs_mkdir($filename, $perms) {
-	$umask = umask(0);
-	$results = mkdir(fs_import_filename($filename, 0), $perms);
-	umask($umask);
-	return $results;
+/**
+ * Creates a directory
+ * @param  string	$dirname
+ * @param  string	$perms		Optional perms, given in octal format
+ * @return boolean	$result		true on success, otherwise false
+ */
+function fs_mkdir($dirname, $perms = 0700) {
+	$result = @mkdir(fs_import_filename($dirname, 0), $perms);
+
+	return $result;
 }
 
 function fs_import_filename($filename, $for_exec=1) {
@@ -176,14 +206,13 @@ function fs_import_filename($filename, $for_exec=1) {
 		if (strstr($filename, " ")) {
 			$filename = "\"$filename\"";
 		}
-	}	
+	}
 
 	debug("Import after: $filename");
 	return $filename;
 }
 
 function fs_export_filename($filename) {
-	
 	# Convert "d:\winnt\temp" to "d:/winnt/temp"
 	#
 	while (strstr($filename, "\\\\")) {
@@ -194,18 +223,19 @@ function fs_export_filename($filename) {
 	return $filename;
 }
 
-function fs_exec($cmd, &$results, &$status, $debugfile) {
-
+function fs_exec($cmd, &$results, &$status) {
 	// We can't redirect stderr with Windows.  Hope that we won't need to.
 	return exec($cmd, $results, $status);
 }
 
 function fs_tempdir() {
-	return export_filename($gallery->app->tmpDir); 
+	global $gallery;
+
+	return export_filename($gallery->app->tmpDir);
 }
 
 function fs_is_executable($filename) {
-	return eregi(".(exe|com|vbs)$", $filename);
+	return eregi("\.(exe|com|vbs|vb|bat|cmd)$", $filename);
 }
 
 function debug($msg) {
@@ -213,4 +243,26 @@ function debug($msg) {
 		print "<br>$msg<br>";
 	}
 }
+
+/**
+ * Files in windows cant start with a .
+ * @param   string	$filename
+ * @return	boolean
+ * @author  Jens Tkotz
+*/
+function fs_fileIsHidden($filename) {
+	return false;
+}
+
+
+/**
+ * Deletes a directory
+ *
+ * @param String $dir
+ * @return boolean
+ */
+function fs_rmdir($dir) {
+	return rmdir(fs_export_filename($dir));
+}
+
 ?>
