@@ -1,45 +1,43 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  *
  * This file Copyright (C) 2003-2004 Joan McGalliard
- * 
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: poll_properties.php,v 1.24.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: poll_properties.php 234 2008-07-27 12:04:14Z jens $
  */
-?>
-<?php
 
 require_once(dirname(__FILE__) . '/init.php');
 
-list($apply, $nv_pairs, $voter_class, $poll_scale, $poll_show_results, $poll_num_results, $poll_orientation, $poll_hint, $poll_type) = 
+list($apply, $nv_pairs, $voter_class, $poll_scale, $poll_show_results, $poll_num_results, $poll_orientation, $poll_hint, $poll_type) =
   getRequestVar(array('apply', 'nv_pairs', 'voter_class', 'poll_scale', 'poll_show_results', 'poll_num_results', 'poll_orientation', 'poll_hint', 'poll_type'));
 
 // Hack check
 if (!$gallery->user->canWriteToAlbum($gallery->album)) {
-	echo _("You are not allowed to perform this action!");
+	echo gTranslate('core', "You are not allowed to perform this action!");
 	exit;
 }
-	
-$error="";
+
+$error = '';
 if (!empty($apply)) {
-	for ($i=0; $i<$gallery->album->getPollScale() ; $i++) {
+	for ($i = 0; $i < $gallery->album->getPollScale() ; $i++) {
 		//convert values to numbers
-		$nv_pairs[$i]["value"]=0+$nv_pairs[$i]["value"];
+		$nv_pairs[$i]["value"] = 0+$nv_pairs[$i]["value"];
 	}
 	$gallery->album->fields["poll_nv_pairs"]=$nv_pairs;
 	$gallery->album->fields["poll_hint"]=$poll_hint;
@@ -47,10 +45,10 @@ if (!empty($apply)) {
 	if ($voter_class == "Logged in" &&
 	    $gallery->album->fields["voter_class"] == "Everybody" &&
 	    sizeof($gallery->album->fields["votes"]) > 0) {
-		$error="<br>" .
-			sprintf(_("Warning: you have changed voters from %s to %s.  It is advisable to reset the poll to remove all previous votes."),
-					"<i>". _("Everybody") ."</i>",
-					"<i>". _("Logged in") ."</i>");
+		$error = "<br>" .
+			sprintf(gTranslate('core', "Warning: you have changed voters from %s to %s.  It is advisable to reset the poll to remove all previous votes."),
+					"<i>". gTranslate('core', "Everybody") ."</i>",
+					"<i>". gTranslate('core', "Logged in") ."</i>");
 	}
 	$gallery->album->fields["voter_class"] = $voter_class;
 	$gallery->album->fields["poll_scale"] = $poll_scale;
@@ -60,8 +58,8 @@ if (!empty($apply)) {
 	$gallery->album->save(array(i18n("Poll properties change")));
 
 	if (getRequestVar('setNested')) {
-		$gallery->album->setNestedPollProperties();
-       	}
+	    $gallery->album->setNestedPollProperties();
+	}
 	reload();
 }
 
@@ -69,46 +67,46 @@ doctype();
 ?>
 <html>
 <head>
-  <title><?php echo _("Poll Properties") ?></title>
+  <title><?php echo gTranslate('core', "Poll Properties") ?></title>
   <?php common_header(); ?>
 </head>
 <body dir="<?php echo $gallery->direction ?>" class="popupbody">
-<div class="popuphead"><?php echo _("Poll Properties"); ?></div>
+<div class="popuphead"><?php echo gTranslate('core', "Poll Properties"); ?></div>
 <div class="popup" align="center">
 <?php
 if (! empty($error)) {
 	echo "<p>". gallery_error($error) . "</p>";
 }
-	echo makeFormIntro("poll_properties.php", 
-			array("name" => "theform", "method" => "POST"),
+	echo makeFormIntro("poll_properties.php",
+			array("name" => "theform"),
 			array("type" => "popup")); ?>
 <table border="0">
 <tr>
-	<td><?php echo _("Type of poll for this album") ?></td>
-	<td><select name="poll_type"><?php selectOptions($gallery->album, "poll_type", array("rank" => _("Rank"), "critique" => _("Critique"))) ?></select></td>
+	<td><?php echo gTranslate('core', "Type of poll for this album") ?></td>
+	<td><select name="poll_type"><?php selectOptions($gallery->album, "poll_type", array("rank" => gTranslate('core', "Rank"), "critique" => gTranslate('core', "Critique"))) ?></select></td>
 </tr>
 <tr>
-	<td><?php echo _("Number of voting options") ?></td>
+	<td><?php echo gTranslate('core', "Number of voting options") ?></td>
 	<td><input type="text" name="poll_scale" value="<?php echo $gallery->album->getPollScale() ?>"></td>
 </tr>
 <tr>
-	<td><?php echo _("Show results of voting to all visitors?") ?></td>
-	<td><select name="poll_show_results"><?php selectOptions($gallery->album, "poll_show_results", array("no" => _("no"), "yes" => _("yes"))) ?></select></td>
+	<td><?php echo gTranslate('core', "Show results of voting to all visitors?") ?></td>
+	<td><select name="poll_show_results"><?php selectOptions($gallery->album, "poll_show_results", array("no" => gTranslate('core', "No"), "yes" => gTranslate('core', "Yes"))) ?></select></td>
 </tr>
 <tr>
-	<td width="50%"><?php echo _("Number of lines of results graph to display on the album page") ?></td>
+	<td width="50%"><?php echo gTranslate('core', "Number of lines of results graph to display on the album page") ?></td>
 	<td><input type="text" name="poll_num_results" value="<?php echo $gallery->album->getPollNumResults() ?>"></td>
 </tr>
 <tr>
-	<td><?php echo _("Who can vote") ?></td>
-	<td><select name="voter_class"><?php selectOptions($gallery->album, "voter_class", array("Logged in" => _("Logged in"), "Everybody" => _("Everybody"), "Nobody" => _("Nobody"))) ?></select></td>
+	<td><?php echo gTranslate('core', "Who can vote") ?></td>
+	<td><select name="voter_class"><?php selectOptions($gallery->album, "voter_class", array("Logged in" => gTranslate('core', "Logged in"), "Everybody" => gTranslate('core', "Everybody"), "Nobody" => gTranslate('core', "Nobody"))) ?></select></td>
 </tr>
 <tr>
-	<td><?php echo _("Orientation of vote choices") ?></td>
-	<td><select name="poll_orientation"><?php selectOptions($gallery->album, "poll_orientation", array("horizontal" => _("Horizontal"), "vertical" => _("Vertical"))) ?></select></td>
+	<td><?php echo gTranslate('core', "Orientation of vote choices") ?></td>
+	<td><select name="poll_orientation"><?php selectOptions($gallery->album, "poll_orientation", array("horizontal" => gTranslate('core', "Horizontal"), "vertical" => gTranslate('core', "Vertical"))) ?></select></td>
 </tr>
 <tr>
-	<td><?php echo _("Vote hint") ?></td>
+	<td><?php echo gTranslate('core', "Vote hint") ?></td>
 	<td><input type="text" name="poll_hint" value="<?php echo $gallery->album->getPollHint() ?>" size="45"></td>
 </tr>
 </table>
@@ -117,8 +115,8 @@ if (! empty($error)) {
 
 <table border="0">
 <tr>
-	<td><?php echo _("Displayed Value"); ?></td>
-	<td><?php echo _("Points"); ?></td>
+	<td><?php echo gTranslate('core', "Displayed Value"); ?></td>
+	<td><?php echo gTranslate('core', "Points"); ?></td>
 </tr>
 <?php
 $nv_pairs=$gallery->album->getVoteNVPairs();
@@ -126,7 +124,7 @@ for ($i=0; $i<$gallery->album->getPollScale() ; $i++) {
 ?>
 <tr>
 	<td><input type="text" name="nv_pairs[<?php echo $i?>][name]" value="<?php echo $nv_pairs[$i]["name"] ?>"></td>
-	<td><input type=text name="nv_pairs[<?php echo $i?>][value]" value="<?php echo $nv_pairs[$i]["value"] ?>"></td>
+	<td><input type="text" name="nv_pairs[<?php echo $i?>][value]" value="<?php echo $nv_pairs[$i]["value"] ?>"></td>
 </tr>
 <?php
 }
@@ -134,12 +132,12 @@ for ($i=0; $i<$gallery->album->getPollScale() ; $i++) {
 </table>
 
 <p>
-<input type="checkbox" name="setNested" value="1" class="popup"><?php echo _("Apply values to nested albums.") ?>
+<input type="checkbox" name="setNested" value="1" class="popup"><?php echo gTranslate('core', "Apply values to nested albums.") ?>
 </p>
 
-<input type="submit" name="apply" value="<?php echo _("Apply") ?>">
-<input type="reset" value="<?php echo _("Undo") ?>">
-<input type="submit" value="<?php echo _("Close") ?>" onclick='parent.close()'>
+<?php echo gSubmit('apply', gTranslate('core', "Apply")); ?>
+<?php echo gReset('reset', gTranslate('core', "Undo")); ?>
+<?php echo gButton('close', gTranslate('core', "Close"), 'parent.close()'); ?>
 
 </form>
 </div>
