@@ -1,39 +1,44 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: publish_xp.php,v 1.39.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: publish_xp.php 278 2008-08-03 19:10:51Z jens $
  */
-?>
-<?php
 
 require_once(dirname(__FILE__) . '/init.php');
 
-list($uname, $password, $langid, $lcid, $cmd, $set_albumName, $setCaption, $newAlbumTitle, $createNewAlbum, $album ) = getRequestVar(array('uname', 'password', 'langid', 'lcid', 'cmd', 'set_albumName', 'setCaption', 'newAlbumTitle', 'createNewAlbum', 'album'));
+list($uname, $password, $langid, $lcid, $cmd, $set_albumName, $setCaption, $newAlbumTitle, $createNewAlbum, $album ) =
+	getRequestVar(array('uname', 'password', 'langid', 'lcid', 'cmd', 'set_albumName', 'setCaption', 'newAlbumTitle', 'createNewAlbum', 'album'));
+
+if(!isXSSclean($langid) || !isXSSclean($lcid)) {
+	printPopupStart(gTranslate('core', "Windows XP publishing wizard"));
+	showInvalidReqMesg();
+	exit;
+}
 
 if (isset($_SERVER["HTTPS"] ) && stristr($_SERVER["HTTPS"], "on")) {
     $proto = "https";
-} else {
+}
+else {
     $proto = "http";
 }
 
 if(empty($cmd)){
-
   header("Cache-control: private");
   header("Content-Type: application/octet-stream");
   header("Content-Disposition: filename=install_registry.reg");
@@ -42,7 +47,7 @@ if(empty($cmd)){
   $lines[] = '';
   $lines[] = '[HKEY_CURRENT_USER\Software\Microsoft\Windows\CurrentVersion\Explorer\PublishingWizard\PublishingWizard\Providers\\' . $gallery->app->galleryTitle . ']';
   $lines[] = '"displayname"="' . $gallery->app->galleryTitle . '"';
-  $lines[] = '"description"="' . sprintf(_("Publish Your Photos and Movies to %s."),  $gallery->app->galleryTitle) . '"';
+  $lines[] = '"description"="' . sprintf(gTranslate('core', "Publish Your Photos and Movies to %s."),  $gallery->app->galleryTitle) . '"';
   $lines[] = '"href"="' . makeGalleryUrl("publish_xp.php", array("cmd" => "publish")) . '"';
   $lines[] = '"icon"="' . $proto . '://' . $_SERVER['SERVER_NAME'] . '/favicon.ico"';
   print join("\r\n", $lines);
@@ -53,7 +58,7 @@ doctype();
 ?>
 <html>
 <head>
-  <title><?php echo sprintf(_("Login to %s"), $gallery->app->galleryTitle) ?></title>
+  <title><?php printf(gTranslate('core', "Login to %s"), $gallery->app->galleryTitle) ?></title>
   <?php common_header(); ?>
 </head>
 
@@ -69,7 +74,7 @@ $ONNEXT_SCRIPT="";
 $SCRIPT_CMD="";
 
 //-- login --
-if (!strcmp($cmd, "login")) {
+if ($cmd == 'login') {
 
 	if ($uname && $password) {
 		$tmpUser = $gallery->userDB->getUserByUsername($uname);
@@ -82,13 +87,14 @@ if (!strcmp($cmd, "login")) {
                         // I think this actually does the "login'
 			$gallery->user = $gallery->userDB->getUserByUsername($gallery->session->username);
                         $ONBACK_SCRIPT="history.go(-1);";
-		} else {
-			echo gallery_error(_("Username and Password are not correct."));
+		}
+		else {
+			echo gallery_error(gTranslate('core', "Username and Password are not correct."));
 			$returnval = "Login Incorrect";
 			$WIZARD_BUTTONS="false,true,false";
 		}
 	} else {
-		echo gallery_error(_("Please Enter Username and Password"));
+		echo gallery_error(gTranslate('core', "Please Enter Username and Password"));
 		$returnval = "Login Incorrect";
 		$WIZARD_BUTTONS="false,true,false";
 	}
@@ -96,17 +102,17 @@ if (!strcmp($cmd, "login")) {
 }
 
 if (!strcmp($cmd,"publish") || (isset($returnval) && $returnval == "Login Incorrect") ) { ?>
-<p align="center" class="popuphead"><?php echo sprintf(_("Login to %s"), $gallery->app->galleryTitle) ?></p>
+<p align="center" class="popuphead"><?php echo sprintf(gTranslate('core', "Login to %s"), $gallery->app->galleryTitle) ?></p>
 
-<?php echo  makeFormIntro("publish_xp.php", array("id" => "login", "method" => "POST")); ?>
+<?php echo  makeFormIntro('publish_xp.php', array('id' => 'login')); ?>
 
 <table border="0" align="center">
 <tr>
-	<td><?php echo _("Username:") ?></td>
+	<td><?php echo gTranslate('core', "Username:") ?></td>
 	<td><input type="text" name="uname" value=""></td>
 </tr>
 <tr>
-	<td><?php echo _("Password:") ?></td>
+	<td><?php echo gTranslate('core', "Password:") ?></td>
 	<td><input type="password" name="password" value=""></td>
 </tr>
 </table>
@@ -116,7 +122,7 @@ if (!strcmp($cmd,"publish") || (isset($returnval) && $returnval == "Login Incorr
 	<input type="hidden" name="cmd" value="login">
 </form>
 
-<?php 
+<?php
 	$ONNEXT_SCRIPT="login.submit();";
 	$SCRIPT_CMD="this.login.uname.focus();";
 }
@@ -126,7 +132,7 @@ if (!strcmp($cmd,"publish") || (isset($returnval) && $returnval == "Login Incorr
 
 if (!strcmp($cmd, "fetch-albums")) {
 ?>
-<p align="center" class="popuphead"><?php echo _("Select the Album to which to Publish") ?></p>
+<p align="center" class="popuphead"><?php echo gTranslate('core', "Select the Album to which to Publish") ?></p>
 
 <div class="popup" align="center">
 <form id="folder">
@@ -140,6 +146,7 @@ if (!strcmp($cmd, "fetch-albums")) {
         $myAlbum=$albumDB->getAlbum($gallery->user, $i);
         $albumName = $myAlbum->fields['name'];
         $albumTitle = $myAlbum->fields['title'];
+
         if ($gallery->user->canAddToAlbum($myAlbum)) {
 		echo "\t<option ";
 		if (isset($album) && $albumName == $album) echo "selected ";
@@ -151,26 +158,26 @@ if (!strcmp($cmd, "fetch-albums")) {
 ?>
 	</select><br>
 
-	<input id="setCaption" type="checkbox" name="setCaption" checked value="1"><?php echo _("Use filenames as captions") ?>
-	
+	<input id="setCaption" type="checkbox" name="setCaption" checked value="1"><?php echo gTranslate('core', "Use filenames as captions") ?>
+
 	<br><br>
-	<input type="button" value="<?php echo _("Create New Album") ?>" onClick="folder.cmd.value='new-album';folder.submit();">
+	<?php echo gButton('create', gTranslate('core', "Create New Album"), "folder.cmd.value='new-album';folder.submit()"); ?>
 
 	<input type="hidden" name="cmd" value="select-album">
 </form>
 </div>
 <?php
-    $ONNEXT_SCRIPT="folder.submit();"; 
+	$ONNEXT_SCRIPT="folder.submit();";
     $ONBACK_SCRIPT="window.location.href = \"publish_xp.php?cmd=publish\";";
     $WIZARD_BUTTONS="true,true,true";
 }
 
 function appendNestedAlbums($level, $permission, $albumName, $albumCompare = "") {
     global $gallery;
- 
+
     $myAlbum = new Album();
     $myAlbum->load($albumName);
-   
+
     $numPhotos = $myAlbum->numPhotos(1);
 
     for ($i=1; $i <= $numPhotos; $i++) {
@@ -184,7 +191,9 @@ function appendNestedAlbums($level, $permission, $albumName, $albumCompare = "")
 				$nextTitle = $nextTitle;
                 $nextName = $nestedAlbum->fields['name'];
 				echo "\t<option ";
-				if ($nextName == $albumCompare) echo "selected ";
+				if ($nextName == $albumCompare) {
+					echo "selected ";
+				}
 				echo "value=\"$nextName\">$nextTitle</option>\n";
                 appendNestedAlbums($level + 1, $permission, $myName, $albumCompare);
             }
@@ -199,19 +208,19 @@ if (!strcmp($cmd, "select-album")) {
 
 	// Do we have a logged in user?
 	if (!$gallery->user->isLoggedIn()) {
-		$error= _("Not Logged In!");
+		$error= gTranslate('core', "Not Logged In!");
 	}
 
 	if (empty($gallery->album) || empty($set_albumName)) {
-		$error = _("No album specified!");
+		$error = gTranslate('core', "No album specified!");
 	} elseif (!$gallery->user->canAddToAlbum($gallery->album) && $set_albumName) {
-	    $error = sprintf(_("This user cannot add photos in %s."), 
+	    $error = sprintf(gTranslate('core', "This user cannot add photos in %s."),
 			    $gallery->album->fields[title]);
 	}
 
 	if (!empty($error)) {
 		echo gallery_error($error). "<br>";
-		echo _("Press the 'Back' button and try again!");
+		echo gTranslate('core', "Press the 'Back' button and try again!");
 		$ONBACK_SCRIPT="window.location.href = \"publish_xp.php?cmd=fetch-albums\";";
     		$WIZARD_BUTTONS="true,false,true";
 	} else {
@@ -230,59 +239,58 @@ if (!strcmp($cmd, "select-album")) {
 
 if (!strcmp($cmd, "new-album")) {
 
-        // Do we have a logged in user?
-        if (!$gallery->user->isLoggedIn()) {
-		$error= _("Not Logged In!");
+    // Do we have a logged in user?
+    if (!$gallery->user->isLoggedIn()) {
+        $error= gTranslate('core', "Not Logged In!");
 
-        	// Permission checks
-		// can the user create albums in the ROOT level
-        } elseif (isset($createNewAlbum) && ($set_albumName == '_xp_wiz_root') && !($gallery->user->canCreateAlbums()) ) {
-            $error = _("User cannot create ROOT level album.") ."<br>\n";
+        // Permission checks
+        // can the user create albums in the ROOT level
+    } elseif (isset($createNewAlbum) && ($set_albumName == '_xp_wiz_root') && !($gallery->user->canCreateAlbums()) ) {
+        $error = gTranslate('core', "User cannot create ROOT level album.") ."<br>\n";
 
-		// can the user create nested albums in the specified album
-        } elseif (isset($createNewAlbum) && 
-			isset($set_albumName) && 
-			$set_albumName != '_xp_wiz_root' && 
-			!($gallery->user->canCreateSubAlbum($gallery->album))
-	) {
-            $error = sprintf(_("User cannot create nested album in %s."),
-			    $gallery->album->fields[title]);
-	} elseif (isset($createNewAlbum) && empty($set_albumName)) {
-		$error = _("No Parent Album Specified!");
-        } elseif (isset($createNewAlbum)) {
-		if ($set_albumName == '_xp_wiz_root') {
-			$parentName = '';
-		} elseif (isset($set_albumName)) {
-			$parentName = $set_albumName;
-		}
+        // can the user create nested albums in the specified album
+    } elseif (isset($createNewAlbum) &&
+    isset($set_albumName) &&
+      $set_albumName != '_xp_wiz_root' &&
+      !($gallery->user->canCreateSubAlbum($gallery->album))) {
+        $error = sprintf(gTranslate('core', "User cannot create nested album in %s."),
+        $gallery->album->fields[title]);
+    } elseif (isset($createNewAlbum) && empty($set_albumName)) {
+        $error = gTranslate('core', "No Parent Album Specified!");
+    } elseif (isset($createNewAlbum)) {
+        if ($set_albumName == '_xp_wiz_root') {
+            $parentName = '';
+        } elseif (isset($set_albumName)) {
+            $parentName = $set_albumName;
+        }
 
-		if ($set_albumName) {
-			$success = createNewAlbum($parentName);
-		}
+        if ($set_albumName) {
+            $success = createNewAlbum($parentName);
+        }
 
-                if ($newAlbumTitle) {
-			$newAlbumTitle = removeTags($newAlbumTitle);
-                        $gallery->album->fields["title"] = $newAlbumTitle;
-                	$gallery->album->save();
-                }
-	} else {
+        if ($newAlbumTitle) {
+            $newAlbumTitle = strip_tags($newAlbumTitle);
+            $gallery->album->fields["title"] = $newAlbumTitle;
+            $gallery->album->save();
+        }
+    } else {
 		if (empty($newAlbumTitle)) $newAlbumTitle = "Untitled";
 		?>
-<p class="popuphead" align="center"><?php echo _("Create New Album") ?></p>
+<p class="popuphead" align="center"><?php echo gTranslate('core', "Create New Album") ?></p>
 
 <div class="popup" align="center">
 <form id="folder">
-	<?php echo _("Enter New Album Title") ?>: 
+	<?php echo gTranslate('core', "Enter New Album Title") ?>:
 	<input id="newAlbumTitle" type="text" name="newAlbumTitle" value="<?php echo $newAlbumTitle ?>" size="25">
 
-	<br><br><?php echo _("Select Parent Album") ?>:
+	<br><br><?php echo gTranslate('core', "Select Parent Album") ?>:
 	<br><br>
 	<select id="album" name="set_albumName" size="10" width="40">
 		<?php
                 $albumDB = new AlbumDB(FALSE);
                 $mynumalbums = $albumDB->numAlbums($gallery->user);
                 if ($gallery->user->canCreateAlbums()) {
-			echo "<option value=\"_xp_wiz_root\">" . _("NEW TOP LEVEL ALBUM") ."</option>\n";
+			echo "<option value=\"_xp_wiz_root\">" . gTranslate('core', "NEW TOP LEVEL ALBUM") ."</option>\n";
                 }
                 // display all albums that the user can move album to
                 for ($i=1; $i<=$mynumalbums; $i++) {
@@ -310,7 +318,7 @@ if (!strcmp($cmd, "new-album")) {
 
         if (!empty($error)) {
                 echo gallery_error($error);
-		echo _("Press the 'Back' button and try again!");
+		echo gTranslate('core', "Press the 'Back' button and try again!");
 		echo "<form id=\"folder\">";
 		echo "<input type=\"hidden\" name=\"cmd\" value=\"new-album\">\n";
 		echo "<input type=\"hidden\" name=\"newAlbumTitle\" value=\"$newAlbumTitle\">\n";
@@ -323,7 +331,7 @@ if (!strcmp($cmd, "new-album")) {
 		echo "<input type=\"hidden\" name=\"cmd\" value=\"fetch-albums\">\n";
                 echo "</form>\n";
 
-		if ($success) {	
+		if ($success) {
 			$SCRIPT_CMD = "folder.submit();";
 		}
         }
@@ -337,11 +345,11 @@ if (!strcmp($cmd, "add-item")) {
 
 	// Hack check
 	if (!$gallery->user->canAddToAlbum($gallery->album)) {
-	    $error = _("User cannot add to album");
+	    $error = gTranslate('core', "User cannot add to album");
 	}
 
 	else if (empty($_FILES['userfile']['name'])) {
-	    	$error = _("No file specified");
+	    	$error = gTranslate('core', "No file specified");
 	}
 
 	else {
@@ -350,11 +358,15 @@ if (!strcmp($cmd, "add-item")) {
 		$tag = ereg_replace(".*\.([^\.]*)$", "\\1", $name);
 		$tag = strtolower($tag);
 
-		if (!empty($name)) {
-    			processNewImage($file, $tag, $name, "", $setCaption);
+		if (!empty($name) && isXSSclean($name,0 )) {
+			$error = processNewImage($file, $tag, $name, '', $setCaption);
+			if(empty($error)) {
+				$gallery->album->save(array(i18n("Image added")));
+			}
+		}
+		else {
+			$error = gTranslate('core', "Skipping file, as it contains malicious characters.");
 		}
-
-		$gallery->album->save(array(i18n("Image added")));
 
 		if (!empty($temp_files)) {
     			/* Clean up the temporary url file */
@@ -366,12 +378,12 @@ if (!strcmp($cmd, "add-item")) {
 
 	if (!empty($error)) {
 	    	echo gallery_error($error);
-	} else {
+	}
+	else {
     		echo "SUCCESS";
 	}
 }
-?>
-<?php
+
 function forceQuestionMark($url) {
     if (!strstr("?", $url)) {
 	$url .= "?";
@@ -438,7 +450,7 @@ function OnNext() {
 }
 
 function window.onload() {
-   window.external.SetHeaderText("<?php echo $gallery->app->galleryTitle ?> <?php echo _("Photo Upload") ?>","<?php echo _("Upload Photos to") ?> <?php echo $gallery->app->galleryTitle ?>");
+   window.external.SetHeaderText("<?php echo $gallery->app->galleryTitle ?> <?php echo gTranslate('core', "Photo Upload") ?>","<?php echo gTranslate('core', "Upload Photos to") ?> <?php echo $gallery->app->galleryTitle ?>");
    window.external.SetWizardButtons(<?php echo $WIZARD_BUTTONS; ?>);
 }
 
