@@ -1,26 +1,25 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: rss.php,v 1.21.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: rss.php 193 2008-07-15 22:02:33Z jens $
  */
-?>
-<?php
+
 require_once(dirname(__FILE__) . '/init.php');
 
 // Set defaults, if RSS has not been setup via config wizard
@@ -53,7 +52,9 @@ function albumSort($a, $b) {
 }
 
 function bestDate($album) {
-	if (isset($album->fields['clicks_date']) && strtotime($album->fields["clicks_date"]) > strtotime($album->fields["last_mod_time"])) {
+	if (isset($album->fields['clicks_date']) &&
+		strtotime($album->fields["clicks_date"]) > strtotime($album->fields["last_mod_time"]))
+	{
 		return $album->fields['clicks_date'];
 	}
 	else {
@@ -62,11 +63,9 @@ function bestDate($album) {
 }
 
 function getThumbs($album) {
-	$tags = "border=0 vspace=2 hspace=0 align=top";
-	
-	$photos = "";
+	$photos = '';
 	$photoCount = $album->numPhotos(1);
-	
+
 	for ($i = 1; $i <= $photoCount; $i += 1) {
 		$photo = $album->getPhoto($i);
 		if (!$photo->isHidden() && !$photo->isMovie() && $photo->thumbnail) {
@@ -74,36 +73,34 @@ function getThumbs($album) {
 			$photos .= "<a href=\"" . makeAlbumUrl($album->fields['name'], $i) . "\">" . $imgtag . "</a>\n";
 		}
 	}
-	
+
 	return $photos;
 }
 
 function getThumbsAndCaptions($album) {
-	$tags = "border=0 vspace=2 hspace=0 align=top";
-	
-	$photos = "";
+	$photos = '';
 	$photoCount = $album->numPhotos(1);
-	
+
 	for ($i = 1; $i <= $photoCount; $i += 1) {
 		$photo = $album->getPhoto($i);
 		if (!$photo->isHidden() && !$photo->isMovie() && is_object($photo->thumbnail)) {
 			$imgtag = $album->getThumbnailTag($i, 0, $tags);
 			$caption = $photo->getCaption();
-			$photos .= "<a href=\"" . makeAlbumUrl($album->fields['name'], $i) .
-"\">" . $imgtag . "</a>$caption<br />\n";
+			$photos .= "<a href=\"" . makeAlbumUrl($album->fields['name'], $i) . "\">" . $imgtag . "</a>";
+			$photos .= $caption . "<br>\n";
 		}
 	}
-	
+
 	return $photos;
 }
 
 function makeDCDate($unixDate) {
 	$dcDate = date("Y-m-d\TH:i:sO", $unixDate);
-	
-	/* CAUTION: This will not work in zones with 
+
+	/* CAUTION: This will not work in zones with
 	 * half-our time offsets
 	 */
-	
+
 	return eregi_replace("..$", ":00", $dcDate);
 }
 
@@ -123,6 +120,12 @@ else {
 	$rssAlbumList = $albumDB->albumList;
 }
 
+if (empty($rssAlbumList)) {
+	printPopupStart(gTranslate('core', "Gallery RSS feed"));
+	showInvalidReqMesg();
+	exit;
+}
+
 foreach ($rssAlbumList as $album) {
 
 	// Save time later.. if we can't read it, don't add it.
@@ -140,7 +143,8 @@ foreach ($rssAlbumList as $album) {
 		"link" => makeAlbumUrl($album->fields["name"]),
 		"guid" => array($album->fields['guid'], array("isPermaLink" => "false")),
 		"!date" => bestDate($album),
-		"title" => htmlspecialchars($album->fields["title"]));
+		"title" => htmlspecialchars($album->fields["title"])
+	);
 
 	// DATE TAGS
 
@@ -154,10 +158,11 @@ foreach ($rssAlbumList as $album) {
 
 	// COMMENTS TAG
 
-	if (method_exists($album, "canViewComments") 
-	   && $album->canViewComments($gallery->user->uid)) {
-		$albumInfo["comments"] = makeGalleryUrl("view_comments.php", 
-		  array("set_albumName" => $album->fields["name"]));
+	if (isset($gallery->app->comments_enabled) && $gallery->app->comments_enabled == "yes" &&
+		method_exists($album, "canViewComments") && $album->canViewComments($gallery->user->uid))
+	{
+		$albumInfo["comments"] = makeGalleryUrl("view_comments.php",
+		array("set_albumName" => $album->fields["name"]));
 	}
 
 	// PHEED AND PHOTO TAGS
@@ -177,7 +182,7 @@ foreach ($rssAlbumList as $album) {
 			$base = $subalbum->getAlbumDirURL("highlight");
 			$albumInfo["photo:imgsrc"] = $highlight->thumbnail->getPath($base);
 			$albumInfo["photo:thumbnail"] = $highlight->getPhotoPath($base);
-			
+
 			$width = $highlight->thumbnail->width;
 			$height = $highlight->thumbnail->height;
 
@@ -187,7 +192,7 @@ foreach ($rssAlbumList as $album) {
 					$ratio = 144 / $width;
 					$width = 144;
 				}
-			
+
 				if ($height > 400 || $ratio != 1) {
 					if (($height * $ratio) > 400) {
 						$ratio = 400 / ($height * $ratio);
@@ -201,9 +206,9 @@ foreach ($rssAlbumList as $album) {
 				$width = floor($width);
 			}
 
-		$albumInfo['pb:thumb'] = $highlight->thumbnail->getPath($base);
-		$albumInfo['pb:height'] = $height;
-		$albumInfo['pb:width'] = $width;
+			$albumInfo['pb:thumb'] = $highlight->thumbnail->getPath($base);
+			$albumInfo['pb:height'] = $height;
+			$albumInfo['pb:width'] = $width;
 		}
 	}
 
@@ -217,22 +222,25 @@ foreach ($rssAlbumList as $album) {
 		if (!$album->transient->photosloaded) {
 			$album->load($album->fields["name"], TRUE);
 		}
-		
+
 		$albumInfo["description"]  = $album->fields["description"] . '<p>';
 		$albumInfo["description"] .= getThumbs($album);
-	} elseif ($gallery->app->rssMode == "thumbs-with-captions") {
+	}
+	elseif ($gallery->app->rssMode == "thumbs-with-captions") {
 		if (!$album->transient->photosloaded) {
 			$album->load($album->fields["name"], TRUE);
 		}
 
 		$albumInfo["description"]  = $album->fields["description"] . '<p>';
 		$albumInfo["description"] .= getThumbsAndCaptions($album);
-	} elseif ($gallery->app->rssMode == "highlight" && isset($highlight)) {
+	}
+	elseif ($gallery->app->rssMode == "highlight" && isset($highlight)) {
 		$url = makeAlbumUrl($album->fields["name"]);
 		$imgtag = $highlight->thumbnail->getTag($base, 0, 0, 'border=0');
 		$albumInfo["description"]  = "<a href=\"$url\">$imgtag</a><br>";
 		$albumInfo["description"] .= $album->fields["description"];
-	} else { # mode = "basic"
+	}
+	else { # mode = "basic"
 		$albumInfo["description"] = $album->fields["description"];
 	}
 
@@ -243,7 +251,9 @@ foreach ($rssAlbumList as $album) {
 
 usort($albumList, "albumSort");
 
-unset($ha); $channel_image = $channel_width = $channel_height = "";
+unset($ha);
+$channel_image = $channel_width = $channel_height = "";
+
 if (isset($gallery->app->rssHighlight) && $gallery->app->rssHighlight != "*") {
 	foreach($albumList as $album) {
 		if ($album["!name"] == $gallery->app->rssHighlight && isset($album["pb:thumb"])) {
@@ -251,7 +261,8 @@ if (isset($gallery->app->rssHighlight) && $gallery->app->rssHighlight != "*") {
 			break;
 		}
 	}
-} elseif (isset($albumList[0]["pb:thumb"])) {
+}
+elseif (isset($albumList[0]["pb:thumb"])) {
 	$ha = $albumList[0];
 }
 
@@ -261,10 +272,10 @@ if (isset($ha)) {
 	$channel_image_height = $ha["pb:height"];
 }
 
-$total_str = pluralize_n2(ngettext(_("1 album"), _("%s albums"), $numAlbums), $numAlbums, _("no albums"));
-$image_str = pluralize_n2(ngettext(_("1 photo"), _("%s photos"), $numPhotos), $numPhotos, _("no photos"));
+$total_str = gTranslate('core', "1 album", "%d albums", $numAlbums, gTranslate('core', "no albums"), true);
+$image_str = gTranslate('core', "1 photo", "%d photos", $numPhotos, gTranslate('core', "no photos"), true);
 
-$description = sprintf(_("%s in %s"), $image_str, $total_str);
+$description = sprintf(gTranslate('core', "%s in %s"), $image_str, $total_str);
 
 header("Content-Type: application/xml");
 
@@ -306,7 +317,7 @@ echo '<' . '?xml version="1.0" encoding="' . $gallery->locale . '"?' . '>';
 
 $maxAlbums = 0;
 foreach($albumList as $album) {
-	
+
 	// If we've hit the max album limit, bust out.
 	if($maxAlbums > $gallery->app->rssMaxAlbums) {
 		break;
@@ -318,7 +329,7 @@ foreach($albumList as $album) {
 		if ($myAlbum->isHiddenRecurse() || !$myAlbum->canReadRecurse($gallery->user->uid)) {
 			continue;
 		}
-	} 
+	}
 
 	// Only increment after we've determined that the album
 	// is valid to add to the feed
@@ -331,7 +342,7 @@ foreach($albumList as $album) {
 		if (ereg("^!", $tag)) {
 			continue;
 		}
-		
+
 		if (is_array($info)) {
 			echo "\t\t\t<$tag";
 			foreach($info[1] as $attr => $value) {
@@ -342,7 +353,7 @@ foreach($albumList as $album) {
 			echo "\t\t\t<$tag>$info</$tag>\n";
 		}
 	}
-	
+
 	echo "\t\t</item>\n";
 }
 
