@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,10 +17,14 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: session.php,v 1.51.2.1 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: session.php 193 2008-07-15 22:02:33Z jens $
  */
-?>
-<?php
+
+if(!defined('LOAD_SESSIONS')) {
+	echo "Invalid Request. Hard Exit.";
+	exit;
+}
+
 /*
  * PHP 4.0.1pl2 introduces a bug where you can't unserialize a 
  * stdClass instance correctly.  So create a dummy class to hold all
@@ -37,8 +41,8 @@ class GallerySession {}
 /* If using PHP < 4.3.2, create our own session_regenerate_id() function */
 if (!function_exists('session_regenerate_id')) {
 	function make_seed() {
-	    list($usec, $sec) = explode(' ', microtime());
-	    return (float)$sec + ((float)$usec * 100000);
+		list($usec, $sec) = explode(' ', microtime());
+		return (float)$sec + ((float)$usec * 100000);
 	}
 
 	function php_combined_lcg() {
@@ -114,7 +118,7 @@ function createGallerySession($newSession = false) {
 
 	// If we're requesting a new session, generate a new session id
 	if ($newSession) {
-	    session_regenerate_id();
+		session_regenerate_id();
 	}
 
 	/*
@@ -167,9 +171,9 @@ update_session_var("fullOnly");
 update_session_var("username", 1);
 update_session_var("offline");
 update_session_var("offlineAlbums");
-if (!isset($gallery->session->offlineAlbums) || $gallery->session->offlineAlbums == null)
-{
-      $gallery->session->offlineAlbums=array();
+
+if (!isset($gallery->session->offlineAlbums) || $gallery->session->offlineAlbums == null) {
+	  $gallery->session->offlineAlbums = array();
 }
 
 /*
