@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,10 +17,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: slideshow.php,v 1.77.2.2 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: slideshow.php 193 2008-07-15 22:02:33Z jens $
  */
-?>
-<?php
+
 	require(dirname(__FILE__)  . '/init.php');
 
 list($mode) = getRequestVar(array('mode'));
@@ -31,7 +30,8 @@ if (isset($mode)) {
 	if ($modeCookie != $mode) {
 	    setcookie($cookieName, $mode, time()+60*60*24*365, "/" );
 	}
-} else {
+}
+else {
 	if (isset($modeCookie)) {
 	    $mode = $modeCookie;
 	}
@@ -67,8 +67,8 @@ if (!empty($albumName)) {
 
 // common initialization
 if (empty($albumName)) {
-	$album = null;
-	$recursive = true;
+	$album		= null;
+	$recursive	= true;
 	$number		= (int)$gallery->app->gallery_slideshow_length;
 	$random		= ($gallery->app->gallery_slideshow_type == "random");
 	$loop		= ($gallery->app->gallery_slideshow_loop == "yes");
@@ -84,27 +84,28 @@ if (empty($albumName)) {
 	$bgcolor	= $gallery->album->fields['bgcolor'];
 }
 
-$playIconText = getIconText('1rightarrow.gif', _("play"));
-$stopIconText = getIconText('2downarrow.gif', _("stop"));
-$normalSizeIconText = getIconText('window_nofullscreen.gif', _("normal size"));
-$fullSizeIconText = getIconText('window_fullscreen.gif', _("full size"));
-$forwardIconText = getIconText('1rightarrow.gif', _("forward direction"));
-$backwardIconText = getIconText('1leftarrow.gif', _("reverse direction"));
-$delayIconText = getIcontext('history.gif', _("Delay"));
-$loopIconText =  getIcontext('reload.gif', _("Loop:"));
+$playIconText		= getIconText('slideshow/1rightarrow.gif', gTranslate('core', "Play"));
+$stopIconText		= getIconText('slideshow/play_stop.gif', gTranslate('core', "Stop"));
+$normalSizeIconText	= getIconText('window_nofullscreen.gif', gTranslate('core', "Normal size"));
+$fullSizeIconText	= getIconText('window_fullscreen.gif', gTranslate('core', "Full size"));
+$forwardIconText	= getIconText('slideshow/1rightarrow.gif', gTranslate('core', "Forward direction"));
+$backwardIconText	= getIconText('slideshow/1leftarrow.gif', gTranslate('core', "Reverse direction"));
+$delayIconText		= getIcontext('history.gif', gTranslate('core', "Delay"));
+$loopIconText		= getIcontext('reload.gif', gTranslate('core', "Loop:"));
 
 // in offline mode, only high is available, because it's the only
 // one where the photos can be spidered...
 if (file_exists(dirname(__FILE__) . "/java/GalleryRemoteAppletMini.jar") &&
 	file_exists(dirname(__FILE__) . "/java/GalleryRemoteHTTPClient.jar") &&
-	! $gallery->session->offline) {
-	$modes["applet"] = _("Fullscreen applet");
+	! $gallery->session->offline)
+{
+	$modes["applet"] = gTranslate('core', "Fullscreen applet");
 }
 
-$modes["high"] = _("Modern browsers");
+$modes["high"] = gTranslate('core', "Modern browsers");
 
 if (!empty($albumName) && !$gallery->session->offline) {
-    $modes["low"] = _("Compatible but limited");
+	$modes["low"] = gTranslate('core', "Compatible but limited");
 }
 
 if (!isset($mode) || !isset($modes[$mode])) {
@@ -113,7 +114,6 @@ if (!isset($mode) || !isset($modes[$mode])) {
 
 include(dirname(__FILE__) . "/includes/slideshow/$mode.inc");
 
-
 slideshow_initialize();
 
 if (!$GALLERY_EMBEDDED_INSIDE) {
@@ -122,32 +122,40 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
 <html>
 <head>
   <title><?php echo $title; ?></title>
-<?php 
+<?php
 	common_header();
 
 // the link colors have to be done here to override the style sheet
 if ($albumName) {
-	echo "\n". '<style type="text/css">';
+	if( !empty($gallery->album->fields["linkcolor"]) ||
+	!empty($gallery->album->fields["bgcolor"]) ||
+	!empty($gallery->album->fields["textcolor"]))
+{
+		echo "\n<style type=\"text/css\">";
+		// the link colors have to be done here to override the style sheet
 	if ($gallery->album->fields["linkcolor"]) {
-?>
-    A:link, A:visited, A:active
-      { color: <?php echo $gallery->album->fields['linkcolor'] ?>; }
-    A:hover
-      { color: #ff6600; }
-<?php
+			echo "\n  a:link, a:visited, a:active {";
+			echo "\n	color: ".$gallery->album->fields['linkcolor'] ."; }";
+			echo "\n  a:hover { color: #ff6600; }";
+
        	}
+
        	if ($gallery->album->fields["bgcolor"]) {
-	       	echo "BODY { background-color:".$gallery->album->fields['bgcolor']."; }";
+			echo "body { background-color:".$gallery->album->fields['bgcolor']."; }";
        	}
-       	if (isset($gallery->album->fields["background"]) && $gallery->album->fields["background"]) {
-	       	echo "BODY { background-image:url(" . $gallery->album->fields['background'] . "); } ";
+
+		if (isset($gallery->album->fields['background']) && $gallery->album->fields['background']) {
+			echo "body { background-image:url(".$gallery->album->fields['background']."); } ";
        	}
+
        	if ($gallery->album->fields["textcolor"]) {
-	       	echo "BODY, TD {color:" . $gallery->album->fields['textcolor']."; }";
-	       	echo ".head {color:" . $gallery->album->fields['textcolor'] . "; }";
-	       	echo ".headbox {background-color:" . $gallery->album->fields['bgcolor'] . "; }";
+			echo "body, tf {color:".$gallery->album->fields['textcolor']."; }";
+			echo ".head {color:".$gallery->album->fields['textcolor']."; }";
+			echo ".headbox {background-color:".$gallery->album->fields['bgcolor']."; }";
+		}
+
+		echo "\n  </style>";
        	}
-	echo "\n</style>\n";
 }
 ?>
 </head>
@@ -174,25 +182,13 @@ if ( (is_ie && !is_ie4up) || (is_opera && !is_opera5up) || (is_nav && !is_nav6up
 </script>
 
 <?php
+
 	slideshow_body();
 
 $imageDir = $gallery->app->photoAlbumURL."/images";
 
 #-- breadcrumb text ---
-$upArrowURL = '<img src="' . getImagePath('nav_home.gif') . '" width="13" height="11" '.
-  'alt="' . _("navigate UP") .'" title="' . _("navigate UP") .'" border="0">';
-
-if (isset($gallery->album)) {
-    foreach ($gallery->album->getParentAlbums(true) as $navAlbum) {
-	$breadcrumb["text"][] = $navAlbum['prefixText'] .': <a class="bread" href="'. $navAlbum['url'] . '">'.
-	  $navAlbum['title'] . "&nbsp;" . $upArrowURL . "</a>";
-    }
-}
-else {
-    /* We're on mainpage */
-    $breadcrumb["text"][]= _("Gallery") .": <a class=\"bread\" href=\"" . makeGalleryUrl("albums.php") . "\">" .
-      $gallery->app->galleryTitle . "&nbsp;" . $upArrowURL . "</a>";
-}
+$breadcrumb["text"] = @returnToPathArray($gallery->album, true, true);
 
 $breadcrumb["bordercolor"] = $borderColor;
 
@@ -203,9 +199,10 @@ if ( !$gallery->session->offline) {
 	foreach ($modes as $m => $mt) {
 		$url=makeGalleryUrl('slideshow.php',array('mode' => $m, "set_albumName" => $gallery->session->albumName));
 		if ($m != $mode) {
-			$adminbox["commands"] .= "&nbsp;<a class=\"admin\" href=\"$url\">[" .$modes[$m] ."]</a>";
-		} else {
-			$adminbox["commands"] .= "&nbsp;" .$modes[$m];
+			$adminbox['commands'] .= "&nbsp;<a href=\"$url\">[" .$modes[$m] ."]</a>";
+		}
+		else {
+			$adminbox['commands'] .= "&nbsp;" .$modes[$m];
 		}
 	}
 }
