@@ -1,27 +1,25 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
- * 
+ * Copyright (C) 2000-2008 Bharat Mediratta
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or (at
  * your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: stats-wizard.php,v 1.9.2.2 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: stats-wizard.php 253 2008-07-28 19:08:00Z jens $
  *
  */
-?>
-<?php
 
 if (!isset($gallery->version)) {
 	require_once(dirname(__FILE__) . '/init.php');
@@ -35,35 +33,31 @@ if (!$gallery->user->isAdmin()) {
 
 require_once(dirname(__FILE__) . '/includes/stats/stats.inc.php');
 
+$iconElements = array();
+
+$iconElements[] = galleryIconLink(
+				makeGalleryUrl("admin-page.php"),
+				'navigation/return_to.gif',
+				gTranslate('core', "Return to admin page"));
+
+$iconElements[] = galleryIconLink(
+				makeAlbumUrl(),
+				'navigation/return_to.gif',
+				gTranslate('core', "Return to gallery"));
+
+$iconElements[] = LoginLogoutButton(makeGalleryUrl());
+
+$adminbox['text'] = gTranslate('core', "Gallery statistics - Wizard");
+$adminbox['commands'] = makeIconMenu($iconElements, 'right');
+
+$breadcrumb['text'][] = languageSelector();
+
 if (!$GALLERY_EMBEDDED_INSIDE) {
-    doctype();
-?>
-<html>
-<head>
-<title><?php echo $gallery->app->galleryTitle ?>::<?php echo _("Gallery statistics - Wizard") ?></title>
-<?php 
-	common_header() ;
-?>
-</head>
-<body dir="<?php echo $gallery->direction ?>">
-<?php  
+	printPopupStart(clearGalleryTitle($adminbox['text']), '', 'left');
 }
 
-    includeHtmlWrap("gallery.header");
-
-    $adminbox['text'] ='<span class="head">'. _("Gallery statistics - Wizard") .'</span>';
-    $adminCommands = '[<a href="'. makeGalleryUrl("admin-page.php") .'">'. _("return to admin page") .'</a>] ';
-    $adminCommands .= '[<a href="'. makeAlbumUrl() .'">'. _("return to gallery") .'</a>] ';
-
-    $adminbox["commands"] = $adminCommands;
-    $adminbox["bordercolor"] = $gallery->app->default["bordercolor"];
-    $breadcrumb['text'][] = languageSelector();
-
-    includeLayout('navtablebegin.inc');
-    includeLayout('adminbox.inc');
-    includeLayout('navtablemiddle.inc');
-    includeLayout('breadcrumb.inc');
-    includeLayout('navtableend.inc');
+includeLayout('adminbox.inc');
+includeLayout('breadcrumb.inc');
 
 ?>
 <div class="popup" align="center">
@@ -79,7 +73,7 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
 	/* This javascript goes through all elements of the form 'stats_form'
 	** depending if set or not it generates an string that represents the parameters for stats.php
 	*/
-	for(var i=0;i<document.stats_form.length; i++) {
+	for(var i = 0; i < document.stats_form.length; i++) {
 		value = false;
 		/* special case */
 		if ((document.stats_form.elements[i].name == 'cols' || document.stats_form.elements[i].name == 'rows') &&
@@ -88,21 +82,21 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
 		}
 		switch(document.stats_form.elements[i].type) {
 			case 'submit':
-			    continue;
+				continue;
 			break;
-			
+
 			case 'checkbox':
-			    if(document.stats_form.elements[i].checked) {
+				if(document.stats_form.elements[i].checked) {
 				value = 1;
-			    }
+				}
 			break;
 
 			case 'radio':
-			    if (document.stats_form.elements[i].checked) {
+				if (document.stats_form.elements[i].checked) {
 				value = document.stats_form.elements[i].value;
-			    }
+				}
 			break;
-			
+
 			default:
 				value = document.stats_form.elements[i].value;
 			break;
@@ -111,40 +105,38 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
 			url = url + '&'+ document.stats_form.elements[i].name +'=' + value;
 		}
 	}
-	document.url_form.stats_url.value = url;
+	document.getElementById('stats_url').value = url;
 }
 </script>
 
 <?php
-	echo makeFormIntro("stats.php", array("name" => "stats_form", 
-						"method" => "POST",
-						"onChange" => 'updateUrl()'));
+	echo makeFormIntro("stats.php", array("name" => "stats_form", "onChange" => 'updateUrl()'));
 	echo "\n<table width=\"100%\" border=\"0\">";
 	echo "\n<tr>";
 	echo "\n<td class=\"blockcell\">";
-		stats_showBlock($stats['types'], _("Type"));
+		stats_showBlock($stats['types'], gTranslate('core', "Type"));
 	echo "\n</td>";
 
 	echo "\n<td class=\"blockcell\">";
-		stats_showBlock($stats['options'], _("Options"));
+		stats_showBlock($stats['options'], gTranslate('core', "Options"));
 	echo "\n\t</td>";
 	echo "\n</tr>";
 	echo "\n<tr>";
 	echo "\n<td class=\"blockcell\">";
-		stats_showBlock($stats['layout'], _("Layout"));
+		stats_showBlock($stats['layout'], gTranslate('core', "Layout"));
 	echo "\n\t</td>";
-	
+
 	echo "\n<td class=\"blockcell\">";
-		stats_showBlock($stats['filter'], _("Filter by Capture Date"));
+		stats_showBlock($stats['filter'], gTranslate('core', "Filter by Capture Date"));
 	echo "\n\t</td>";
-	
+
 	echo "\n</tr>";
 	echo "\n</table>";
-	echo "\n". '<input type="submit" name="submitbutton" value="'. _("Show statistics") . '">';
+	echo gsubmit('submitbutton', gTranslate('core', "Show statistics"));
 	echo "\n</form>";
 
 	echo "\n". '<div align="left">';
-	echo _("Maybe your want to use your OWN statistics somewhere .. Just copy and paste the url from this textbox.");
+	echo gTranslate('core', "Maybe your want to use your OWN statistics somewhere... Just copy and paste the URL from this textbox.");
 	echo "\n<br>". '<form name="url_form" action="#">';
 	echo "\n". '<input type="text" name="stats_url" size="150" value="" readonly';
 	echo "\"</div>";
@@ -156,7 +148,9 @@ if (!$GALLERY_EMBEDDED_INSIDE) {
   // We could do this onLoad, but this doesnt work embedded.
   updateUrl();
 </script>
+
 </div>
+
 <?php
 includeHtmlWrap("stats.footer");
 
