@@ -1,7 +1,7 @@
 <?php
 /*
  * Gallery - a web based photo album viewer and editor
- * Copyright (C) 2000-2005 Bharat Mediratta
+ * Copyright (C) 2000-2008 Bharat Mediratta
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,10 +17,9 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * $Id: view_photo.php,v 1.260.2.3 2005/09/12 22:40:44 dmolavi Exp $
+ * $Id: view_photo.php 239 2008-07-28 09:07:46Z jens $
  */
-?>
-<?php
+
 /**
  * @package Item
  */
@@ -34,108 +33,125 @@ $iconsForItemOptions = true;
 
 require_once(dirname(__FILE__) . '/init.php');
 
-list($full, $id, $index, $votes) = getRequestVar(array('full', 'id', 'index', 'votes'));
-list($save, $commenter_name, $comment_text) = getRequestVar(array('save', 'commenter_name', 'comment_text'));
-
 // Hack check and prevent errors
-if (empty($gallery->session->albumName) || !$gallery->user->canReadAlbum($gallery->album) || !$gallery->album->isLoaded()) {
-    $gallery->session->gRedirDone = false;
-    header("Location: " . makeAlbumHeaderUrl('', '', array('gRedir' => 1)));
-    return;
+if (empty($gallery->session->albumName) ||
+	!$gallery->user->canReadAlbum($gallery->album) ||
+	!$gallery->album->isLoaded())
+{
+	$gallery->session->gRedirDone = false;
+	header("Location: " . makeAlbumHeaderUrl('', '', array('gRedir' => 1)));
+	return;
 }
 
+list($full, $id, $index, $votes) =
+	getRequestVar(array('full', 'id', 'index', 'votes'));
+
+list($save, $commenter_name, $comment_text) =
+	getRequestVar(array('save', 'commenter_name', 'comment_text'));
+
 // Set $index from $id
 if (isset($id)) {
-    $index = $gallery->album->getPhotoIndex($id);
-    if ($index == -1) {
-        // That photo no longer exists.
-        header("Location: " . makeAlbumHeaderUrl($gallery->session->albumName));
-        return;
-    }
-} else {
+	$index = $gallery->album->getPhotoIndex($id);
+	if ($index == -1) {
+		// That photo no longer exists.
+		header("Location: " . makeAlbumHeaderUrl($gallery->session->albumName));
+		return;
+	}
+}
+else {
     if ($index > $gallery->album->numPhotos(1)) {
-        $index = $numPhotos;
+        $index = $gallery->album->numPhotos(1);
     }
     $id = $gallery->album->getPhotoId($index);
 }
 
 $nextId = getNextId($id);
 
-// Determine if user has the rights to view full-sized images
+$currentUrlResized = makeAlbumHeaderUrl($gallery->session->albumName, $id);
+
+/* Determine if user has the rights to view full-sized images */
 if (!empty($full) && !$gallery->user->canViewFullImages($gallery->album)) {
-    header("Location: " . makeAlbumHeaderUrl($gallery->session->albumName, $id));
-    return;
-} elseif (!$gallery->album->isResized($index) && !$gallery->user->canViewFullImages($gallery->album)) {
-    header("Location: " . makeAlbumHeaderUrl($gallery->session->albumName));
-    return;
+	header("Location: $currentUrlResized");
+	return;
+}
+elseif (!$gallery->album->isResized($index) &&
+	!$gallery->user->canViewFullImages($gallery->album))
+{
+	header("Location: " . makeAlbumHeaderUrl($gallery->session->albumName));
+	return;
 }
 
 if (!isset($full) || (isset($full) && !$gallery->album->isResized($index))) {
-    $full = NULL;
+	$full = NULL;
 }
 
-if (!empty($votes)) {
-    if (!isset($votes[$id]) &&
-        $gallery->album->getPollScale() == 1 &&
-        $gallery->album->getPollType() == "critique") {
-        $votes[$id] = null;
-    }
+if (!empty($votes) && canVote()) {
+	if (!isset($votes[$id]) &&
+		$gallery->album->getPollScale() == 1 &&
+		$gallery->album->getPollType() == "critique")
+	{
+		$votes[$id] = null;
+	}
 
-    saveResults($votes);
-    if ($gallery->album->getPollShowResults()) {
-        list($buf, $rank)=showResultsGraph(0);
-        print $buf;
-    }
+	saveResults($votes);
+	if ($gallery->album->getPollShowResults()) {
+		list($buf, $rank)=showResultsGraph(0);
+		print $buf;
+	}
 }
 
 $albumName = $gallery->session->albumName;
-if (!isset($gallery->session->viewedItem[$gallery->session->albumName][$id]) &&
-  !$gallery->session->offline) {
-    $gallery->session->viewedItem[$albumName][$id] = 1;
-    $gallery->album->incrementItemClicks($index);
+$noCount = getRequestVar('noCount');
+
+if ($noCount != 1 && !isset($gallery->session->viewedItem[$gallery->session->albumName][$id]) &&
+    !$gallery->session->offline) {
+	$gallery->session->viewedItem[$albumName][$id] = 1;
+	$gallery->album->incrementItemClicks($index);
 }
 
 $photo = $gallery->album->getPhoto($index);
 
 if ($photo->isMovie()) {
-    $image = $photo->thumbnail;
-} else {
-    $image = $photo->image;
+	$image = $photo->thumbnail;
+}
+else {
+	$image = $photo->image;
 }
 
 $photoURL = $gallery->album->getAlbumDirURL("full") . "/" . $image->name . "." . $image->type;
 list($imageWidth, $imageHeight) = $image->getRawDimensions();
 
 $do_fullOnly = isset($gallery->session->fullOnly) &&
-                !strcmp($gallery->session->fullOnly,"on") &&
-                !strcmp($gallery->album->fields["use_fullOnly"],"yes");
+			!strcmp($gallery->session->fullOnly,"on") &&
+			!strcmp($gallery->album->fields["use_fullOnly"],"yes");
+
 if ($do_fullOnly) {
-    $full = $gallery->user->canViewFullImages($gallery->album);
+	$full = $gallery->user->canViewFullImages($gallery->album);
 }
 
-$fitToWindow = !strcmp($gallery->album->fields["fit_to_window"], "yes")
-                && !$gallery->album->isResized($index)
-                && !$full
-                && (!$GALLERY_EMBEDDED_INSIDE || $GALLERY_EMBEDDED_INSIDE =='phpBB2');
+$fitToWindow = !strcmp($gallery->album->fields["fit_to_window"], "yes") &&
+    !$gallery->album->isMovieByIndex($index) &&
+    !$gallery->album->isResized($index) &&
+    !$full &&
+    (!$GALLERY_EMBEDDED_INSIDE || $GALLERY_EMBEDDED_INSIDE =='phpBB2');
 
 $numPhotos = $gallery->album->numPhotos($gallery->user->canWriteToAlbum($gallery->album));
 
 $next = $index+1;
 if ($next > $numPhotos) {
-    //$next = 1;
-    $last = 1;
+	//$next = 1;
+	$last = 1;
 }
 
 $prev = $index-1;
 if ($prev <= 0) {
-    //$prev = $numPhotos;
-    $first = 1;
+	//$prev = $numPhotos;
+	$first = 1;
 }
 
 /*
-* We might be prev/next navigating using this page
-*  so recalculate the 'page' variable
-*/
+ * We might be prev/next navigating using this page so recalculate the 'page' variable
+ */
 $rows = $gallery->album->fields["rows"];
 $cols = $gallery->album->fields["cols"];
 $perPage = $rows * $cols;
@@ -144,14 +160,14 @@ $page = (int)(ceil($index / ($rows * $cols)));
 $gallery->session->albumPage[$gallery->album->fields['name']] = $page;
 
 /*
-* Relative URLs are tricky if we don't know if we're rewriting
-* URLs or not.  If we're rewriting, then the browser will think
-* we're down 1 dir farther than we really are.  Use absolute
-* urls wherever possible.
+ * Relative URLs are tricky if we don't know if we're rewriting
+ * URLs or not.  If we're rewriting, then the browser will think
+ * we're down 1 dir farther than we really are.  Use absolute
+ * urls wherever possible.
 */
 $top = $gallery->app->photoAlbumURL;
 
-$bordercolor = $gallery->album->fields["bordercolor"];
+$bordercolor = $gallery->album->fields['bordercolor'];
 
 $mainWidth = "100%";
 
@@ -163,17 +179,9 @@ $navigator["url"] = ".";
 $navigator["bordercolor"] = $bordercolor;
 
 #-- breadcrumb text ---
-$upArrowURL = '<img src="' . getImagePath('nav_home.gif') . '" width="13" height="11" '.
-  'alt="' . _("navigate UP") .'" title="' . _("navigate UP") .'" border="0">';
+$breadcrumb["text"] = returnToPathArray($gallery->album, true);
 
-if ($gallery->album->fields['returnto'] != 'no') {
-    foreach ($gallery->album->getParentAlbums(true) as $navAlbum) {
-        $breadcrumb["text"][] = $navAlbum['prefixText'] .': <a class="bread" href="'. $navAlbum['url'] . '">'.
-        $navAlbum['title'] . "&nbsp;" . $upArrowURL . "</a>";
-    }
-}
-
-$extra_fields=$gallery->album->getExtraFields(false);
+$extra_fields = $gallery->album->getExtraFields(false);
 $title = NULL;
 if (in_array("Title", $extra_fields)) {
     $title = $gallery->album->getExtraField($index, "Title");
@@ -188,22 +196,31 @@ if (isset($gallery->app->comments_length)) {
     $maxlength = 0;
 }
 
-if (!empty($save)) {
+if (!empty($save) && $gallery->user->canAddComments($gallery->album)) {
     if ( empty($commenter_name) || empty($comment_text)) {
-        $error_text = _("Name and comment are both required to save a new comment!");
-    } elseif ($maxlength >0 && strlen($comment_text) > $maxlength) {
-        $error_text = sprintf(_("Your comment is too long, the admin set maximum length to %d chars"), $maxlength);
-    } elseif (isBlacklistedComment($tmp = array('commenter_name' => $commenter_name, 'comment_text' => $comment_text), false)) {
-        $error_text = _("Your Comment contains forbidden words. It will not be added.");
-    } else {
-        $comment_text = removeTags($comment_text);
-        $commenter_name = removeTags($commenter_name);
+        $error_text = gTranslate('core', "Name and comment are both required to save a new comment!");
+    }
+    elseif ($maxlength >0 && strlen($comment_text) > $maxlength) {
+        $error_text = sprintf(gTranslate('core', "Your comment is too long, the admin set maximum length to %d chars"), $maxlength);
+    }
+    elseif (isBlacklistedComment($tmp = array('commenter_name' => $commenter_name, 'comment_text' => $comment_text), false)) {
+        $error_text = gTranslate('core', "Your Comment contains forbidden words. It will not be added.");
+    }
+    else {
+        $comment_text = $comment_text;
+        $commenter_name = $commenter_name;
         $IPNumber = $_SERVER['REMOTE_ADDR'];
         $gallery->album->addComment($id, $comment_text, $IPNumber, $commenter_name);
         $gallery->album->save();
         emailComments($id, $comment_text, $commenter_name);
     }
 }
+if(!$fitToWindow) {
+	$allImageAreas = $gallery->album->getAllImageAreas($index);
+}
+else {
+	$allImageAreas = '';
+}
 
 $metaTags = array();
 $keyWords = $gallery->album->getKeywords($index);
@@ -213,42 +230,56 @@ if (!empty($keyWords)) {
 
 if (!$GALLERY_EMBEDDED_INSIDE) {
 	doctype(); ?>
-<html> 
+<html>
 <head>
   <title><?php echo $gallery->app->galleryTitle . ' :: '. $gallery->album->fields["title"] . ' :: '. $title ; ?></title>
-  <?php 	
+  <?php
   common_header(array('metaTags' => $metaTags));
 
   /* prefetch/navigation */
   $navcount = sizeof($navigator['allIds']);
   $navpage = $navcount - 1;
+
+  $firstUrl  = makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][0], array('noCount' => 1));
+  $lastUrl   = makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navcount - 1], array('noCount' => 1));
+  $upUrl     = makeAlbumUrl($gallery->session->albumName, '', array('noCount' => 1));
+
   while ($navpage > 0) {
       if (!strcmp($navigator['allIds'][$navpage], $id)) {
           break;
       }
       $navpage--;
   }
+
   if ($navigator['allIds'][0] != $id) {
       if ($navigator['allIds'][0] != 'unknown') {
-          echo "\n  ". '<link rel="first" href="'. makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][0]) .'">';
+          echo "\n  ". '<link rel="first" href="'. $firstUrl .'">';
       }
 
       if ($navigator['allIds'][$navpage-1] != 'unknown') {
-          echo "\n  ". '<link rel="prev" href="'. makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navpage-1]) .'">';
-      }
-  }
-  if ($navigator['allIds'][$navcount - 1] != $id) {
-      if ($navigator['allIds'][$navpage+1] != 'unknown') {
-          echo "\n  ". '<link rel="next" href="'. makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navpage+1]) .'">';
-      }
-      if ($navigator['allIds'][$navcount-1] != 'unknown') {
-          echo "\n  ". '<link rel="last" href="'. makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navcount - 1]) .'">';
+          $prevUrl   = makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navpage-1],
+                            array('noCount' => 1));
+
+          echo "\n  ". '<link rel="prev" href="'. $prevUrl .'">';
       }
   }
 
-  echo "\n  ". '<link rel="up" href="' . makeAlbumUrl($gallery->session->albumName) .'">';
+  if ($navigator['allIds'][$navcount - 1] != $id) {
+      if ($navigator['allIds'][$navpage+1] != 'unknown') {
+          $nextUrl   = makeAlbumUrl($gallery->session->albumName, $navigator['allIds'][$navpage+1],
+                            array('noCount' => 1));
+
+          echo "\n  ". '<link rel="next" href="'. $nextUrl .'">';
+      }
+      if ($navigator['allIds'][$navcount-1] != 'unknown') {
+          echo "\n  ". '<link rel="last" href="'. $lastUrl .'">';
+      }
+  }
+
+  echo "\n  ". '<link rel="up" href="' . $upUrl .'">';
+
   if ($gallery->album->isRoot() &&
-  (!$gallery->session->offline || isset($gallery->session->offlineAlbums["albums.php"]))) {
+  	 (!$gallery->session->offline || isset($gallery->session->offlineAlbums["albums.php"]))) {
       echo "\n  ". '<link rel="top" href="'. makeGalleryUrl('albums.php', array('set_albumListPage' => 1)) .'">';
   }
 ?>
@@ -262,7 +293,7 @@ if (!empty($gallery->album->fields["linkcolor"])) {
       { color: <?php echo $gallery->album->fields['linkcolor'] ?>; }
     A:hover
       { color: #ff6600; }
-<?php 
+<?php
 }
 if (!empty($gallery->album->fields["bgcolor"])) {
     echo "BODY { background-color:" . $gallery->album->fields['bgcolor'] . "; }";
@@ -278,20 +309,25 @@ if (!empty($gallery->album->fields["textcolor"])) {
     }
 }
 ?>
-  </style> 
+  </style>
+
   </head>
-  <body dir="<?php echo $gallery->direction ?>"<?php echo ($fitToWindow) ? ' onResize="calculateNewSize()"' : '' ?>>
+  <body dir="<?php echo $gallery->direction ?>">
 <?php
 } // End if ! embedded
 
 includeHtmlWrap("photo.header");
 
+if (!empty($allImageAreas)) {
+	echo jsHTML('wz/wz_tooltip.js');
+}
+
 $useIcons = (!$iconsForItemOptions || $gallery->app->useIcons == 'no') ? false : true;
 $albumItemOptions = getItemActions($index, $useIcons);
 
 if ($fitToWindow) {
     /* Include Javascript */
-    include(dirname(__FILE__) .'/js/fitToWindow.js.php');
+    echo jsHTML('fitToWindow.js.php');
 }
 ?>
 <!-- Top Nav Bar -->
@@ -307,18 +343,19 @@ if (!$gallery->album->isMovie($id)) {
     print '<a id="page_url" href="'. $page_url .'"></a>'."\n";
 
     if ($gallery->album->fields["use_exif"] == "yes" &&
-      (eregi("jpe?g\$", $photo->image->type)) &&
-      (isset($gallery->app->use_exif) || isset($gallery->app->exiftags)) &&
-      sizeof($albumItemOptions) == 2) {
+		(eregi("jpe?g\$", $photo->image->type)) &&
+		(isset($gallery->app->use_exif) || isset($gallery->app->exiftags)) &&
+		sizeof($albumItemOptions) == 2)
+	{
         $albumName = $gallery->session->albumName;
-        $iconText = getIconText('frame_query.gif', _("photo properties"));
+        $iconText = getIconText('frame_query.gif', gTranslate('core', "photo properties"));
         $iconElements[] =  popup_link($iconText, "view_photo_properties.php?set_albumName=$albumName&index=$index", 0, false, 500, 500);
     }
 
     if (!empty($gallery->album->fields["print_photos"]) &&
-      !$gallery->session->offline &&
-      !$gallery->album->isMovie($id)){
-
+		!$gallery->session->offline &&
+		!$gallery->album->isMovie($id))
+	{
         $photo = $gallery->album->getPhoto($GLOBALS["index"]);
         $photoPath = $gallery->album->getAlbumDirURL("full");
         $prependURL = '';
@@ -336,31 +373,29 @@ if (!$gallery->album->isMovie($id)) {
         $thumbImage= $prependURL . $photoPath . "/";
         if ($photo->thumbnail) {
             $thumbImage .= $photo->image->name . "." . "thumb" . "." . $photo->image->type;
-        } else if ($photo->image->resizedName) {
+		}
+		else if ($photo->image->resizedName) {
             $thumbImage .= $photo->image->name . "." . "sized" . "." . $photo->image->type;
-        } else {
+		}
+		else {
             $thumbImage .= $photo->image->name . "." . $photo->image->type;
         }
 
         list($imageWidth, $imageHeight) = $photo->image->getRawDimensions();
 
-        /*
-        ** Now build the admin Texts / left colun
-        */
-
+		/* Now build the admin Texts / left colun */
         function enablePrintForm($name) {
-            global $printEZPrintsForm, $printPhotoAccessForm, $printShutterflyForm, $printFotoserveForm;
+            global $printPhotoAccessForm, $printShutterflyForm;
 
             switch ($name) {
                 case 'shutterfly':
                     $printShutterflyForm = true;
-                    break;
-                case 'fotoserve':
-                    $printFotoserveForm = true;
-                    break;
+		break;
+
                 case 'photoaccess':
                     $printPhotoAccessForm = true;
-                    break;
+		break;
+
                 default:
                 break;
             }
@@ -373,11 +408,10 @@ if (!$gallery->album->isMovie($id)) {
         $fullNames = array(
             'Print Services' => array(
                 'fotokasten'  => 'Fotokasten',
-                'fotoserve'   => 'Fotoserve',
                 'shutterfly'  => 'Shutterfly',
                 'photoaccess' => 'PhotoWorks',
             ),
-            'Mobile Service' => array('mpush' => 'mPUSH (mobile service)')
+		'Mobile Service' => array('mpush' => 'mPUSH (mobile service)')
         );
 
         /* display a <select> menu if more than one option */
@@ -387,7 +421,8 @@ if (!$gallery->album->isMovie($id)) {
                 foreach ($serviceGroup as $name => $fullName) {
                     if (!in_array($name, $printServices)) {
                         continue;
-                    } else {
+					}
+					else {
                         $serviceGroups[$serviceGroupName][$name] = $fullName;
                     }
                 }
@@ -396,9 +431,10 @@ if (!$gallery->album->isMovie($id)) {
             $options = array();
 
             if (isset($serviceGroups['Mobile Service'])) {
-                $options[] = _("Send photo to...") ;
-            } else {
-                $options[] = _("Print photo with...");
+                $options[] = gTranslate('core', "Send photo to...") ;
+	    }
+	    else {
+                $options[] = gTranslate('core', "Print photo with...");
             }
 
             $firstGroup = true;
@@ -408,6 +444,7 @@ if (!$gallery->album->isMovie($id)) {
                     $options[]= '----------';
                 }
                 $firstGroup = false;
+
                 foreach ($serviceGroup as $name => $fullName) {
                     enablePrintForm($name);
                     $options[$name] = '&nbsp;&nbsp;&nbsp;'. $fullName;
@@ -426,16 +463,16 @@ if (!$gallery->album->isMovie($id)) {
             $adminTextIconElemens[] = $printServicesText;
 
             /* just print out text if only one option */
-        } elseif ($numServices == 1) {
-            $name = @key($printServices);
-
-            enablePrintForm($name);
+		}
+		elseif ($numServices == 1) {
             foreach ($fullNames as $serviceGroupName => $serviceGroup) {
                 foreach ($serviceGroup as $name => $fullName) {
                     if (!in_array($name, $printServices)) {
                         continue;
-                    } else {
-                        $iconText = getIconText('', sprintf(_('process this photo with %s'), $fullName));
+					}
+					else {
+			enablePrintForm($name);
+                        $iconText = getIconText('', sprintf(gTranslate('core', "process this photo with %s"), $fullName));
                         $adminTextIconElemens[] = "<a class=\"admin\" href=\"#\" onClick=\"doPrintService('$name');\">$iconText</a>";
                     }
                 }
@@ -444,6 +481,7 @@ if (!$gallery->album->isMovie($id)) {
 
 ?>
 <script language="javascript1.2" type="text/JavaScript">
+
 function doPrintService(input) {
     if (!input) {
         input = document.print_form.print_services.value;
@@ -463,10 +501,6 @@ function doPrintService(input) {
         case 'mpush':
             window.open('http://mpush.msolutions.cc/req.php?account=<?php echo $gallery->app->default['mPUSHAccount'] ?>&image=<?php echo $rawImage ?>&caption=<?php echo urlencode($gallery->album->getCaption($index)) ?>','_MPUSH','width=640,height=420,titlebar=1,resizable=1,scrollbars=1');
             break;
-        case 'fotoserve':
-            document.fotoserve.redirect.value=document.location;
-            document.fotoserve.submit();
-        break;
     }
 }
 </script>
@@ -474,18 +508,20 @@ function doPrintService(input) {
     }
     if (!strcmp($gallery->album->fields["use_fullOnly"], "yes") &&
       !$gallery->session->offline  &&
-      $gallery->user->canViewFullImages($gallery->album)) {
+	  	$gallery->user->canViewFullImages($gallery->album))
+	{
         $lparams['set_fullOnly'] = (!isset($gallery->session->fullOnly) || strcmp($gallery->session->fullOnly,"on")) ? "on" : "off";
         $link = makeAlbumURL($gallery->session->albumName, $id, $lparams);
-        $adminTextIconElemens[] = _('View Images:');
-        $iconTextNormal = _("normal");
-        $iconTextFull = _("full");
+        $adminTextIconElemens[] = gTranslate('core', 'View Images:');
+        $iconTextNormal = gTranslate('core', "normal");
+        $iconTextFull = gTranslate('core', "full");
 
         if (!isset($gallery->session->fullOnly) || strcmp($gallery->session->fullOnly,"on")) {
             $adminTextIconElemens[] = $iconTextNormal;
             $adminTextIconElemens[] = '|';
-            $adminTextIconElemens[] = "<a class=\"admin\" href=\"$link\">[" . $iconTextFull .']</a>';
-        } else {
+            $adminTextIconElemens[] = "<a class=\"admin\" href=\"$link\">[". $iconTextFull .']</a>';
+        }
+		else {
             $adminTextIconElemens[] = "<a class=\"admin\" href=\"$link\">[" .$iconTextNormal .']</a>';
             $adminTextIconElemens[] = '|';
             $adminTextIconElemens[] = $iconTextFull;
@@ -497,50 +533,54 @@ function doPrintService(input) {
     */
     if(isset($gallery->album->fields["ecards"]) && $gallery->album->fields["ecards"] == 'yes' &&
       $gallery->app->emailOn == 'yes') {
-        $iconText = getIconText('ecard.gif', _("Send Photo as eCard"));
+        $iconText = getIconText('ecard.gif', gTranslate('core', "Send Photo as eCard"));
         $adminTextIconElemens[] = popup_link($iconText,
-            makeGalleryUrl('ecard_form.php', array('photoIndex' => $index,'gallery_popup' => 'true' )), 1, true, 550, 600);
+            				     makeGalleryUrl('ecard_form.php', array('photoIndex' => $index,'gallery_popup' => 'true' )), 1, true, 550, 600, '', '', '', false);
     }
 }
 
 if(sizeof($albumItemOptions) > 2 && !$useIcons) {
-    $iconElements[] =  drawSelect2("itemOptions", $albumItemOptions, array(
-        'onChange' => "imageEditChoice(document.admin_options_form.itemOptions)",
-        'class' => 'adminform')
+    $iconElements[] =  drawSelect2(
+    	'itemOptions',
+    	$albumItemOptions,
+    	array(
+        	'onChange' => "imageEditChoice(document.admin_options_form.itemOptions)",
+        	'class' => 'adminform'
+        )
     );
 }
 
-if (!$GALLERY_EMBEDDED_INSIDE && !$gallery->session->offline) {
-    if ($gallery->user->isLoggedIn()) {
-        $iconText = getIconText('exit.gif', _("logout"));
-        $iconElements[] = '<a href="'.
-          doCommand("logout", array(), "view_album.php", array("page" => $page)) .
-          '">'. $iconText .'</a>';
-    } else {
-        $iconText = getIconText('identity.gif', _("login"));
-        $iconElements[] = popup_link($iconText, "login.php", false);
-    }
-}
+$iconElements[] = LoginLogoutButton($currentUrlResized);
+
 includeLayout('navtablebegin.inc');
 
-$adminbox["text"] = makeIconMenu($adminTextIconElemens, 'left');
-$adminbox["commands"] = makeIconMenu($iconElements, 'right');
-$adminbox["bordercolor"] = $bordercolor;
+$adminbox['text']		= makeIconMenu($adminTextIconElemens, 'left');
+$adminbox['commands']		= makeIconMenu($iconElements, 'right');
+$adminbox['bordercolor']	= $bordercolor;
 includeLayout('adminbox.inc');
 includeLayout('navtablemiddle.inc');
 
 $breadcrumb["bordercolor"] = $bordercolor;
 includeLayout('breadcrumb.inc');
 
-/* Show itemOptions only if we have more then one (photo properties) */
-if(sizeof($albumItemOptions) > 2 && $useIcons) {
-    includeLayout('navtablemiddle.inc');
-    $albumItemOptionElements = array();
+/* Icon menu above the photo */
+if($useIcons && sizeof($albumItemOptions) > 1) {
     foreach ($albumItemOptions as $trash => $option) {
         if(!empty($option['value'])) {
-            echo "\n". popup_link($option['text'], $option['value'], true, false, 500, 500, 'iconLink');
-        }
+            if (stristr($option['value'], 'popup')) {
+				$content = popup_link(
+						$option['text'],
+						$option['value'],
+						true, false, 550, 600, '', '',
+						$option['icon']);
+            }
+	    else {
+		$content = galleryIconLink($option['value'], $option['icon'], $option['text']);
+            }
+	    $itemActions[] = $content;
+    	}
     }
+    echo makeIconMenu($itemActions, 'center', true, true);
 }
 
 includeLayout('navtablemiddle.inc');
@@ -568,8 +608,7 @@ if ($bordercolor) {
 <!-- End Top Nav Bar -->
 </div>
 
-
-<div style="width:<?php echo $mainWidth ?>"> 
+<div style="width:<?php echo $mainWidth ?>">
 <?php includeHtmlWrap("inline_photo.header"); ?>
 </div>
 
@@ -583,7 +622,7 @@ if (!$gallery->album->isMovie($id)) {
     if(!$do_fullOnly  && ($full || $fitToWindow || $gallery->album->isResized($index))) {
         switch(true) {
             case $fitToWindow:
-                $href="";
+                $href = '';
                 break;
             case $full:
                 $href = makeAlbumUrl($gallery->session->albumName, $id);
@@ -593,29 +632,44 @@ if (!$gallery->album->isMovie($id)) {
                 break;
         }
     }
-} else {
-    $href = $gallery->album->getPhotoPath($index) ;
+}
+else {
+	$href = $gallery->album->getPhotoPath($index) ;
 }
 
 $frame = $gallery->album->fields['image_frame'];
 if ($fitToWindow && (eregi('safari|opera', $_SERVER['HTTP_USER_AGENT']) || $gallery->session->offline)) {
-    //Safari/Opera can't render dynamically sized image frame
-    $frame = 'none';
+	//Safari/Opera can't render dynamically sized image frame
+	$frame = 'none';
 }
 
-$photoTag = $gallery->album->getPhotoTag($index, $full,'id="galleryImage"');
+if(empty($full) && !empty($allImageAreas)) {
+    echo showImageMap($index, $href);
+    $photoTag = $gallery->album->getPhotoTag($index, $full, array('id' => 'galleryImage', 'usemap' => '#myMap'));
+}
+else {
+    $photoTag = $gallery->album->getPhotoTag($index, $full, array('id' => 'galleryImage'));
+}
+
+if($gallery->album->isMovie($id)) {
+    list($width, $height) = $photo->getThumbDimensions();
+}
+else {
+    list($width, $height) = $photo->getDimensions($full);
+}
+
+$gallery->html_wrap['borderColor']		= $gallery->album->fields["bordercolor"];
+$gallery->html_wrap['borderWidth']		= $gallery->album->fields["border"];
+$gallery->html_wrap['frame']			= $frame;
+$gallery->html_wrap['imageWidth']		= $width;
+$gallery->html_wrap['imageHeight']		= $height;
+$gallery->html_wrap['imageHref']		= $href;
+$gallery->html_wrap['imageTag']			= $photoTag;
 
-list($width, $height) = $photo->getDimensions($full);
-$gallery->html_wrap['borderColor'] = $gallery->album->fields["bordercolor"];
-$gallery->html_wrap['borderWidth'] = $gallery->album->fields["border"];
-$gallery->html_wrap['frame'] = $frame;
-$gallery->html_wrap['imageWidth'] = $width;
-$gallery->html_wrap['imageHeight'] = $height;
-$gallery->html_wrap['imageHref'] = $href;
-$gallery->html_wrap['imageTag'] = $photoTag;
 if ($fitToWindow && $gallery->user->canViewFullImages($gallery->album)) {
-    $gallery->html_wrap['attr'] = 'onclick="sizeChange.toggle()"';
+	$gallery->html_wrap['attr']['onclick'] = 'sizeChange.toggle()';
 }
+
 $gallery->html_wrap['pixelImage'] = getImagePath('pixel_trans.gif');
 
 includeHtmlWrap("inline_photo.frame");
@@ -638,8 +692,7 @@ displayPhotoFields($index, $extra_fields, true, in_array('EXIF', $extra_fields),
 
 if ( canVote()) {
     echo "\n<!-- Voting pulldown -->\n";
-    echo makeFormIntro("view_photo.php", array("name" => "vote_form",
-    "method" => "POST"));
+    echo makeFormIntro('view_photo.php', array('name' => 'vote_form'));
 ?>
 	<script language="javascript1.2" type="text/JavaScript">
 	function chooseOnlyOne(i, form_pos, scale) {
@@ -679,27 +732,30 @@ echo "<br>";
 
 includeHtmlWrap("inline_photo.footer");
 
-if ($gallery->user->isLoggedIn() &&  
-  $gallery->user->getEmail() &&
-  !$gallery->session->offline &&
-  $gallery->app->emailOn == "yes") {
-    $emailMeComments = getRequestVar('emailMeComments');
-    if (!empty($emailMeComments)) {
-        if ($emailMeComments == 'true') {
-            $gallery->album->setEmailMe('comments', $gallery->user, $id);
-        } else {
-            $gallery->album->unsetEmailMe('comments', $gallery->user, $id);
-        }
-    }
+if ($gallery->app->comments_enabled == 'yes' &&
+	$gallery->user->isLoggedIn() &&
+	$gallery->user->getEmail() &&
+	!$gallery->session->offline &&
+	$gallery->app->emailOn == "yes")
+{
+	$emailMeComments = getRequestVar('emailMeComments');
+	if (!empty($emailMeComments)) {
+		if ($emailMeComments == 'true') {
+			$gallery->album->setEmailMe('comments', $gallery->user, $id);
+		}
+		else {
+			$gallery->album->unsetEmailMe('comments', $gallery->user, $id);
+		}
+	}
 
     if (! $gallery->album->getEmailMe('comments', $gallery->user)) {
         echo "\n<form name=\"emailMe\" action=\"#\">";
 
         $url= makeAlbumUrl($gallery->session->albumName, $id, array(
-        'emailMeComments' => ($gallery->album->getEmailMe('comments', $gallery->user, $id)) ? 'false' : 'true')
+        	'emailMeComments' => ($gallery->album->getEmailMe('comments', $gallery->user, $id)) ? 'false' : 'true')
         );
 
-        echo _("Email me when comments are added");
+        echo gTranslate('core', "Email me when comments are added");
 ?>
 	<input type="checkbox" name="comments" <?php echo ($gallery->album->getEmailMe('comments', $gallery->user, $id)) ? "checked" : "" ?> onclick="location.href='<?php echo $url; ?>'" >
 	</form>
@@ -723,15 +779,7 @@ if ( $gallery->album->fields['nav_thumbs'] != 'yes') {
 includeLayout('breadcrumb.inc');
 includeLayout('navtableend.inc');
 echo languageSelector();
-if ($fitToWindow) {
-?>
-<script type="text/javascript">
-<!--
-calculateNewSize();
-//-->
-</script>
-<?php 
-}
+
 if (isset($printShutterflyForm)) { ?>
 <form name="sflyc4p" action="http://www.shutterfly.com/c4p/UpdateCart.jsp" method="post">
   <input type=hidden name=addim value="1">
@@ -755,16 +803,9 @@ if (isset($printShutterflyForm)) { ?>
   ?>
   <input type=hidden name=imbkprnta-1 value="<?php echo htmlentities(strip_tags($imbkprnt)) ?>">
 </form>
-<?php }
-if (isset($printFotoserveForm)) { ?>
-<form name="fotoserve" 
-action="http://www.fotoserve.com/menalto/build.html" method="post">
-  <input type="hidden" name="image" value="<?php echo $rawImage ?>">
-  <input type="hidden" name="thumb" value="<?php echo $thumbImage ?>">
-  <input type="hidden" name="redirect" value="this-gets-set-by-javascript-in-onClick">
-  <input type="hidden" name="name" value="<?php echo $photo->image->name . '.' . $photo->image->type; ?>">
-</form>
-<?php }
+<?php
+}
+
 if (isset($printPhotoAccessForm)) { ?>
   <form method="post" name="photoAccess" action="http://www.tkqlhce.com/click-1660787-10381744">
   <input type="hidden" name="cb" value="CB_GP">
@@ -777,8 +818,21 @@ if (isset($printPhotoAccessForm)) { ?>
   <input type="hidden" name="imgHeight" value="<?php echo $imageHeight ?>">
 </form>
 <?php }
-includeHtmlWrap("photo.footer");
-	if (!$GALLERY_EMBEDDED_INSIDE) { ?>
+
+    includeHtmlWrap("photo.footer");
+
+    if ($fitToWindow) {
+?>
+<script type="text/javascript">
+<!--
+calculateNewSize();
+//-->
+</script>
+<?php
+    }
+    if (!$GALLERY_EMBEDDED_INSIDE) { ?>
 </body>
 </html>
-<?php } ?>
+<?php
+}
+?>
\ No newline at end of file
